--[[
    Istelien L (implementation of Istelien quiz engine in LUA with the aim of using it in LOTRO)
	Copyright (C) 2023-2024 Alejandro Meirinhos from Spain.

	This file is part of Istelien L.

	Istelien L is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Istelien L is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Istelien L.  If not, see <https://www.gnu.org/licenses/>.
--]]

import 'Anglachel.Istelien.ChatStatics'	

-- Monitor the game chat in search of answers or commands
function readChat(sender, args)

	if (args['ChatType'] == chatChannels[config['GAME']['GameChannel']]['ID']) then -- Treat chat lines only from the configured channel
	--if (1) then --Debug
		local messageTyped,senderName
				
		local parsingLine = string.gsub(tostring(args['Message']), '<[^>]+>','') -- Remove color formating
		parsingLine = string.gsub(parsingLine, '\n', '') -- Remove linefeeds
		parsingLine = stringTrim(parsingLine) -- Remove outside spaces
		-- Turbine.Shell.WriteLine('Parsing line:' .. parsingLine) -- DEBUG
		-- Check if it's a user's line
		local patternToMatch = '^%[' -- Look for '[' at the beginning
		local foundIndexStart,foundIndexEnd = string.find(parsingLine, patternToMatch)
		if (foundIndexStart ~= nil) then -- '[' was found
			if (foundIndexStart == 1) then -- It's at the beginning, so it's a user line.
				-- Now to get the message that has been sent and the character name of the user who sent it. The game is bugged and it always shows your own character as Sender, so we have to find a different way to find the sender name other than simply looking up where it should be.
				patternToMatch = '^%[' .. replaceCharacters(translate('msgToChannel'), nonbasicCharactersInChat) .. ' %a+%]%s' -- Look for [To <something>]
				foundIndexStart,foundIndexEnd = string.find(parsingLine, patternToMatch)
				if (foundIndexStart ~= nil) then -- If it's found, it's your own chat, and we can look at the proper item for the sender name
					messageTyped = string.sub(parsingLine, foundIndexEnd + 1, #parsingLine)
	
					senderName = args['Sender']
				else -- It has to be [<channel_name>], so it's from a different player. We have to do a workaround to get the sender name
					patternToMatch = '^%[.+%]%s+%a+:%s' -- Find the bit previous to the message: [<channel_name>] <character_name>:
					foundIndexStart,foundIndexEnd = string.find(parsingLine, patternToMatch)
					messageTyped = string.sub(parsingLine, foundIndexEnd + 1, #parsingLine)
					patternToCapture = '^%[.+%]%s+(%a+):.-' -- Capture the character name from the same piece: [<channel_name>] <character_name>:
		
					senderName = string.match(parsingLine, patternToCapture)			
				end
				if (chatChannels[config['GAME']['GameChannel']]['QuotedMessages'] == true) then -- Final tweak. Some channels put quotes in the messages and others dont
					messageTyped = string.sub(messageTyped, 2, #messageTyped - 1)
				end
	
				messageTyped = stringTrim(messageTyped) -- Trim the player's message
				-- Evaluate player's input
				processMessage(messageTyped, senderName)
			end
		end
	end

	return
end

-- Perform actions accordng to input
function processMessage(inputString, sender)
	-- findCharCodes(inputString) -- DEBUG function to find how the game stores non-standard characters typed by someone in chat				
	local patternToCapture = '^(!%a+)' -- !<command> <argument> Look for a command
	local command = string.match(inputString, patternToCapture)
	if (command ~= nil) then -- Process it as a command
		-- Turbine.Shell.WriteLine('Intento de comando.') -- DEBUG
		launchCommand(sender, inputString)
	else -- Process it as an answer
		if (questionState == 1) then
			-- Turbine.Shell.WriteLine('Intento de respuesta.') -- DEBUG
			adaptedString = replaceCharacters(inputString, nonbasicCharactersInChat) -- Preprocess answer to properly show nonbasic characters.
			userAnswer(adaptedString, sender)
		end
	end
end

-- This function was supposed to send messages to chat. Since this is not possible we make it return the command to be fed to a quickslot for the user to click
function sendToChat(message, channelName, target, insertLogo, colour)
	if (colour == nil) then
		colour = 'Default'
	end
	if (target == nil) then
		target = ''
	end
	--[
	message = chatColours[colour] .. message .. chatColours['Closure']
	if (insertLogo == true) then
		message = istelienTextLogo .. ' ' .. message
	end
	--]
	if (channelName == nil) then
		if (target ~= '') then
			channelName = 'Tell'
		else
			channelName = 'Append'
		end
	end
	if (channelName == 'Tell') then 
		if (target ~= '') then
			message = target .. ' ' .. message
		else
			channelName = 'Append'
		end
	end	
	if (message ~= nil) then
		local chatCommand = chatChannels[channelName]['Command'] .. message
		-- Turbine.Shell.WriteLine('sendToChat: ' .. chatCommand) -- DEBUG
		return chatCommand		
	end
end

-- DEBUG function to find how the game stores non-standard characters typed by someone in chat. It's needed to complete the static table nonbasicCharactersInChat in ChatStatics.luam used to preprocess answers from players
function findCharCodes(input)
	local list = stringSplit(input, ',')
	list[0] = questionAnswer
	dataManagement(list, 'Save', 'Istelien_CharCodes')
end