--[[
    Istelien L (implementation of Istelien quiz engine in LUA with the aim of using it in LOTRO)
	Copyright (C) 2023-2024 Alejandro Meirinhos from Spain.

	This file is part of Istelien L.

	Istelien L is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Istelien L is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Istelien L.  If not, see <https://www.gnu.org/licenses/>.
--]]

-- Register command
mainCommand = Turbine.ShellCommand()

function mainCommand:Execute(cmd, arg)
	if (string.lower(arg) == 'show') then
		mainWindow(true) -- Create main window
		activateWindow(wMainWindow, true)
	else
		if (string.lower(arg) == 'hide') then
			mainWindow(false)
		else
			if (arg ~= nil) then
				mainCommand:GetHelp()
			end
		end
	end
end
function mainCommand:GetHelp()
	Turbine.Shell.WriteLine(replaceCharacters(translate('msgHelpCommand'), nonbasicCharactersInChat) .. '\n' .. replaceCharacters(translate('msgHelpCommandUsers'), nonbasicCharactersInChat))
end
if (Turbine.Shell.AddCommand('istelien', mainCommand) > 0) then
	Turbine.Shell.WriteLine(replaceCharacters(translate('msgMainCommand'), nonbasicCharactersInChat))
end

-- Set new chat command on the specified control.
function remapShortcut(control, command)
	control:SetShortcut(Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, command))
	control.ShortcutData = command
end


function launchCommand(sender, inputString)
	functionList =
	{
		--[[ DEBUG
		['!addplayer'] = 'addPlayer',
		['!playerchangeteam'] = 'playerChangeTeam',
		['!playerleaveteam'] = 'playerLeaveTeam',
		['!reloaddefaults'] = 'reloadDefaultSettings',
		['!reloadsettings'] = 'initPluginData',
		['!savetestsettings'] = 'saveTestSettings',
		['!saveruntimesettings'] = 'saveRuntimeSettings',
		['!addscore'] = 'playerAddPoints',
		['!startgame'] = 'startGame',
		['!questionscores'] = 'printQuestionScoresAll',
		['!updatequestionscores'] = 'updtScoresQuestion',
		['!compare'] = 'stringDistance',
		--]]
		['!help'] = 'commandsHelp',
		['!results'] = 'printResults',
		['!jointeam'] = 'joinTeam',
		['!leaveteam'] = 'leaveTeam',
		['!listteams'] = 'printTeams',
		['!listplayers'] = 'printPlayers'
	}

	local patternToCapture = '^(!%a+)' -- !<command> <argument> Look for a command
	local command = string.lower(string.match(inputString, patternToCapture))
	-- debugLine = sender .. ' Comando:' .. command -- DEBUG
	local patternToCapture = '^!%a+%s+(.+)' -- !<command> <argument> Look for a command
	local argument = string.match(inputString, patternToCapture)
	if (argument ~= nil) then
		-- debugLine = debugLine .. '. Parmetro: ' .. argument -- DEBUG
	end
	-- Turbine.Shell.WriteLine(debugLine)	-- DEBUG
	if (functionList[command]) ~= nil then
		-- Turbine.Shell.WriteLine('Intentar lanzar funcin: ' .. functionList[command]) -- DEBUG
		local returnString = _G['Anglachel']['Istelien'][functionList[command]](sender, argument) -- Call 
		if (returnString ~= nil) then
			remapShortcut(wMainWindow.qsAckCommand, returnString)
			wMainWindow.qsAckCommand:SetEnabled(true)
			wMainWindow.qsAckCommand:SetVisible(true)
			wMainWindow.btnAckCommand:SetEnabled(true)
			wMainWindow.btnAckCommand:SetVisible(true)
		end
	else
		-- Turbine.Shell.WriteLine('Lanzar comando. Comando inexistente') -- DEBUG
	end
end

-- Give command list and info
function commandsHelp(sender, teamName, channelName)
	message = replaceCharacters(translate('msgAvailableCommands'), nonbasicCharactersInChat) .. ':\n'
	message = message .. chatColours['Orange'] .. '!results' .. chatColours['Closure'] .. ': ' .. replaceCharacters(translate('msgResultsInfo'), nonbasicCharactersInChat) .. '.\n'
	message = message .. chatColours['Orange'] .. '!jointeam <TeamName>' .. chatColours['Closure'] .. ': ' .. replaceCharacters(translate('msgJoinTeamInfo'), nonbasicCharactersInChat) .. '.\n'
	message = message .. chatColours['Orange'] .. '!leaveteam' .. chatColours['Closure'] .. ': ' .. replaceCharacters(translate('msgLeaveTeamInfo'), nonbasicCharactersInChat) .. '.\n'
	message = message .. chatColours['Orange'] .. '!listteams' .. chatColours['Closure'] .. ': ' .. replaceCharacters(translate('msgListTeamsInfo'), nonbasicCharactersInChat) .. '.\n'
	message = message .. chatColours['Orange'] .. '!listplayers' .. chatColours['Closure'] .. ': ' .. replaceCharacters(translate('msgListPlayersInfo'), nonbasicCharactersInChat) .. '.\n'
	message = message .. chatColours['Orange'] .. '!listplayers <TeamName>' .. chatColours['Closure'] .. ': ' .. replaceCharacters(translate('msgListPlayersOfTeamInfo'), nonbasicCharactersInChat) .. '.\n'
	return sendToChat(message, channelName, sender, true)
end

-- Join an existing team
function joinTeam(sender, teamName, channelName)
	removePlayerFromTeam(sender)
	local chatCommand = addPlayerToTeam(sender, teamName)
	if (wTeamsManager ~= nil) then
		local memberList = listTeamMembers(selectedPlayer, selectedTeam)
		refreshTMList(memberList, wTeamsManager.membersBoxList)
		local playerList = listParticipants('Players')
		refreshTMList(playerList, wTeamsManager.playersBoxList)
		remapShortcut(wTeamsManager.qsAnnounceMembers, printPlayers(selectedPlayer, selectedTeam, config['GAME']['GameChannel']))
	end
	return chatCommand
end

-- Leave the current team
function leaveTeam(sender, teamName, channelName)
	return removePlayerFromTeam(sender)
end

-- Shows the registered players. If a team name is specified, shows the players of that team.
function printPlayers(sender, teamName, channelName)
	local message = ''
	local playerList = {}
	if (teamName ~= nil) then -- If a team name is specified, as for players of that team
		if (teamName == '') then -- No teams. Say that
			message = replaceCharacters(translate('msgNoTeams'), nonbasicCharactersInChat) .. '.'
		else
			playerList = listTeamMembers(sender, teamName) -- (sender is discarded inside the function if teamName is provided)
			if (#playerList > 0 ) then
				message = replaceCharacters(translate('msgListPlayersInTeam'), nonbasicCharactersInChat) .. ' ' .. chatColours['Orange'] .. teamName .. chatColours['Closure'] ..':'
			else
				message = chatColours['Orange'] .. teamName .. chatColours['Closure'] .. ' ' .. replaceCharacters(translate('msgNoPlayersInTeamRegistered'), nonbasicCharactersInChat) .. '.'
			end
		end
	else -- If no team name is specified, list all players
		playerList = listParticipants('Players')
		if (#playerList > 0 ) then
			message = replaceCharacters(translate('msgListPlayers'), nonbasicCharactersInChat) .. ':'
		else
			message = replaceCharacters(translate('msgNoPlayersRegistered'), nonbasicCharactersInChat) .. ':'		
		end
	end
	message = message .. chatColours['Orange']
	for i,v in ipairs(playerList) do
		message = message .. '\n' .. v
	end
	message = message .. chatColours['Closure']
	-- Send message
	return sendToChat(message, channelName, sender, true)
end

-- Shows the registered teams.
function printTeams(sender, dummy, channelName)
	local teamList = listParticipants('Teams')
	local message = ''
	if (#teamList > 0 ) then
		message = replaceCharacters(translate('msgListTeams'), nonbasicCharactersInChat) .. ':'
	else
		message = replaceCharacters(translate('msgNoTeamsCreated'), nonbasicCharactersInChat) .. '.'
	end
	message = message .. chatColours['Orange']
	for i,v in ipairs(teamList) do
		message = message .. '\n' .. v
	end
	message = message .. chatColours['Closure']
	message = message .. '\n' .. replaceCharacters(translate('msgTeamsCommandsInstructions'), nonbasicCharactersInChat) .. '.'
	if (#teamList == 0 ) then
		message = message .. translate('msgTeamsCommandsInstructions2') .. '.'
	end
	-- Send message
	return sendToChat(message, channelName, sender, true)
end

-- Shows scores of players or teams.
function printAbsoluteScores(sender, participantsType, channelName)
	local message =  strings[clientLanguage]['msg'.. string.sub(participantsType, 1, #participantsType - 1) .. 'Standings'] .. ':'
	local standings = getStandings(participantsType)
	if (standings ~= nil) then
		for i,v in ipairs(standings) do
			for j,w in pairs(v) do
				local pointString = replaceCharacters(translate('msgPoints'), nonbasicCharactersInChat)
				if (tonumber(w) == 1) then
					pointString = replaceCharacters(translate('msgPoint'), nonbasicCharactersInChat)
				end
				message = message .. '\n' .. chatColours['Orange'] .. j .. chatColours['Closure'] .. ': ' .. w .. ' ' .. pointString .. '.'
			end
		end
	else
		message = message .. '\n' .. chatColours['Orange'] .. replaceCharacters(translate('msgNobodyScored'), nonbasicCharactersInChat) .. chatColours['Closure'] .. '.'
	end
	return sendToChat(message, channelName, sender)
end

-- Calls for showing scores of players and teams (if applicable)
function printResults(sender, dummy, channelName)
	local chatCommand = printAbsoluteScores(sender, 'Players', channelName)
	if (config['GAME']['TeamsEnable'] == 1) then
		local secondLine = printAbsoluteScores(sender, 'Teams', 'Append')
		if (secondLine ~= nil) then
			chatCommand = chatCommand .. '\n' .. secondLine
		end
	end
	return chatCommand
end

-- Shows scores of players or teams for a specific question.
function printQuestionScores(sender, questionNumber, channelName, participantsType)
	if (participantsType == nil) then
		participantsType = 'Players'
	end
	questionNumber = tonumber(questionNumber)
	local showScores = true
	local scoreList = listQuestionScores(questionNumber, participantsType)
	local message = ''
	if (scoreList == nil) then
		message = message .. replaceCharacters(translate('msgNobodyScoredThisQuestion'), nonbasicCharactersInChat) .. '.'
		-- Turbine.Shell.WriteLine('Debug message: ' .. message) -- DEBUG
		showScores = false
	end

	if (showScores == true) then
		message = strings[clientLanguage]['msg' .. string.sub(participantsType, 1, #participantsType - 1) .. 'Score'] .. ' ' .. replaceCharacters(translate('msgFor'), nonbasicCharactersInChat) .. ' '  .. chatColours['Orange'] .. replaceCharacters(translate('msgQuestion'), nonbasicCharactersInChat) .. chatColours['Closure'] .. ' #' .. questionNumber .. ':\n'
		for i,v in pairs(scoreList) do
			local pointString = replaceCharacters(translate('msgPoints'), nonbasicCharactersInChat)
			if (tonumber(v) == 1) then
				pointString = replaceCharacters(translate('msgPoint'), nonbasicCharactersInChat)
			end
			--Turbine.Shell.WriteLine('Debug printQuestionSores, scoreList. i: ' .. i .. ' - v: ' .. v) -- DEBUG
			message = message .. chatColours['Orange'] .. v .. chatColours['Closure'] .. ' ' .. pointString .. ' ' .. replaceCharacters(translate('msgFor'), nonbasicCharactersInChat) .. ' ' .. chatColours['Orange'] .. i .. chatColours['Closure'] .. '. '
		end
	end

	if (showScores == true or participantsType == 'Players') then -- To only show the "Nobody scored..." message once
		return sendToChat(message, channelName, sender)
	else
		return ''
	end
end

-- Calls for showing scores of players and teams (if applicable) for a specific question
function printQuestionScoresAll(sender, questionNumber, channelName)
	local chatCommand = printQuestionScores(sender, questionNumber, channelName, 'Players')
	if (config['GAME']['TeamsEnable'] == 1) then
		local secondLine = printQuestionScores(sender, questionNumber, 'Append', 'Teams')
		if (secondLine ~= '') then
			chatCommand = chatCommand .. '\n' .. secondLine
		end
	end		
	return chatCommand
end

--[[ MANAGEMENT FUNCTIONS / DEBUG COMMANDS
function addPlayer(sender, argument)
	if (argument ~= nil) then
		split = stringSplit(argument)
		updatePlayerData(split[1], split[2])
	else
		updatePlayerData(sender)
	end
end
function playerChangeTeam(sender, argument)
	if (argument ~= nil) then
		split = stringSplit(argument)
		joinTeam(split[1], split[2])
	end
end
function playerAddPoints(sender, argument)
	if (argument ~= nil) then
		split = stringSplit(argument)
		addScore(split[1], tonumber(split[2]))
	end
end
function playerLeaveTeam(sender, argument)
	if (argument ~= nil) then
		split = stringSplit(argument)
		leaveTeam(split[1])
	else
		leaveTeam(sender)
	end
end

function updtScoresQuestion(sender, argument)
	updateQuestionScoring(argument, true)
end
function reloadDefaultSettings(sender, argument)
	if config == nil then
		config = defaultSettings['Config']
	end
	if (teams == nil) then
		teams = defaultSettings['Teams']
	end
	gameParticipants = {['Players'] = {},['Teams'] = teams}
end
function saveTestSettings(sender, argument)
	dataManagement(config, 'Save', 'Istelien_test_config')
	dataManagement(gameParticipants, 'Save', 'Istelien_test_participants')
	dataManagement(savegame, 'Save', 'Istelien_test_savegame')
end
function saveRuntimeSettings(sender, argument)
	dataManagement(config, 'Save', 'Istelien_config')
	dataManagement(gameParticipants, 'Save', 'Istelien_participants')
	dataManagement(gameLog, 'Save', 'Istelien_gamelog')
	dataManagement(savegame, 'Save', 'Istelien_savegame')
	dataManagement(gameQuiz, 'Save', 'Istelien_gameQuiz')
end
function stringDistance(sender, argument)
	if (argument ~= nil) then
		split = stringSplit(argument)
		Turbine.Shell.WriteLine('Likeness: ' .. stringProximity(split[1], split[2]))
	end
end
--]]

