--[[
    Istelien L (implementation of Istelien quiz engine in LUA with the aim of using it in LOTRO)
	Copyright (C) 2023-2024 Alejandro Meirinhos from Spain.

	This file is part of Istelien L.
	
	Istelien L is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Istelien L is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Istelien L.  If not, see <https://www.gnu.org/licenses/>.
--]]

defaultSettings = 
{
	['CONFIG'] =
	{
		['GAME'] =
		{
			['SelectedQuiz'] = -- List of quizzes inside Istelien_quizLib.plugindata marking if they're selected for play or not
			{
				[1] = true,
				[2] = false
			},
			['GameChannel'] = 'Kinship', -- Game channel
			['GameMode'] = 1, -- 1=By GameTarget questions - 2=By GameTarget minutes - 3=By GameTarget points (individual) - 4=By GameTarget points (teams)
			['GameTarget'] = 20,
			['QuestionMode'] = 1, -- 1=Semiautomatic - 2=Manual with master scorer
			['QuestionTime'] = 30, -- Seconds per question
			['QuestionHint'] = 20, -- Seconds to throw hint.
			['TeamsEnable'] = 0, -- Enable or disable playing with teams
			['TeamsLock'] = 1, -- Disallow team changes while game is running
			['LogGame'] = 1 -- Save game results to a file.
		},
		['SCORING'] =
		{
			['MultipleHits'] = 1, -- Allow more than one winner per question
			['MultipleHitsTypeSpeed'] = 6, -- Characters per second threshold. This value would be used to calculate how much time a human would take to copy an answer that has been already submitted by someone else and would allow multiple winners that submit their own in less time (so they were already typing and not cheating).
			['MultipleHitsDivisor'] = 1, -- The nominal score of the correct answer will be divided by this number to set the score for the non-fastest winners. If set to 1, the score will be NominalScore/NumberOfWinners. If set to 2, the score will be decreasing for each new winner
			['ScoreMode'] = 1, -- 1=One point per question - 2=One point per word - 3=Custom
			['CustomScores'] =
			{
				-- Scores depending on the number of words the answer has when ScoreMode
				[1] = 1,
				[2] = 1,
				[3] = 1,
				[4] = 2,
				[5] = 2,
				[6] = 2,
				[7] = 3,
				[8] = 3,
				[9] = 3,
				[0] = 5 -- 0 is actually any value not listed otherwise (answers can't have zero words)
			}
		},
		['DIFFICULTY'] =
		{
			['IgnoreCase'] = 1, -- The answer matching system will allow matching lower case against upper case.
			['IndulgentSpelling'] = 1, -- The answer matching system will ignore diacritical marks on vocals and convert some other characters to plain latin characters before comparing.
			['ApproximateAnswers'] = 1, -- Enable fuzzy string matching for answers
			['ProximityValue'] = 90 -- How similar the player answers need to be to the correct answer to be valid, when ApproximateAnswers = 1
		},
		['SPELLING'] =
		{
			-- Replacements to be done to answers when IndulgentSpelling = 1
			[''] = 'A',
			[''] = 'A',
			[''] = 'A',
			[''] = 'A',
			[''] = 'A',
			[''] = 'A',
			[''] = 'AE',
			[''] = 'c',
			[''] = 'E',
			[''] = 'E',
			[''] = 'E',
			[''] = 'E',
			[''] = 'I',
			[''] = 'I',
			[''] = 'I',
			[''] = 'I',
			[''] = 'D',
			[''] = 'N',
			[''] = 'O',
			[''] = 'O',
			[''] = 'O',
			[''] = 'O',
			[''] = 'O',
			[''] = 'x',
			[''] = 'O',
			[''] = 'U',
			[''] = 'U',
			[''] = 'U',
			[''] = 'U',
			[''] = 'Y',
			[''] = 'TH',
			[''] = 'sz',
			[''] = 'a',
			[''] = 'a',
			[''] = 'a',
			[''] = 'a',
			[''] = 'a',
			[''] = 'a',
			[''] = 'ae',
			[''] = 'c',
			[''] = 'e',
			[''] = 'e',
			[''] = 'e',
			[''] = 'e',
			[''] = 'i',
			[''] = 'i',
			[''] = 'i',
			[''] = 'i',
			[''] = 'd',
			[''] = 'n',
			[''] = 'o',
			[''] = 'o',
			[''] = 'o',
			[''] = 'o',
			[''] = 'o',
			[''] = '/',
			[''] = 'o',
			[''] = 'u',
			[''] = 'u',
			[''] = 'u',
			[''] = 'u',
			[''] = 'y',
			[''] = 'th',
			[''] = 'y'
		}
	},
	['PARTICIPANTS'] =
	{	
		['Players'] =
		{
			['Summy'] =
			{
				['Team'] = 'Dummy'
			},
			['Bonnie'] =
			{
				['Team'] = 'Donnie'
			},
			['Ronnie'] =
			{
				['Team'] = 'Donnie'
			}
		},
		['Teams'] =
		{
			['Donnie'] =
			{
				['Members'] =
				{
					['Bonnie'] = 1, -- This is a dummy value. Only the name is needed.
					['Ronnie'] = 1
				}
			},
			['Dummy'] =
			{		
				['Members'] =
				{
					['Summy'] = 1,
					['Yummy'] = 1,
					['Tummy'] = 1
				}
			}
		}
	}
}