--[[
    Istelien L (implementation of Istelien quiz engine in LUA with the aim of using it in LOTRO)
	Copyright (C) 2023-2024 Alejandro Meirinhos from Spain.

	This file is part of Istelien L.

	Istelien L is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Istelien L is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Istelien L.  If not, see <https://www.gnu.org/licenses/>.
--]]

-------------------------------------------------------------------------------------------------------------
--[[


AddCallback() and RemoveCallback functions by Garan


--]]
--------------------------------------------------------------------------------------------------------------


function addCallback(object, event, callback)
    if (object[event] == nil) then
        object[event] = callback;
    else
        if (type(object[event]) == 'table') then
            local exists = false;
            local k,v;
            for k,v in ipairs(object[event]) do
                if v == callback then
                    exists=true;
                    break;
                end
            end
            if not exists then
                table.insert(object[event], callback);
            end
        else
            if object[event] ~= callback then
                object[event] = {object[event], callback};
            end
        end
    end
    return callback;
end

function removeCallback(object, event, callback)
	if (object[event] == callback) then
		object[event] = nil;
	else
		if (type(object[event]) == 'table') then
			local size = table.getn(object[event])
			for i = 1, size do
				if (object[event][i] == callback) then
					table.remove(object[event], i)
					break;
				end
			end
		end
	end
end

-- Remove all working bits
function cleanEventMonitors()
	--removeCallback(Turbine.Chat, 'Received', readChat) -- Stop chat monitoring (if active)

	-- Close all possibly created timers
	questionTimer, questionTimerEvent, questionCountdown = closeTimer(questionTimer, questionTimerEvent, questionCountdown)
	extraTimer, extraTimerEvent, extraCountdown = closeTimer(extraTimer, extraTimerEvent, extraCountdown)
	gameTimer, gameTimerEvent, gameCountdown = closeTimer(gameTimer, gameTimerEvent, gameCountdown)
end