#cs ----------------------------------------------------------------------------

 AutoIt Version: 3.3.14.5
 Author:         Alejandro Meirinhos 

 Version: 1.0 - 2024-01-04

 Script Function:
	Reads the position of Istelien's main window from a configuration file and Then
	monitors the activation of action buttons for automatically clicking on them.
 
 Notice:
	Copyright (C) 2023-2024 Alejandro Meirinhos from Spain.

	This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with This program.  If not, see <https://www.gnu.org/licenses/>.

#ce ----------------------------------------------------------------------------

#include <File.au3>
#include <GUIConstantsEx.au3>
#include <Timers.au3>
#include <WinAPIFiles.au3>

Global $bMonitor[2] = [False,_Timer_Init()]
$sFolder = @SCRIPTDIR
$hexColorRed = 0xD28C3E
$sHotKey = 'F8'
$iShadesRed = 76
$iControlTimestamp = _Timer_Init()
$hexColorBlue = 0x204FDD
$iShadesBlue = 32

$aConfig = IniReadSection(@SCRIPTDIR & '\AutoFlow.ini', 'MAIN')
If @error = 0 Then
	For $i = 1 To $aConfig[0][0]
		Switch $aConfig[$i][0] 
			Case 'Folder'
				$sFolder = $aConfig[$i][1]
			Case 'HotKey'
				$sHotKey = $aConfig[$i][1]
			Case 'ButtonColorRed'
				$hexColorRed = $aConfig[$i][1]
			Case 'ShadesRed'
				$iShadesRed = $aConfig[$i][1]
			Case 'ButtonColorBlue'
				$hexColorRed = $aConfig[$i][1]
			Case 'ShadesBlue'
				$iShadesRed = $aConfig[$i][1]
		EndSwitch
	Next
EndIf
If $sFolder = '' Then
	$sFolder = @SCRIPTDIR
EndIf
If $sHotKey = '' Then
	$sHotKey = 'F8'
EndIf
If $hexColorRed = '' Then
	$hexColorRed = 0xA94B0D
EndIf
If $iShadesRed = '' Then
	$iShadesRed = '64'
EndIf
If $hexColorBlue = '' Then
	$hexColorBlue = 0x204FDD
EndIf
If $iShadesBlue = '' Then
	$iShadesBlue = '32'
EndIf

_GUI()


Func _GUI()

	$iGuiFontSize = 10
	$iGuiSpacing = $iGuiFontSize
	$iGuiControlFontHeight = Ceiling($iGuiFontSize * 2.35)
	$iGuiHeight = $iGuiSpacing + $iGuiControlFontHeight * 9 + $iGuiSpacing + $iGuiControlFontHeight + $iGuiSpacing
	$iGuiWidth = $iGuiControlFontHeight * 20
	$iGuiControlWidth = $iGuiWidth - ($iGuiSpacing * 2)
	$iGuiButtonWidth = ($iGuiControlFontHeight * 5)
	$hGui = GUICreate('AutoFlow', $iGuiWidth, $iGuiHeight)

	$idLabel_Instructions = GUICtrlCreateLabel('1.- Select Istelien''s GUI configuration file. It''s called "Istelien_gui.plugindata" and it''s in your account folder, which by default is Documents\The Lord of the Rings Online\PluginData\<AccountName>\AllServers. You must repeat this step if you move Istelien''s main window in game.' & @CRLF & '2.- Click the Start Game button in game.' & @CRLF & '3.- Use the Monitoring hotkey (' & $sHotKey & ') to toggle AutoFlow On. Unfortunately LOTRO should be out of focus for this work, so you must ALT + TAB first.' & @CRLF & '4.- When the game finishes or you want to stop using this tool, ALT + TAB to come back here and use the Monitoring hotkey (' & $sHotKey & ') again to toggle AutoFlow Off.' & @CRLF & @CRLF & 'USE THIS TOOL AT YOUR OWN RISK AND AVOID ACTIVATION WHEN A GAME IS NOT RUNNING.', $iGuiSpacing, $iGuiSpacing, $iGuiControlWidth, $iGuiControlFontHeight * 9)
		GUICtrlSetFont($idLabel_Instructions, $iGuiFontSize)

	Global $idButton_SelectFile = GUICtrlCreateButton('Read Configuration', ($iGuiWidth / 2) - $iGuiButtonWidth - ($iGuiSpacing / 2), $iGuiSpacing + $iGuiControlFontHeight * 9 + $iGuiSpacing, $iGuiButtonWidth, $iGuiControlFontHeight)
	Global $idButton_Toggle = GUICtrlCreateButton('[' & $sHotKey & '] Monitoring Off', ($iGuiWidth / 2) + ($iGuiSpacing / 2), $iGuiSpacing + $iGuiControlFontHeight * 9 + $iGuiSpacing, $iGuiButtonWidth, $iGuiControlFontHeight)
	GUICtrlSetState($idButton_Toggle, $GUI_DISABLE)

	GUISetState(@SW_SHOW, $hGui)
	$bExitGui = False
	While $bExitGui = False
		$idEvent = GUIGetMsg(1)
		Select
			Case $idEvent[0] = $GUI_EVENT_CLOSE
				$bExitGui = True
			Case $idEvent[0] = $idButton_SelectFile
				$sReadFile = _SelectFile()
				If $sReadFile <> '' Then		
					$iCoordsFound = 0
					$aCoordFile = FileReadToArray($sReadFile)
					If @error Then
						MsgBox(16, 'Error', 'There was an error reading the file.')
						$iCoordsFound = -1
					Else
						$iPos = 0
						$sStringToParse = ''
						For $i = 0 To UBound($aCoordFile) - 1
							If $iPos = 0 Then
								$iPos = StringInStr($aCoordFile[$i], '["MainWindow"]', 1)
								If ($iPos <> 0) Then
									$sStringToParse = $sStringToParse & $aCoordFile[$i]
								EndIf
							Else
								$sStringToParse = $sStringToParse & $aCoordFile[$i]
								If StringInStr($aCoordFile[$i], '}', 1) <> 0 Then
									$i = UBound($aCoordFile)
								EndIf
							EndIf
						Next
						$aMatchX = StringRegExp($sStringToParse, '\["posX"\]\s*=\s*(\d+)', 1)
						$iCoordsFound = $iCoordsFound + @error
						$aMatchY = StringRegExp($sStringToParse, '\["posY"\]\s*=\s*(\d+)', 1)
						$iCoordsFound = $iCoordsFound + @error
					EndIf

					If $iCoordsFound = 0 Then
						_SetPositions($aMatchX[0], $aMatchY[0])

						GUICtrlSetState($idButton_Toggle, $GUI_ENABLE)
						HotKeySet('{' & $sHotKey & '}', '_HotKeyPressed')
						HotKeySet('{ESC}', '_HotKeyPressed')
					Else
						MsgBox(16, 'Error', 'Could not find the window position information in the specified file.')
					EndIf
				EndIf
			Case $idEvent[0] = $idButton_Toggle
				If (_Timer_Diff($bMonitor[1]) >= 2000) Then ; This prevents buffered button clicks to start monitor right away after you stop it with the hotkey
					_ToggleMonitor()
				EndIf
		EndSelect
	Wend

	GUIDelete($hGui)
EndFunc


Func _SelectFile()
	$bReadFile = True

	$sReadFile = FileOpenDialog('Select the GUI configuration file', $sFolder, 'Istelien GUI configuration (Istelien_gui.plugindata)|See al files (*.*)', BitOR(1, 2))
	If @error <> 0 Then
		$bReadFile = False
		Msgbox(16, 'Error','Error selecting the file to read.', 30)
	EndIf

	If $bReadFile = True Then
		$sFileNamePos = StringInStr($sReadFile, '\', 0, -1)
		IniWriteSection(@SCRIPTDIR & '\AutoFlow.ini', 'MAIN', 'Folder = ' & StringLeft($sFolder, $sFileNamePos - 1))
		Return $sReadFile
	Else
		Return ''
	EndIf
Endfunc

Func _SetPositions($posX, $posY)

	$iBaseX = $posX
	$iBaseY = $posY
	$iButtonWidth = 150
	$iButtonHeight = 20

	Global $iControlButtonX = $iBaseX + 150
	Global $iControlButtonY = $iBaseY + 200
	Global $iAckCommandX = $iBaseX + 65
	Global $iAckCommandY = $iBaseY + 640
	Global $iAckCommandClickX = $iAckCommandX + $iButtonWidth / 2
	Global $iAckCommandClickY = $iAckCommandY + $iButtonHeight / 2
	Global $iProvideHintX = $iBaseX + 235
	Global $iProvideHintY = $iBaseY + 660
	Global $iProvideHintClickX = $iProvideHintX + $iButtonWidth / 2
	Global $iProvideHintClickY = $iProvideHintY + $iButtonHeight / 2
	Global $iStepAheadX = $iBaseX + 235
	Global $iStepAheadY = $iBaseY + 680
	Global $iStepAheadClickX = $iStepAheadX + $iButtonWidth / 2
	Global $iStepAheadClickY = $iStepAheadY + $iButtonHeight / 2
Endfunc

Func _ToggleMonitor()
	If $bMonitor[0] = False Then
		$bMonitor[0] = True
		GUICtrlSetData($idButton_Toggle, '[' & $sHotKey & '] Monitoring On')
		GUICtrlSetState($idButton_SelectFile, $GUI_DISABLE)
	Else
		$bMonitor[0] = False
		$bMonitor[1] = _Timer_Init()
		GUICtrlSetData($idButton_Toggle, '[' & $sHotKey & '] Monitoring Off')
		GUICtrlSetState($idButton_SelectFile, $GUI_ENABLE)
	EndIf

	If $bMonitor[0] = True Then
		$bHintSent = False
		$iStepAheadTimestamp = _Timer_Init()
		$iHintTimestamp = _Timer_Init()
		$iAckCommandTimestamp = _Timer_Init()
		While $bMonitor[0] = True
			; See that the Quiz Library button is off, what means the game is started
			If _CheckButton($iControlButtonX, $iControlButtonY, $iControlTimestamp, 0, $hexColorBlue, $iShadesBlue) = False Then
				; Wrap question or Ask question
				If _CheckButton($iStepAheadX, $iStepAheadY, $iStepAheadTimestamp, 1000, $hexColorRed, $iShadesRed) = True Then
					MouseClick('left', $iStepAheadClickX, $iStepAheadClickY, 1, 0)
					$iStepAheadTimestamp = _Timer_Init()
					Sleep(500)
					$bHintSent = False
				EndIf
				; Provide Hint
				If _CheckButton($iProvideHintX, $iProvideHintY, $iHintTimestamp, 1000, $hexColorRed, $iShadesRed) = True And $bHintSent = False Then
					MouseClick('left', $iProvideHintClickX, $iProvideHintClickY, 1, 0)
					$iHintTimestamp = _Timer_Init()
					$bHintSent = True
					Sleep(500)
				EndIf
				; Acknowledge command
				If _CheckButton($iAckCommandX, $iAckCommandY, $iAckCommandTimestamp, 1000, $hexColorRed, $iShadesRed) = True Then
					MouseClick('left', $iAckCommandClickX, $iAckCommandClickY, 1, 0)
					$iAckCommandTimestamp = _Timer_Init()
					Sleep(250)
				EndIf
			EndIf
		Wend
	EndIf
Endfunc

Func _HotKeyPressed()
    Switch @HotKeyPressed
        Case '{' & $sHotKey & '}'
				_ToggleMonitor()
        Case "{ESC}"
            Exit
    EndSwitch
EndFunc


Func _CheckButton($iButtonX, $iButtonY, $iPrevTimestamp, $iSeconds, $hexColor, $iShades)
	$bClickAllowed = False
	If (_Timer_Diff($iPrevTimestamp) >= $iSeconds) Then
		$aCoords = PixelSearch($iButtonX + 9, $iButtonY + 4, $iButtonX + 14, $iButtonY + 9, $hexColor, $iShades)
		If Not @error Then
			$bClickAllowed = True
		EndIf
	EndIf

	Return $bClickAllowed
Endfunc

; Exit program
Func _Terminate()
    Exit
EndFunc