#cs ----------------------------------------------------------------------------

 AutoIt Version: 3.3.14.5
 Author:         Alejandro Meirinhos 
 
 Version: 1.0 - 2024-01-05

 Script Function:
	Converts a questions file formated for LOTRivia into a LOTRO Plugin
	saved data file.
 
 Notice:
	Copyright (C) 2023-2024 Alejandro Meirinhos from Spain.

	This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with This program.  If not, see <https://www.gnu.org/licenses/>.
--]]

#ce ----------------------------------------------------------------------------
#include <Array.au3>
#include <File.au3>
#include <GUIConstantsEx.au3>

$bImportFile = True ; Switch for performing the final task of the program

$sImportFile = FileOpenDialog('Select a questions file to convert', @SCRIPTDIR, 'Lua file (*.lua)|See al files (*.*)', BitOR(1, 2))
If @error <> 0 Then
	$bImportFile = False
	Msgbox(16, 'Error','Error selecting the file to import.', 30)
Else	
	$aImportFile = FileReadToArray($sImportFile)
	If @error <> 0 Then
		$iErrorCode = @error
		Local $aReadError[3] = [2,'File selection failed.','Bad file filter.']
		Msgbox(16, 'File error',$aReadError[$iErrorCode], 30)
		$bImportFile = False
	EndIf
EndIf

; Discard unnecessary lines and have them sorted
If $bImportFile = True Then

	; Definition of target array: (0) = Question,(1) = Answer, (2) = Commentary
	
	Local $aParsedQuestions[1][2] = [[0,'']]
	Local $aParsedAnswers[1][2] = [[0,'']]
	Local $aParsedComments[1][2] = [[0,'']]
	For $i = 0 To UBound($aImportFile) - 1
		$aMatch = StringRegExp($aImportFile[$i], '^\t* *\t* *(LT_Question|LT_Answer|LT_QuestionCommentary)\[([0-9]+)\]\t* *\t* *=\t* *\t* *"(.*)"', 1)
		If IsArray($aMatch) = True Then
			If $aMatch[0] = 'LT_Question' Then
				$aParsedQuestions[0][0] = _ArrayAdd($aParsedQuestions, Int($aMatch[1]), 0, @CRLF)
				$aParsedQuestions[$aParsedQuestions[0][0]][0] = Int($aMatch[1])
				$aParsedQuestions[$aParsedQuestions[0][0]][1] = $aMatch[2]
			Else
				If $aMatch[0] = 'LT_Answer' Then
					$aParsedAnswers[0][0] = _ArrayAdd($aParsedAnswers, Int($aMatch[1]), 0, @CRLF)
					$aParsedAnswers[$aParsedAnswers[0][0]][0] = Int($aMatch[1])
					$aParsedAnswers[$aParsedAnswers[0][0]][1] = $aMatch[2]
				Else
					$aParsedComments[0][0] = _ArrayAdd($aParsedComments, Int($aMatch[1]), 0, @CRLF)
					$aParsedComments[$aParsedComments[0][0]][0] = Int($aMatch[1])
					$aParsedComments[$aParsedComments[0][0]][1] = $aMatch[2]
				EndIf
			EndIf
		EndIf
	Next

	
	$bSortQ = _ArraySort($aParsedQuestions, 0, 1)
	$bSortA = _ArraySort($aParsedAnswers, 0, 1)
	$bSortC = _ArraySort($aParsedComments, 0, 1)
	If $bSortQ * $bSortA * $bSortC = 0 Then
		$bImportFile = False
	EndIf
EndIf

If $bImportFile = False Then
		Msgbox(16, 'Failure','There was an error parsing the input file.', 30)	
Else	
	; Create proper arrays to use them later for the export
	Local $aQuestionArray[($aParsedQuestions[$aParsedQuestions[0][0]][0]) + 1]
	Local $aAnswerArray[($aParsedAnswers[$aParsedAnswers[0][0]][0]) + 1]
	Local $aCommentArray[($aParsedComments[$aParsedComments[0][0]][0]) + 1]
	Local $aExportData[($aParsedComments[$aParsedComments[0][0]][0]) + 1][3]
	Local $aFieldNames[3] = ['Question','Answer','QuestionCommentary']
	$aExportData[0][0] = 'Question'
	$aExportData[0][1] = 'Answer'
	$aExportData[0][2] = 'QuestionCommentary'
	
	; Fill the new arrays with the data previously parsed
	For $i = 1 To $aParsedQuestions[0][0]
		
		;Msgbox(16, $i,$aParsedQuestions[$i][0] & ' - ' & $aParsedQuestions[$i][1], 30)	
		$aQuestionArray[$aParsedQuestions[$i][0]] = $aParsedQuestions[$i][1]
		$aExportData[$aParsedQuestions[$i][0]][0] = $aParsedQuestions[$i][1]
	Next
	For $i = 1 To $aParsedAnswers[0][0]
		$aAnswerArray[$aParsedAnswers[$i][0]] = $aParsedAnswers[$i][1]
		$aExportData[$aParsedAnswers[$i][0]][1] = $aParsedAnswers[$i][1]
	Next
	For $i = 1 To $aParsedComments[0][0]
		$aCommentArray[$aParsedComments[$i][0]] = $aParsedComments[$i][1]
		$aExportData[$aParsedComments[$i][0]][2] = $aParsedComments[$i][1]
	Next

	_ArrayDisplay($aExportData, 'Preview of the quiz contents', '1:', 0, Default, 'Question|Answer|QuestionCommentary')	
	
EndIf

If $bImportFile = True Then
	$aPackageInfo = inputInfo()
	; Create file from the imported data
	Local $aExportFile[14] = ['return','{', @TAB & '[1] =', @TAB & '{', @TAB & @TAB & '["Info"] =', @TAB & @TAB & '{', @TAB & @TAB & @TAB & '["PackageName"] = "' & $aPackageInfo[1] & '",', @TAB & @TAB & @TAB & '["PackageCategory"] = "' & $aPackageInfo[2] & '",', @TAB & @TAB & @TAB & '["PackageAuthor"] = "' & $aPackageInfo[3] & '",', @TAB & @TAB & @TAB & '["PackageVersion"] = "' & $aPackageInfo[4] & '",', @TAB & @TAB & @TAB & '["PackageDate"] = "' & $aPackageInfo[5] & '"', @TAB & @TAB & '},', @TAB & @TAB & '["Content"] =', @TAB & @TAB & '{']
	$iLineCounter = UBound($aExportFile)
	$iNumFields = UBound($aFieldNames) - 1
	For $i = 1 To Ubound($aExportData) - 1
		$iLineCounter = _ArrayAdd($aExportFile, @TAB & @TAB & @TAB & '[' & $i & '] =')
		$iLineCounter = _ArrayAdd($aExportFile, @TAB & @TAB & @TAB & '{')
		For $j = 0 To $iNumFields
			$iLineCounter = _ArrayAdd($aExportFile, @TAB & @TAB & @TAB & @TAB & '["' & $aFieldNames[$j] & '"] = "' & StringReplace(StringReplace(StringReplace($aExportData[$i][$j], '\', '\\'), '"', '\"'), '''','\''') & '",', 0, '|', @CRLF, 1)
		Next
		$iLineCounter = _ArrayAdd($aExportFile, @TAB & @TAB & @TAB & '},')
	Next
	$iLineCounter = _ArrayAdd($aExportFile, @TAB & @TAB & '}')
	$iLineCounter = _ArrayAdd($aExportFile, @TAB & '},')
	$iLineCounter = _ArrayAdd($aExportFile, '}')
	;_ArrayDisplay($aExportFile)
	$sExportFile = FileSaveDialog('Save the converted file', @SCRIPTDIR, 'LOTRO Plugin Datafaile (*.plugindata)', BitOR(2, 16), 'MyQuiz.plugindata')
	If @error <> 0 Then
		Msgbox(16, 'Error','Error setting destination file.', 30)
	Else
		$hExportFile = FileOpen($sExportFile, 514) ; This forces to encode it in ANSI
		$bReturn = 1
		$bReturn = $bReturn * _FileWriteFromArray($hExportFile, $aExportFile, Default, Default, @CRLF)
		$bReturn = $bReturn * FileClose($hExportFile)
		#cs ; Alternative to the previous four lines to encode it in UTF-8 by default. Currently I think the file needs to be encoded in ANSI for LOTRO to properly read non-English characters without black magic and make the user's life difficult
		$bReturn = _FileWriteFromArray($sExportFile, $aExportFile, Default, Default, @CRLF)
		#ce
		If $bReturn = 1 Then
			Msgbox(64, 'Success','The quiz file has been created.', 30)
		Else
			Msgbox(16, 'Failure','There was an error exporting the quiz file.', 30)			
		EndIf
	EndIf
EndIf

Func inputInfo()
	$iGuiFontSize = 10
	$iGuiSpacing = $iGuiFontSize
	$iGuiControlFontHeight = Ceiling($iGuiFontSize * 2.35)
	$iGuiHeight = $iGuiSpacing + $iGuiControlFontHeight * 2 + $iGuiSpacing + $iGuiControlFontHeight * 2 + $iGuiSpacing + $iGuiControlFontHeight * 2 + $iGuiSpacing + $iGuiControlFontHeight * 2 + $iGuiSpacing + $iGuiControlFontHeight + $iGuiSpacing
	$iGuiWidth = $iGuiControlFontHeight * 15
	$iGuiControlWidth = $iGuiWidth - ($iGuiSpacing * 2)
	$iGuiButtonWidth = ($iGuiControlFontHeight * 5)
	$hGui = GUICreate('Package Information', $iGuiWidth, $iGuiHeight)
	
	$idLabel_PackageName = GUICtrlCreateLabel('Please enter a title or a general topic for this package: ', $iGuiSpacing, $iGuiSpacing, $iGuiControlWidth, $iGuiControlFontHeight)
		GUICtrlSetFont($idLabel_PackageName, $iGuiFontSize)
    $idInput_PackageName = GUICtrlCreateInput('', $iGuiSpacing, $iGuiSpacing + $iGuiControlFontHeight, $iGuiControlWidth, $iGuiControlFontHeight)
		GUICtrlSetFont($idInput_PackageName, $iGuiFontSize)
		GUICtrlSetData($idInput_PackageName, 'Quiz converted from LOTRivia')
	
	$idLabel_PackageCategory = GUICtrlCreateLabel('Enter an optional subtitle or category for this package: ', $iGuiSpacing, $iGuiSpacing + $iGuiControlFontHeight * 2 + $iGuiSpacing, $iGuiControlWidth, $iGuiControlFontHeight)
		GUICtrlSetFont($idLabel_PackageCategory, $iGuiFontSize)
    $idInput_PackageCategory = GUICtrlCreateInput('', $iGuiSpacing, $iGuiSpacing + $iGuiControlFontHeight * 2 + $iGuiSpacing + $iGuiControlFontHeight, $iGuiControlWidth, $iGuiControlFontHeight)	
		GUICtrlSetFont($idInput_PackageCategory, $iGuiFontSize)
	
	$idLabel_PackageAuthor = GUICtrlCreateLabel('Please introduce the author of this package: ', $iGuiSpacing, $iGuiSpacing + $iGuiControlFontHeight * 4 + $iGuiSpacing + $iGuiSpacing, $iGuiControlWidth, $iGuiControlFontHeight)
		GUICtrlSetFont($idLabel_PackageAuthor, $iGuiFontSize)
    $idInput_PackageAuthor = GUICtrlCreateInput('', $iGuiSpacing, $iGuiSpacing + $iGuiControlFontHeight * 4 + $iGuiSpacing + $iGuiSpacing + $iGuiControlFontHeight, $iGuiControlWidth, $iGuiControlFontHeight)	
		GUICtrlSetFont($idInput_PackageAuthor, $iGuiFontSize)
		GUICtrlSetData($idInput_PackageAuthor, 'Automatically converted for Istelien L')
	$idLabel_PackageVersion = GUICtrlCreateLabel('Package Version: ', $iGuiSpacing, $iGuiSpacing + $iGuiControlFontHeight * 6 + $iGuiSpacing * 3, $iGuiWidth / 2 - $iGuiSpacing * 2, $iGuiControlFontHeight)
		GUICtrlSetFont($idLabel_PackageVersion, $iGuiFontSize)
    $idInput_PackageVersion = GUICtrlCreateInput('', $iGuiSpacing, $iGuiSpacing + $iGuiControlFontHeight * 7 + $iGuiSpacing * 3, $iGuiWidth / 2 - $iGuiSpacing * 2, $iGuiControlFontHeight)	
		GUICtrlSetFont($idInput_PackageVersion, $iGuiFontSize)
		GUICtrlSetData($idInput_PackageVersion, '1.0')
	
	$idLabel_PackageDate = GUICtrlCreateLabel('Package Date: ', $iGuiWidth / 2, $iGuiSpacing + $iGuiControlFontHeight * 6 + $iGuiSpacing * 3, $iGuiWidth / 2 - $iGuiSpacing, $iGuiControlFontHeight)
		GUICtrlSetFont($idLabel_PackageDate, $iGuiFontSize)
    $idInput_PackageDate = GUICtrlCreateInput('', $iGuiWidth / 2, $iGuiSpacing + $iGuiControlFontHeight * 7 + $iGuiSpacing * 3, $iGuiWidth / 2 - $iGuiSpacing, $iGuiControlFontHeight)	
		GUICtrlSetFont($idInput_PackageDate, $iGuiFontSize)
		GUICtrlSetData($idInput_PackageDate, @YEAR & '-' & @MON & '-' & @MDAY)
	
	$idButton_Continue = GUICtrlCreateButton('Continue', ($iGuiWidth / 2) - $iGuiButtonWidth - ($iGuiSpacing / 2), $iGuiSpacing + $iGuiControlFontHeight * 8 + $iGuiSpacing * 4, $iGuiButtonWidth, $iGuiControlFontHeight)
	$idButton_Cancel = GUICtrlCreateButton('Cancel', ($iGuiWidth / 2) + ($iGuiSpacing / 2), $iGuiSpacing + $iGuiControlFontHeight * 8 + $iGuiSpacing * 4, $iGuiButtonWidth, $iGuiControlFontHeight)
	
	GUISetState(@SW_SHOW, $hGui)
	$bExitGui = False
	Local $aUserInput[1] = [0]
	While $bExitGui = False
		$idEvent = GUIGetMsg(1)
		Select
			Case $idEvent[0] = $GUI_EVENT_CLOSE
				Exit
			Case $idEvent[0] = $idButton_Continue
				$aUserInput[0] = _ArrayAdd($aUserInput, GUICtrlRead($idInput_PackageName))
				$aUserInput[0] = _ArrayAdd($aUserInput, GUICtrlRead($idInput_PackageCategory))
				$aUserInput[0] = _ArrayAdd($aUserInput, GUICtrlRead($idInput_PackageAuthor))
				$aUserInput[0] = _ArrayAdd($aUserInput, GUICtrlRead($idInput_PackageVersion))
				$aUserInput[0] = _ArrayAdd($aUserInput, GUICtrlRead($idInput_PackageDate))
				$bExitGui = True				
			Case $idEvent[0] = $idButton_Cancel
				Exit
		EndSelect
	Wend
	
	GUIDelete($hGui)
	
	Return $aUserInput

EndFunc