--[[
    Istelien L (implementation of Istelien quiz engine in LUA with the aim of using it in LOTRO)
	Copyright (C) 2023-2024 Alejandro Meirinhos from Spain.

	This file is part of Istelien L.
	
	Istelien L is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Istelien L is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Istelien L.  If not, see <https://www.gnu.org/licenses/>.
--]]

-- The following sets of replacements are needed in different parts of LOTRO to show non-English characters properly. Both sets are clearly related so it all comes from some mistreating of these characters inside LOTRO.
-- This is for turning strange characters resulting from someone chatting into the good ones inside the plugin
nonbasicCharactersInChat =
{
	['À'] = '',
	['Á'] = '',
	['Â'] = '',
	['Ã'] = '',
	['Ä'] = '',
	['Å'] = '',
	['Æ'] = '',
	['Ç'] = '',
	['È'] = '',
	['É'] = '',
	['Ê'] = '',
	['Ë'] = '',
	['Ì'] = '',
	['Í'] = '',
	['Î'] = '',
	['Ï'] = '',
	['Ð'] = '',
	['Ñ'] = '',
	['Ò'] = '',
	['Ó'] = '',
	['Ô'] = '',
	['Õ'] = '',
	['Ö'] = '',
	['×'] = '',
	['Ø'] = '',
	['Ù'] = '',
	['Ú'] = '',
	['Û'] = '',
	['Ü'] = '',
	['Ý'] = '',
	['Þ'] = '',
	['ß'] = '',
	['à'] = '',
	['á'] = '',
	['â'] = '',
	['ã'] = '',
	['ä'] = '',
	['å'] = '',
	['æ'] = '',
	['ç'] = '',
	['è'] = '',
	['é'] = '',
	['ê'] = '',
	['ë'] = '',
	['ì'] = '',
	['í'] = '',
	['î'] = '',
	['ï'] = '',
	['ð'] = '',
	['ñ'] = '',
	['ò'] = '',
	['ó'] = '',
	['ô'] = '',
	['õ'] = '',
	['ö'] = '',
	['÷'] = '',
	['ø'] = '',
	['ù'] = '',
	['ú'] = '',
	['û'] = '',
	['ü'] = '',
	['ý'] = '',
	['þ'] = '',
	['ÿ'] = ''
}

-- This is for turning good non-English character into the strange composite strings that LOTRO's GUI can show as normal good characters.
nonbasicCharactersForGui =
{
	[''] = 'À',
	[''] = 'Á',
	[''] = 'Â',
	--[''] = 'Ã', -- This one, which place in the order is here, can't be done because LUA tables haven't really have an order, and if this one is not done first, it will screw previous replacements that have  as part of its result.
	[''] = 'Ä',
	[''] = 'Å',
	[''] = 'Æ',
	[''] = 'Ç',
	[''] = 'È',
	[''] = 'É',
	[''] = 'Ê',
	[''] = 'Ë',
	[''] = 'Ì',
	[''] = 'Í',
	[''] = 'Î',
	[''] = 'Ï',
	[''] = 'Ð',
	[''] = 'Ñ',
	[''] = 'Ò',
	[''] = 'Ó',
	[''] = 'Ô',
	[''] = 'Õ',
	[''] = 'Ö',
	[''] = '×',
	[''] = 'Ø',
	[''] = 'Ù',
	[''] = 'Ú',
	[''] = 'Û',
	[''] = 'Ü',
	[''] = 'Ý',
	[''] = 'Þ',
	[''] = 'ß',
	[''] = 'à',
	[''] = 'á',
	[''] = 'â',
	[''] = 'ã',
	[''] = 'ä',
	[''] = 'å',
	[''] = 'æ',
	[''] = 'ç',
	[''] = 'è',
	[''] = 'é',
	[''] = 'ê',
	[''] = 'ë',
	[''] = 'ì',
	[''] = 'í',
	[''] = 'î',
	[''] = 'ï',
	[''] = 'ð',
	[''] = 'ñ',
	[''] = 'ò',
	[''] = 'ó',
	[''] = 'ô',
	[''] = 'õ',
	[''] = 'ö',
	[''] = '÷',
	[''] = 'ø',
	[''] = 'ù',
	[''] = 'ú',
	[''] = 'û',
	[''] = 'ü',
	[''] = 'ý',
	[''] = 'þ',
	[''] = 'ÿ'
}
-- This replacement should be done right before nonbasicCharactersForGui for replacements to be complete, and never after or in the middle to be correct.
nonbasicCharactersForGuiPrev =
{
	[''] = 'Ã'
}


languages =
{
	[0] = 'English', -- 0 is "Invalid", so we set it to English by default
	[2] = 'English',
	[268435457] = 'EnglishGB' ,
	[268435459] = 'French',
	[268435460] = 'German', 		
	[268435463] = 'Russian'	
}

strings = 
{
	['English'] = 
	{
		-- GUI strings
		['txtFellowshipChannelName'] = 'Fellowship',
		['txtKinshipChannelName'] = 'Kinship',
		['txtOfficerChannelName'] = 'Officer',
		['txtOOCChannelName'] = 'OOC',
		['txtRaidChannelName'] = 'Raid',
		['txtRegionalChannelName'] = 'Regional',
		['txtTellChannelName'] = 'Tell',
		['txtUserChat1ChannelName'] = 'User Chat 1',
		['txtUserChat2ChannelName'] = 'User Chat 2',
		['txtUserChat3ChannelName'] = 'User Chat 3',
		['txtUserChat4ChannelName'] = 'User Chat 4',
		['txtUserChat5ChannelName'] = 'User Chat 5',
		['txtUserChat6ChannelName'] = 'User Chat 6',
		['txtUserChat7ChannelName'] = 'User Chat 7',
		['txtUserChat8ChannelName'] = 'User Chat 8',
		['txtWorldChannelName'] = 'World',
		['txtGenSettings'] = 'General Settings',
		['txtChannel'] = 'Play in channel',
		['txtGameMode'] = 'Game goal',
		['txtGameMode1'] = 'Number of Questions',
		['txtGameMode2'] = 'Elapsed Time',
		['txtGameMode3'] = 'Player Points',
		['txtGameMode4'] = 'Team Points',
		['txtGameTarget'] = 'Target',
		['txtQuestion'] = 'question',
		['txtQuestions'] = 'questions',
		['txtMinute'] = 'minute',
		['txtMinutes'] = 'minutes',
		['txtPoint'] = 'point',
		['txtPoints'] = 'points',
		['txtSecond'] = 'second',
		['txtSeconds'] = 'seconds',
		['txtQuestionMode'] = 'Answer validation',
		['txtQuestionMode1'] = 'Semiautomatic',
		['txtQuestionMode2'] = 'Manual',
		['txtQuestionTime'] = 'Time per question',
		['txtQuestionHint'] = 'Hint at',
		['txtLogGame'] = 'Log game',
		['txtSelectQuiz'] = 'Select Quiz',
		['txtTeamSettings'] = 'Team Settings',
		['txtTeamsEnable'] = 'Enable Team play',
		['txtTeamsLock'] = 'Lock teams',
		['txtManageTeams'] = 'Manage Teams',
		['txtDifficulty'] = 'Difficulty Settings',
		['txtIgnoreCase'] = 'Ignore case',
		['txtIndulgentSpelling'] = 'Indulgent spelling',
		['txtApproximateAnswers'] = 'Approximate answers',
		['txtPercentAccuracy'] = '% accuracy',
		['txtScoring'] = 'Scoring Settings',
		['txtScoreMode'] = 'Question points',
		['txtScoreMode1'] = 'Fixed',
		['txtScoreMode2'] = 'Incremental',
		['txtScoreMode3'] = 'Custom',
		['txtCustomScores'] = 'Customize',
		['txtMultipleHits'] = 'Reward simultaneous answers',
		['txtMultipleHitsTypeSpeed'] = 'Speed threshold',
		['txtMultipleHitsTypeSpeedAdj'] = 'chars/sec',
		['txtMultipleHitsDivisor'] = 'Runner-up points',
		['txtMultipleHitsDivisor1'] = 'Fixed',
		['txtMultipleHitsDivisor2'] = 'Decreasing',
		['txtGameControls'] = 'Game Controls',
		['txtStartGame'] = 'Start Game',
		['txtPauseGame'] = 'Pause Game',
		['txtResumeGame'] = 'Resume Game',
		['txtResumeFromSave'] = 'Resume Game',
		['txtEndGame'] = 'End Game',
		['txtLoadGame'] = 'Load Game',
		['txtSaveGame'] = 'Save Game',
		['txtFlowInstructions'] = 'Use the following buttons to control game flow and react to player inputs and configured settings.\nIn semiautomatic mode you want to react as quick as possible for the best game experience.',
		['txtFinishQuestion'] = 'Finish Question',
		['txtProvideHint'] = 'Provide Hint',
		['txtAckCommand'] = 'Ack Command',
		['txtPointGift'] = 'Point Gift',
		['txtPlayers'] = 'Players',
		['txtTeams'] = 'Teams',
		['txtAnnounceScores'] = 'Announce Scores',
		['txtEndQuestion'] = 'End Question',
		['txtWrapQuestion'] = 'Wrap Question',
		['txtAskQuestion'] = 'Ask Question',
		['txtMasterScorer'] = 'Master Scorer',
		['txtMasterScorerInfo'] = 'Set the number of points each participant should earn for this question.\nBy default, suggested values according to game settings are shown',
		['txtCorrectAnswer'] = 'The answer was',
		['txtSetPoints'] = 'Set Points',
		['txtPointTo'] = 'point to',
		['txtPointsTo'] = 'points to',
		['txtAccept'] = 'Accept',
		['txtCancel'] = 'Cancel',
		['txtStandings'] = 'Standings',
		['txtPlayerStandings'] = 'Player Standings',
		['txtTeamStandings'] = 'Team Standings',
		['txtNobodyScored'] = 'Nobody scored',
		['txtPublishResults'] = 'Publish',
		['txtAccept'] = 'Accept',
		['txtCancel'] = 'Cancel',
		['txtClearSelection'] = 'Clear Selection',
		['txtQuizLibrary'] = 'Quiz Library',
		['txtQuizLibraryInfo'] = 'Select the packages for your next game.\nClear selection to use the built-in package.',
		['txtPackageList'] = 'Package List',
		['txtUnnamedPackage'] = 'Unnamed Package',
		['txtBy'] = 'by',
		['txtUnnamedPackage'] = 'an unknown author',
		['msgCouldNotLoadAnyPackage'] = 'Could not load the configured quiz selection. Using the first on the list',
		['msgCouldNotLoadSomePackage'] = 'Could not load all the packages in configured quiz selection. Loaded the rest',
		['txtCustomizeScores'] = 'Ed. Scoring',
		['txtCustomizeScoresInfo'] = 'Use the controls below to assign scores depending on answer length',
		['txtMore'] = 'More',
		['txtWord'] = 'word',
		['txtWords'] = 'words',
		['txtAddLine'] = '+',
		['txtRemoveLine'] = '-',
		['txtTeamsManager'] = 'Teams Manager',
		['txtAvailableTeams'] = 'Available Teams',
		['txtTeamMembers'] = 'Team Members',
		['txtRegisteredPlayers'] = 'Registered Players',
		['txtAnnounceMembers'] = 'Announce Members',
		['txtAddMember'] = '<',
		['txtDeleteMember'] = '>',
		['txtAddTeam'] = '+',
		['txtDeleteTeam'] = '-',
		['txtAddPlayer'] = '+',
		['txtDeletePlayer'] = '-',
		['txtTeamsManagerInfo'] = 'Players need to be registered to join a team. Empty teams will be cleared at the beginning of the game. Lone players too until they use the chat again during gameplay. If teams are not locked, players can type "!jointeam <TeamName>" to request joining an existing or new team. You can acknowledge the command or use this window again',
		['txtAnnounceTeams'] = 'Announce Teams',
		['txtClose'] = 'Close',
		['txtName'] = 'Name',
		['txtAdd'] = 'Add',
		['txtSavegames'] = 'Saved Games',
		['txtSavegameList'] = 'List of Saved Games',
		['txtEmptySlot'] = 'Empty slot',
		['txtLoadDefaults'] = 'Load Defaults',
		['txtDeleteSelected'] = 'Delete Game',
		['txtDeletedSelectedOK'] = 'Deleted game at slot',
		['txtDeletedSelectedFail'] = 'Could not delete game at slot',
		['txtLoadGameOK'] = 'Loaded game from slot',
		['txtLoadGameFail'] = 'Could not load game from slot',
		['txtSave'] = 'Save',
		['txtSaveGameOK'] = 'Saved game to slot',
		['txtSaveGameFail'] = 'Could not save game to slot',
		['txtHelpText'] = [[Welcome to Istelien.

Two important points it's good you are aware of. Any other smaller options would be covered by the online or included documentation.

First: you can start playing right away with the included quiz library. However, you can add new quiz packages of any topic. To help you with that, there are two tools included in the plugin's folder under Istelien\Resources\Tools:
- ImportQuizCSV to create new packages from questions in a simple text file.
- ImportQuizLT to import quizzes you may have added to LOTRivia if you previously used that plugin before.
Please read each tool's README file for instructions on how to do it.

Second: the aspiration of this plugin was to be a fully automatic quiz engine that allows the host to play with others. However, LOTRO does not allow unattended chat input. There are two ways to try to overcome this:
1.- I've designed the semiautomatic mode for Answer validation to require the minimum management possible during the game. For the best experience, click any red button as soon as they appear in the interface. The ones covering the game flow are in the same position so you could manage without moving the mouse and just clicking twice on a quick succession, while you use the keyboard to play as any other player.
2.- I've included a third experimental tool called AutoFlow that reads the main window position and clicks those red buttons when they appear. Activate it after starting the game and deactivate it when finished. Read the README file as with the other tools.

Hope you enjoy playing and hosting.]],
		-- CHAT strings
		['msgFellowshipCommand'] = '/f',
		['msgKinshipCommand'] = '/k',
		['msgOfficerCommand'] = '/o',
		['msgOOCCommand'] = '/ooc',
		['msgRaidCommand'] = '/ra',
		['msgRegionalCommand'] = '/regional',
		['msgTellCommand'] = '/tell',
		['msgUserChat1Command'] = '/1',
		['msgUserChat2Command'] = '/2',
		['msgUserChat3Command'] = '/3',
		['msgUserChat4Command'] = '/4',
		['msgUserChat5Command'] = '/5',
		['msgUserChat6Command'] = '/6',
		['msgUserChat7Command'] = '/7',
		['msgUserChat8Command'] = '/8',
		['msgWorldCommand'] = '/world',
		['msgMainCommand'] = 'Istelien command added. Type <rgb=#FF0000>/istelien show</rgb> or right click on the icon to open the main menu.',
		['msgHelpCommand'] = 'Click on the ? icon of the main menu for basic information or refer to the online or included documentation for details.',
		['msgHelpCommandUsers'] = 'User commands available. Type <rgb=#FF0000>!help</rgb> on the game channel to get a list.',
		['msgAvailableCommands'] = 'List of available commands',
		['msgResultsInfo'] = 'Receive the game standings',
		['msgJoinTeamInfo'] = 'Join the specified team. Create it first if it does not exist yet',
		['msgLeaveTeamInfo'] = 'Leave your team',
		['msgListTeamsInfo'] = 'List all existing teams',
		['msgListPlayersInfo'] = 'List all registered players',
		['msgListPlayersOfTeamInfo'] = 'List all the players of the specified team',
		['msgJoinedTeam'] = 'You have joined the team',
		['msgCouldNotJoinTeam'] = 'You must specify a team. Enter',
		['msgTeamChangesNotAllowed'] = 'Changes to teams are not allowed at the moment',
		['msgLeftTeam'] = 'You are now a loner',
		['msgAlreadyWithoutTeam'] = 'You were not part of any team',
		['msgToChannel'] = 'To',
		['msgOpenExclamation'] = '',
		['msgCloseExclamation'] = '!',
		['msgPointGift'] = 'Corruption',
		['msgGameMasterAdded'] = 'The Game Master has added',
		['msgPoint'] = 'point',
		['msgPoints'] = 'points',
		['msgTo'] = 'to',
		['msgFor'] = 'for',
		['msgListPlayers'] = 'List of active players',
		['msgNoPlayersRegistered'] = 'There are no registered players at the moment',
		['msgListPlayersInTeam'] = 'List of players in the team',
		['msgNoPlayersInTeamRegistered'] = 'has no members at the moment',
		['msgNoTeams'] = 'There are no teams at the moment',
		['msgListTeams'] = 'List of registered teams',
		['msgNoTeamsCreated'] = 'There are no teams at the moment',
		['msgTeamsCommandsInstructions'] = 'If teams are not locked you can use <rgb=#FFA500>!jointeam <TeamName></rgb> to join an existing or new team of your choice',
		['msgTeamsCommandsInstructions2'] = '<rgb=#FFA500>!listplayers <TeamName></rgb> lets you see the members of an existing team',
		['msgGameStart'] = 'Game Start',
		['msgStartingGame'] = 'STARTING GAME',
		['msgStartingGameSaved'] = 'RESUMING SAVED GAME',
		['msgGameMode1'] = 'Game duration',
		['msgGameMode2'] = 'Game duration',
		['msgGameMode3'] = 'Game goal',
		['msgGameMode4'] = 'Game goal',
		['msgGameTargetType1'] = 'question',
		['msgGameTargetType1Plural'] = 'questions',
		['msgGameTargetType2'] = 'minute',
		['msgGameTargetType2Plural'] = 'minutes',
		['msgGameTargetType3'] = 'player point',
		['msgGameTargetType3Plural'] = 'player points',
		['msgGameTargetType4'] = 'team point',
		['msgGameTargetType4Plural'] = 'team points',
		['msgScoreMode1'] = 'Fixed scoring',
		['msgScoreMode2'] = 'Incremental scoring',
		['msgScoreMode3'] = 'Custom scoring',
		['msgType'] = 'Type',
		['msgForCommands'] = 'for your available commands',
		['msgGamePause'] = 'Game Pause',
		['msgGameLoad'] = 'Game Load',
		['msgPausingGame'] = 'PAUSING GAME',
		['msgAwaitingResume'] = 'There will be no new questions until it is resumed',
		['msgGameResume'] = 'Game Resume',
		['msgResumingGame'] = 'RESUMING GAME',
		['msgContinuePlaying'] = 'You can continue playing where you left it',
		['msgGameEnd'] = 'Game End',
		['msgEndGame'] = 'END GAME',
		['msgFinalResults'] = 'Final Results',
		['msgProvisionalResults'] = 'Provisional Results',
		['msgPlayerStandings'] = 'Player standings',
		['msgTeamStandings'] = 'Team standings',
		['msgNobodyScored'] = 'Nobody scored',
		['msgNobodyScoredThisQuestion'] = 'Nobody scored on this question',
		['msgGotRightAnswer'] = 'got it',
		['msgNobodyKnew'] = 'Nobody knew',
		['msgAnswerWas'] = 'The answer was',
		['msgPlayerScore'] = 'Player score',
		['msgTeamScore'] = 'Team score',
		['msgHint'] = 'A Hint',
		['msgQuiz'] = 'Quiz',
		['msgBy'] = 'by',
		['msgQuestion'] = 'Question',
		['msgCategory'] = 'Category',	
		['msgAuthor'] = 'Author',	
		['msgTimesUp'] = 'Time\'s up',
		['msgManualWrap'] = 'The Game Master decided you had enough of this question',
	},
	['French'] = 
	{
		-- GUI strings
		['txtFellowshipChannelName'] = 'Communaut',
		['txtKinshipChannelName'] = 'Confrrie',
		['txtOfficerChannelName'] = 'Officier',
		['txtOOCChannelName'] = 'HDP',
		['txtRaidChannelName'] = 'Raid',
		['txtRegionalChannelName'] = 'Rgional',
		['txtTellChannelName'] = 'Dire',
		['txtUserChat1ChannelName'] = 'Chat Utilisateur 1',
		['txtUserChat2ChannelName'] = 'Chat Utilisateur 2',
		['txtUserChat3ChannelName'] = 'Chat Utilisateur 3',
		['txtUserChat4ChannelName'] = 'Chat Utilisateur 4',
		['txtUserChat5ChannelName'] = 'Chat Utilisateur 5',
		['txtUserChat6ChannelName'] = 'Chat Utilisateur 6',
		['txtUserChat7ChannelName'] = 'Chat Utilisateur 7',
		['txtUserChat8ChannelName'] = 'Chat Utilisateur 8',
		['txtWorldChannelName'] = 'Monde',
		['txtGenSettings'] = 'Paramtres Gnraux',
		['txtChannel'] = 'Jouer dans le canal',
		['txtGameMode'] = 'But du jeu',
		['txtGameMode1'] = 'Nombre de Questions',
		['txtGameMode2'] = 'Temps coul',
		['txtGameMode3'] = 'Points du Joueur',
		['txtGameMode4'] = 'Points d\'quipe',
		['txtGameTarget'] = 'But',
		['txtQuestion'] = 'question',
		['txtQuestions'] = 'questions',
		['txtMinute'] = 'minute',
		['txtMinutes'] = 'minutes',
		['txtPoint'] = 'point',
		['txtPoints'] = 'points',
		['txtSecond'] = 'seconde',
		['txtSeconds'] = 'secondes',
		['txtQuestionMode'] = 'Validation de Rponse',
		['txtQuestionMode1'] = 'Semi-automatique',
		['txtQuestionMode2'] = 'Manuel',
		['txtQuestionTime'] = 'Temps par question',
		['txtQuestionHint'] = 'Piste dans',
		['txtLogGame'] = 'Registrer jeu',
		['txtSelectQuiz'] = 'Choisir Quiz',
		['txtTeamSettings'] = 'Paramtres d\'quipes',
		['txtTeamsEnable'] = 'Activer le jeu d\'quipe',
		['txtTeamsLock'] = 'Verrouiller quipes',
		['txtManageTeams'] = 'Grer des Equipes',
		['txtDifficulty'] = 'Paramtres de Difficult',
		['txtIgnoreCase'] = 'Ignorer casse',
		['txtIndulgentSpelling'] = 'Orthographe Indulgente',
		['txtApproximateAnswers'] = 'Rponses approchantes',
		['txtPercentAccuracy'] = '% exactitude',
		['txtScoring'] = 'Paramtres de Score',
		['txtScoreMode'] = 'Points de Question',
		['txtScoreMode1'] = 'Fixe',
		['txtScoreMode2'] = 'Incrmental',
		['txtScoreMode3'] = 'Personnalis',
		['txtCustomScores'] = 'Personnaliser',
		['txtMultipleHits'] = 'Rcompenser les rponses simultanes',
		['txtMultipleHitsTypeSpeed'] = 'Seuil de vitesse',
		['txtMultipleHitsTypeSpeedAdj'] = 'carac/sec',
		['txtMultipleHitsDivisor'] = 'Points de deuxime place',
		['txtMultipleHitsDivisor1'] = 'Fixe',
		['txtMultipleHitsDivisor2'] = 'Dcroissant',
		['txtGameControls'] = 'Commandes de Jeu',
		['txtStartGame'] = 'Dmarrer Jeu',
		['txtPauseGame'] = 'Pauser Jeu',
		['txtResumeGame'] = 'Reprendre Jeu',
		['txtResumeFromSave'] = 'Reprendre Jeu',
		['txtEndGame'] = 'Terminer Jeu',
		['txtLoadGame'] = 'Charger Jeu',
		['txtSaveGame'] = 'Sauvegarder Jeu',
		['txtFlowInstructions'] = 'Utilisez les boutons suivants pour contrler le flux de jeu et ragir aux entres du joueur et aux paramtres configurs.\nEn mode semi-automatique, vous voulez ragir le plus rapidement possible pour une exprience de jeu optimale.',
		['txtFinishQuestion'] = 'Terminer Question',
		['txtProvideHint'] = 'Donner Piste',
		['txtAckCommand'] = 'Acq Commande',
		['txtPointGift'] = 'Cadeau de Points',
		['txtPlayers'] = 'Joueurs',
		['txtTeams'] = 'quipes',
		['txtAnnounceScores'] = 'Annoncer les scores',
		['txtEndQuestion'] = 'Terminer Question',
		['txtWrapQuestion'] = 'Emballer Question',
		['txtAskQuestion'] = 'Poser Question',
		['txtMasterScorer'] = 'Score Arbitre',
		['txtMasterScorerInfo'] = 'Dfinit le nombre de points que chaque participant doit gagner pour cette question.\nPar dfaut, sont affiches les valeurs suggres en fonction des paramtres du jeu',
		['txtCorrectAnswer'] = 'La rponse tait',
		['txtSetPoints'] = 'Dfinir Points',
		['txtPointTo'] = 'point pour',
		['txtPointsTo'] = 'points pour',
		['txtAccept'] = 'Accepter',
		['txtCancel'] = 'Annuler',
		['txtStandings'] = 'Classement',
		['txtPlayerStandings'] = 'Classement des Joueurs',
		['txtTeamStandings'] = 'Classement des quipes',
		['txtNobodyScored'] = 'Pas de score',
		['txtPublishResults'] = 'Publier',
		['txtAccept'] = 'Accepter',
		['txtCancel'] = 'Annuler',
		['txtClearSelection'] = 'Effacer Slection',
		['txtQuizLibrary'] = 'Bibliothque de Quiz',
		['txtQuizLibraryInfo'] = 'Slectionnez les paquets pour votre prochain jeu.\nEffacer la slection pour utiliser le paquet intgr.',
		['txtPackageList'] = 'Liste des Paquets',
		['txtUnnamedPackage'] = 'Paquet sans nom',
		['txtBy'] = 'par',
		['txtUnnamedPackage'] = 'un auteur inconnu',
		['msgCouldNotLoadAnyPackage'] = 'Impossible de charger la slection de quiz configure. En utilisant le premier de la liste',
		['msgCouldNotLoadSomePackage'] = 'Impossible de charger tous les paquets dans la slection de quiz configure. Charg le reste',
		['txtCustomizeScores'] = 'Ed. Score',
		['txtCustomizeScoresInfo'] = 'Utilisez les contrles ci-dessous pour attribuer des scores en fonction de la longueur de la rponse',
		['txtMore'] = 'Plus',
		['txtWord'] = 'mot',
		['txtWords'] = 'mots',
		['txtAddLine'] = '+',
		['txtRemoveLine'] = '-',
		['txtTeamsManager'] = 'Gestionnaire d\'quipes',
		['txtAvailableTeams'] = 'quipes disponibles',
		['txtTeamMembers'] = 'Membres de l\'quipe',
		['txtRegisteredPlayers'] = 'Joueurs Inscrits',
		['txtAnnounceMembers'] = 'Annoncer Membres',
		['txtAddMember'] = '<',
		['txtDeleteMember'] = '>',
		['txtAddTeam'] = '+',
		['txtDeleteTeam'] = '-',
		['txtAddPlayer'] = '+',
		['txtDeletePlayer'] = '-',
		['txtTeamsManagerInfo'] = 'Les joueurs doivent tre inscrits pour rejoindre une quipe. Les quipes vides seront limines au dbut de la partie. Les joueurs solitaires aussi jusqu\' ce qu\'ils utilisent  nouveau le chat pendant le jeu. Si les quipes ne sont pas verrouilles, les joueurs peuvent taper "!jointeam <TeamName>" pour demander  rejoindre une quipe existante ou nouvelle. Vous pouvez acquitter de la commande ou rutiliser cette fentre',
		['txtAnnounceTeams'] = 'Announce Teams',
		['txtClose'] = 'Fermer',
		['txtName'] = 'Nom',
		['txtAdd'] = 'Ajouter',
		['txtSavegames'] = 'Parties Sauvegardes',
		['txtSavegameList'] = 'Liste des Parties Sauvegardes',
		['txtEmptySlot'] = 'Emplacement vide',
		['txtLoadDefaults'] = 'Charger Dfaut',
		['txtDeleteSelected'] = 'Supprimer Partie',
		['txtDeletedSelectedOK'] = 'Partie supprime  l\'emplacement',
		['txtDeletedSelectedFail'] = 'Impossible de supprimer la partie  l\'emplacement',
		['txtLoadGameOK'] = 'Partie charge  partir de l\'emplacement',
		['txtLoadGameFail'] = 'Impossible de charger la partie  partir de l\'emplacement',
		['txtSave'] = 'Enregistrer',
		['txtSaveGameOK'] = 'Partie sauvegard dans l\'emplacement',
		['txtSaveGameFail'] = 'Impossible de sauvegarder la partie dans l\'emplacement',
		['txtHelpText'] = [[Bienvenue sur Istelien.
 
Deux points importants qu'il est bon que vous connaissiez. Toute autre option plus petite est couverte par la documentation en ligne ou incluse.
 
Tout d'abord: vous pouvez commencer  jouer tout de suite avec la bibliothque de quiz incluse. Cependant, vous pouvez ajouter de nouveaux packages de quiz sur n'importe quel sujet. Pour vous aider, il existe deux outils inclus dans le dossier du plugin sous Istelien\Resources\Tools:
- ImportezQuizCSV pour crer de nouveaux packages  partir de questions dans fichier de texte simple.
- ImportQuizLT pour importer les quiz que vous avez peut-tre ajouts  LOTRivia si vous avez dj utilis ce plugin auparavant.
Veuillez lire le fichier README de chaque outil pour obtenir des instructions.
 
Deuximement: l'aspiration de ce plugin tait d'tre un moteur de quiz entirement automatique qui permet  l'hte de jouer avec d'autres. Cependant, LOTRO n'autorise pas la saisie de clavardage automatique. Il y a deux faons d'essayer de surmonter cela:
1.- J'ai conu le mode semi-automatique pour la validation des rponses afin de ncessiter le minimum de gestion possible pendant le jeu. Pour une meilleure exprience, cliquez sur les boutons rouges ds qu'ils apparaissent dans l'interface. Ceux qui couvrent le flux de jeu sont dans la mme position, ce qui vous permet de vous dbrouiller sans dplacer la souris et en cliquant deux fois sur une succession rapide, pendant que vous utilisez le clavier pour jouer comme autres joueurs.
2.- J'ai inclus un troisime outil exprimental appel AutoFlow qui lit la position de la fentre principale et clique sur les boutons rouges lorsqu'ils apparaissent. Activez-le aprs avoir dmarr le jeu et dsactivez-le lorsque vous avez termin. Lisez le fichier README comme avec les autres outils.
 
J'espre que vous apprcierez de jouer et d'hberger.]],
		-- CHAT strings
		['msgFellowshipCommand'] = '/f',
		['msgKinshipCommand'] = '/k',
		['msgOfficerCommand'] = '/o',
		['msgOOCCommand'] = '/hdp',
		['msgRaidCommand'] = '/ra',
		['msgRegionalCommand'] = '/rgional',
		['msgTellCommand'] = '/dire',
		['msgUserChat1Command'] = '/1',
		['msgUserChat2Command'] = '/2',
		['msgUserChat3Command'] = '/3',
		['msgUserChat4Command'] = '/4',
		['msgUserChat5Command'] = '/5',
		['msgUserChat6Command'] = '/6',
		['msgUserChat7Command'] = '/7',
		['msgUserChat8Command'] = '/8',
		['msgWorldCommand'] = '/monde',
		['msgMainCommand'] = 'Istelien commande ajout. Tapez <rgb=#FF0000>/istelien show</rgb> ou faites un clic droit sur l\'icne pour ouvrir le menu principal.',
		['msgHelpCommand'] = 'Cliquez sur le bouton ? du menu principal pour obtenir des informations de base ou reportez-vous  la documentation en ligne ou incluse pour plus de dtails.',
		['msgHelpCommandUsers'] = 'Commandes d\'utilisateur disponibles. Tapez <rgb=#FF0000>!help</rgb> sur le canal de jeu pour obtenir une liste.',
		['msgAvailableCommands'] = 'Liste des commandes disponibles',
		['msgResultsInfo'] = 'Recevoir le classement du jeu',
		['msgJoinTeamInfo'] = 'Rejoindre l\'quipe spcifie. Crez-le d\'abord s\'il n\'existe pas encore',
		['msgLeaveTeamInfo'] = 'Quittez votre quipe',
		['msgListTeamsInfo'] = 'Lister toutes les quipes existantes',
		['msgListPlayersInfo'] = 'Liste tous les joueurs inscrits',
		['msgListPlayersOfTeamInfo'] = 'Lister toutes les joueurs de l\'quipe spcifie',
		['msgJoinedTeam'] = 'Vous avez rejoint l\'quipe',
		['msgCouldNotJoinTeam'] = 'Vous devez spcifier une quipe. Entrez',
		['msgTeamChangesNotAllowed'] = 'Modifications des quipes ne sont pas autorises pour le moment',
		['msgLeftTeam'] = 'Vous tes maintenant un solitaire',
		['msgAlreadyWithoutTeam'] = 'Vous ne faisiez partie d\'aucune quipe',
		['msgToChannel'] = 'A',
		['msgOpenExclamation'] = '',
		['msgCloseExclamation'] = '!',
		['msgPointGift'] = 'Corruption',
		['msgGameMasterAdded'] = 'Le Matre du Jeu a ajout',
		['msgPoint'] = 'point',
		['msgPoints'] = 'points',
		['msgTo'] = '',
		['msgFor'] = 'pour',
		['msgListPlayers'] = 'Liste des joueurs actifs',
		['msgNoPlayersRegistered'] = 'Il n\'y a pas de joueurs inscrits pour le moment',
		['msgListPlayersInTeam'] = 'Liste des joueurs de l\'quipe',
		['msgNoPlayersInTeamRegistered'] = 'n\'a pas de membres pour le moment',
		['msgNoTeams'] = 'Il n\'y a pas d\'quipes pour le moment',
		['msgListTeams'] = 'Liste des quipes inscrites',
		['msgNoTeamsCreated'] = 'Il n\'y a pas d\'quipes pour le moment',
		['msgTeamsCommandsInstructions'] = 'Si les quipes ne sont pas verrouilles, vous pouvez utiliser <rgb=#FFA500>!jointeam<TeamName></rgb> pour rejoindre une quipe existante ou nouvelle de votre choix',
		['msgTeamsCommandsInstructions2'] = '<rgb=#FFA500>!listplayers <TeamName></rgb> permet de voir les membres d\'une quipe existante',
		['msgGameStart'] = 'Dmarrage de Partie',
		['msgStartingGame'] = 'LA PARTIE VA COMMENCER',
		['msgStartingGameSaved'] = 'REPRISE DE LA PARTIE SAUVEGARDE',
		['msgGameMode1'] = 'Dure du jeu',
		['msgGameMode2'] = 'Dure du jeu',
		['msgGameMode3'] = 'Objectif de jeu',
		['msgGameMode4'] = 'Objectif de jeu',
		['msgGameTargetType1'] = 'question',
		['msgGameTargetType1Plural'] = 'questions',
		['msgGameTargetType2'] = 'minute',
		['msgGameTargetType2Plural'] = 'minutes',
		['msgGameTargetType3'] = 'point du joueur',
		['msgGameTargetType3Plural'] = 'points du joueur',
		['msgGameTargetType4'] = 'point d\'quipe',
		['msgGameTargetType4Plural'] = 'points d\'quipe',
		['msgScoreMode1'] = 'Score fix',
		['msgScoreMode2'] = 'Score incrmentiel',
		['msgScoreMode3'] = 'Score personnalis',
		['msgType'] = 'Tapez',
		['msgForCommands'] = 'pour vos commandes disponibles',
		['msgGamePause'] = 'Pause de Partie',
		['msgGameLoad'] = 'Charge de Partie',
		['msgPausingGame'] = 'PARTIE EN PAUSE',
		['msgAwaitingResume'] = 'Il n\'y aura pas de nouvelles questions tant qu\'il n\'y aura pas de reprise',
		['msgGameResume'] = 'Reprise de Partie',
		['msgResumingGame'] = 'REPRISE DE PARTIE',
		['msgContinuePlaying'] = 'Vous pouvez continuer  jouer l o vous l\'avez laiss',
		['msgGameEnd'] = 'Fin de Partie',
		['msgEndGame'] = 'FIN DE PARTIE',
		['msgFinalResults'] = 'Rsultats Finaux',
		['msgProvisionalResults'] = 'Rsultats provisoires',
		['msgPlayerStandings'] = 'Classement des joueurs',
		['msgTeamStandings'] = 'Classement des quipes',
		['msgNobodyScored'] = 'Personne n\'a obtenu de score',
		['msgNobodyScoredThisQuestion'] = 'Personne n\'a obtenu de score sur cette question',
		['msgGotRightAnswer'] = 'le savait',
		['msgNobodyKnew'] = 'Personne ne savait',
		['msgAnswerWas'] = 'La rponse tait',
		['msgPlayerScore'] = 'Score du joueur',
		['msgTeamScore'] = 'Score de l\'quipe',
		['msgHint'] = 'Une Piste',
		['msgQuiz'] = 'Quiz',
		['msgBy'] = 'par',
		['msgQuestion'] = 'Question',
		['msgCategory'] = 'Catgorie',	
		['msgAuthor'] = 'Auteur',	
		['msgTimesUp'] = 'Le temps s\'est coul',
		['msgManualWrap'] = 'Le Matre du Jeu a dcid que vous en aviez assez de cette question',
	},
	['German'] = 
	{
		-- GUI strings
		['txtFellowshipChannelName'] = 'Gruppen',
		['txtKinshipChannelName'] = 'Sippe',
		['txtOfficerChannelName'] = 'Offiziere',
		['txtOOCChannelName'] = 'OOC',
		['txtRaidChannelName'] = 'Schlachtzugs',
		['txtRegionalChannelName'] = 'Regional',
		['txtTellChannelName'] = 'Flstern',
		['txtUserChat1ChannelName'] = 'Benutzer-Chat 1',
		['txtUserChat2ChannelName'] = 'Benutzer-Chat 2',
		['txtUserChat3ChannelName'] = 'Benutzer-Chat 3',
		['txtUserChat4ChannelName'] = 'Benutzer-Chat 4',
		['txtUserChat5ChannelName'] = 'Benutzer-Chat 5',
		['txtUserChat6ChannelName'] = 'Benutzer-Chat 6',
		['txtUserChat7ChannelName'] = 'Benutzer-Chat 7',
		['txtUserChat8ChannelName'] = 'Benutzer-Chat 8',
		['txtWorldChannelName'] = 'Welt',
		['txtGenSettings'] = 'General Settings',
		['txtChannel'] = 'Play in channel',
		['txtGameMode'] = 'Game goal',
		['txtGameMode1'] = 'Number of Questions',
		['txtGameMode2'] = 'Elapsed Time',
		['txtGameMode3'] = 'Player Points',
		['txtGameMode4'] = 'Team Points',
		['txtGameTarget'] = 'Target',
		['txtQuestion'] = 'question',
		['txtQuestions'] = 'questions',
		['txtMinute'] = 'minute',
		['txtMinutes'] = 'minutes',
		['txtPoint'] = 'point',
		['txtPoints'] = 'points',
		['txtSecond'] = 'second',
		['txtSeconds'] = 'seconds',
		['txtQuestionMode'] = 'Answer validation',
		['txtQuestionMode1'] = 'Semiautomatic',
		['txtQuestionMode2'] = 'Manual',
		['txtQuestionTime'] = 'Time per question',
		['txtQuestionHint'] = 'Hint at',
		['txtLogGame'] = 'Log game',
		['txtSelectQuiz'] = 'Select Quiz',
		['txtTeamSettings'] = 'Team Settings',
		['txtTeamsEnable'] = 'Enable Team play',
		['txtTeamsLock'] = 'Lock teams',
		['txtManageTeams'] = 'Manage Teams',
		['txtDifficulty'] = 'Difficulty Settings',
		['txtIgnoreCase'] = 'Ignore case',
		['txtIndulgentSpelling'] = 'Indulgent spelling',
		['txtApproximateAnswers'] = 'Approximate answers',
		['txtPercentAccuracy'] = '% accuracy',
		['txtScoring'] = 'Scoring Settings',
		['txtScoreMode'] = 'Question points',
		['txtScoreMode1'] = 'Fixed',
		['txtScoreMode2'] = 'Incremental',
		['txtScoreMode3'] = 'Custom',
		['txtCustomScores'] = 'Customize',
		['txtMultipleHits'] = 'Reward simultaneous answers',
		['txtMultipleHitsTypeSpeed'] = 'Speed threshold',
		['txtMultipleHitsTypeSpeedAdj'] = 'chars/sec',
		['txtMultipleHitsDivisor'] = 'Runner-up points',
		['txtMultipleHitsDivisor1'] = 'Fixed',
		['txtMultipleHitsDivisor2'] = 'Decreasing',
		['txtGameControls'] = 'Game Controls',
		['txtStartGame'] = 'Start Game',
		['txtPauseGame'] = 'Pause Game',
		['txtResumeGame'] = 'Resume Game',
		['txtResumeFromSave'] = 'Resume Game',
		['txtEndGame'] = 'End Game',
		['txtLoadGame'] = 'Load Game',
		['txtSaveGame'] = 'Save Game',
		['txtFlowInstructions'] = 'Use the following buttons to control game flow and react to player inputs and configured settings.\nIn semiautomatic mode you want to react as quick as possible for the best game experience.',
		['txtFinishQuestion'] = 'Finish Question',
		['txtProvideHint'] = 'Provide Hint',
		['txtAckCommand'] = 'Ack Command',
		['txtPointGift'] = 'Point Gift',
		['txtPlayers'] = 'Players',
		['txtTeams'] = 'Teams',
		['txtAnnounceScores'] = 'Announce Scores',
		['txtEndQuestion'] = 'End Question',
		['txtWrapQuestion'] = 'Wrap Question',
		['txtAskQuestion'] = 'Ask Question',
		['txtMasterScorer'] = 'Master Scorer',
		['txtMasterScorerInfo'] = 'Set the number of points each participant should earn for this question.\nBy default, suggested values according to game settings are shown',
		['txtCorrectAnswer'] = 'The answer was',
		['txtSetPoints'] = 'Set Points',
		['txtPointTo'] = 'point to',
		['txtPointsTo'] = 'points to',
		['txtAccept'] = 'Accept',
		['txtCancel'] = 'Cancel',
		['txtStandings'] = 'Standings',
		['txtPlayerStandings'] = 'Player Standings',
		['txtTeamStandings'] = 'Team Standings',
		['txtNobodyScored'] = 'Nobody scored',
		['txtPublishResults'] = 'Publish',
		['txtAccept'] = 'Accept',
		['txtCancel'] = 'Cancel',
		['txtClearSelection'] = 'Clear Selection',
		['txtQuizLibrary'] = 'Quiz Library',
		['txtQuizLibraryInfo'] = 'Select the packages for your next game.\nClear selection to use the built-in package.',
		['txtPackageList'] = 'Package List',
		['txtUnnamedPackage'] = 'Unnamed Package',
		['txtBy'] = 'by',
		['txtUnnamedPackage'] = 'an unknown author',
		['msgCouldNotLoadAnyPackage'] = 'Could not load the configured quiz selection. Using the first on the list',
		['msgCouldNotLoadSomePackage'] = 'Could not load all the packages in configured quiz selection. Loaded the rest',
		['txtCustomizeScores'] = 'Ed. Scoring',
		['txtCustomizeScoresInfo'] = 'Use the controls below to assign scores depending on answer length',
		['txtMore'] = 'More',
		['txtWord'] = 'word',
		['txtWords'] = 'words',
		['txtAddLine'] = '+',
		['txtRemoveLine'] = '-',
		['txtTeamsManager'] = 'Teams Manager',
		['txtAvailableTeams'] = 'Available Teams',
		['txtTeamMembers'] = 'Team Members',
		['txtRegisteredPlayers'] = 'Registered Players',
		['txtAnnounceMembers'] = 'Announce Members',
		['txtAddMember'] = '<',
		['txtDeleteMember'] = '>',
		['txtAddTeam'] = '+',
		['txtDeleteTeam'] = '-',
		['txtAddPlayer'] = '+',
		['txtDeletePlayer'] = '-',
		['txtTeamsManagerInfo'] = 'Players need to be registered to join a team. Empty teams will be cleared at the beginning of the game. Lone players too until they use the chat again during gameplay. If teams are not locked, players can type "!jointeam <TeamName>" to request joining an existing or new team. You can acknowledge the command or use this window again',
		['txtAnnounceTeams'] = 'Announce Teams',
		['txtClose'] = 'Close',
		['txtName'] = 'Name',
		['txtAdd'] = 'Add',
		['txtSavegames'] = 'Saved Games',
		['txtSavegameList'] = 'List of Saved Games',
		['txtEmptySlot'] = 'Empty slot',
		['txtLoadDefaults'] = 'Load Defaults',
		['txtDeleteSelected'] = 'Delete Game',
		['txtDeletedSelectedOK'] = 'Deleted game at slot',
		['txtDeletedSelectedFail'] = 'Could not delete game at slot',
		['txtLoadGameOK'] = 'Loaded game from slot',
		['txtLoadGameFail'] = 'Could not load game from slot',
		['txtSave'] = 'Save',
		['txtSaveGameOK'] = 'Saved game to slot',
		['txtSaveGameFail'] = 'Could not save game to slot',
		['txtHelpText'] = [[Welcome to Istelien.

Two important points it's good you are aware of. Any other smaller options would be covered by the online or included documentation.

First: you can start playing right away with the included quiz library. However, you can add new quiz packages of any topic. To help you with that, there are two tools included in the plugin's folder under Istelien\Resources\Tools:
- ImportQuizCSV to create new packages from questions in a simple text file.
- ImportQuizLT to import quizzes you may have added to LOTRivia if you previously used that plugin before.
Please read each tool's README file for instructions on how to do it.

Second: the aspiration of this plugin was to be a fully automatic quiz engine that allows the host to play with others. However, LOTRO does not allow unattended chat input. There are two ways to try to overcome this:
1.- I've designed the semiautomatic mode for Answer validation to require the minimum management possible during the game. For the best experience, click any red button as soon as they appear in the interface. The ones covering the game flow are in the same position so you could manage without moving the mouse and just clicking twice on a quick succession, while you use the keyboard to play as any other player.
2.- I've included a third experimental tool called AutoFlow that reads the main window position and clicks those red buttons when they appear. Activate it after starting the game and deactivate it when finished. Read the README file as with the other tools.

Hope you enjoy playing and hosting.]],
		-- CHAT strings
		['msgFellowshipCommand'] = '/g',
		['msgKinshipCommand'] = '/sc',
		['msgOfficerCommand'] = '/so',
		['msgOOCCommand'] = '/ooc',
		['msgRaidCommand'] = '/szc',
		['msgRegionalCommand'] = '/regional',
		['msgTellCommand'] = '/f',
		['msgUserChat1Command'] = '/1',
		['msgUserChat2Command'] = '/2',
		['msgUserChat3Command'] = '/3',
		['msgUserChat4Command'] = '/4',
		['msgUserChat5Command'] = '/5',
		['msgUserChat6Command'] = '/6',
		['msgUserChat7Command'] = '/7',
		['msgUserChat8Command'] = '/8',
		['msgWorldCommand'] = '/welt',
		['msgMainCommand'] = 'Istelien command added. Type <rgb=#FF0000>/istelien show</rgb> or right click on the icon to open the main menu.',
		['msgHelpCommand'] = 'Click on the ? icon of the main menu for basic information or refer to the online or included documentation for details.',
		['msgHelpCommandUsers'] = 'User commands available. Type <rgb=#FF0000>!help</rgb> on the game channel to get a list.',
		['msgAvailableCommands'] = 'List of available commands',
		['msgResultsInfo'] = 'Receive the game standings',
		['msgJoinTeamInfo'] = 'Join the specified team. Create it first if it does not exist yet',
		['msgLeaveTeamInfo'] = 'Leave your team',
		['msgListTeamsInfo'] = 'List all existing teams',
		['msgListPlayersInfo'] = 'List all registered players',
		['msgListPlayersOfTeamInfo'] = 'List all the players of the specified team',
		['msgJoinedTeam'] = 'You have joined the team',
		['msgCouldNotJoinTeam'] = 'You must specify a team. Enter',
		['msgTeamChangesNotAllowed'] = 'Changes to teams are not allowed at the moment',
		['msgLeftTeam'] = 'You are now a loner',
		['msgAlreadyWithoutTeam'] = 'You were not part of any team',
		['msgToChannel'] = 'Zu',
		['msgOpenExclamation'] = '',
		['msgCloseExclamation'] = '!',
		['msgPointGift'] = 'Corruption',
		['msgGameMasterAdded'] = 'The Game Master has added',
		['msgPoint'] = 'point',
		['msgPoints'] = 'points',
		['msgTo'] = 'to',
		['msgFor'] = 'for',
		['msgListPlayers'] = 'List of active players',
		['msgNoPlayersRegistered'] = 'There are no registered players at the moment',
		['msgListPlayersInTeam'] = 'List of players in the team',
		['msgNoPlayersInTeamRegistered'] = 'has no members at the moment',
		['msgNoTeams'] = 'There are no teams at the moment',
		['msgListTeams'] = 'List of registered teams',
		['msgNoTeamsCreated'] = 'There are no teams at the moment',
		['msgTeamsCommandsInstructions'] = 'If teams are not locked you can use <rgb=#FFA500>!jointeam <TeamName></rgb> to join an existing or new team of your choice',
		['msgTeamsCommandsInstructions2'] = '<rgb=#FFA500>!listplayers <TeamName></rgb> lets you see the members of an existing team',
		['msgGameStart'] = 'Game Start',
		['msgStartingGame'] = 'STARTING GAME',
		['msgStartingGameSaved'] = 'RESUMING SAVED GAME',
		['msgGameMode1'] = 'Game duration',
		['msgGameMode2'] = 'Game duration',
		['msgGameMode3'] = 'Game goal',
		['msgGameMode4'] = 'Game goal',
		['msgGameTargetType1'] = 'question',
		['msgGameTargetType1Plural'] = 'questions',
		['msgGameTargetType2'] = 'minute',
		['msgGameTargetType2Plural'] = 'minutes',
		['msgGameTargetType3'] = 'player point',
		['msgGameTargetType3Plural'] = 'player points',
		['msgGameTargetType4'] = 'team point',
		['msgGameTargetType4Plural'] = 'team points',
		['msgScoreMode1'] = 'Fixed scoring',
		['msgScoreMode2'] = 'Incremental scoring',
		['msgScoreMode3'] = 'Custom scoring',
		['msgType'] = 'Type',
		['msgForCommands'] = 'for your available commands',
		['msgGamePause'] = 'Game Pause',
		['msgGameLoad'] = 'Game Load',
		['msgPausingGame'] = 'PAUSING GAME',
		['msgAwaitingResume'] = 'There will be no new questions until it is resumed',
		['msgGameResume'] = 'Game Resume',
		['msgResumingGame'] = 'RESUMING GAME',
		['msgContinuePlaying'] = 'You can continue playing where you left it',
		['msgGameEnd'] = 'Game End',
		['msgEndGame'] = 'END GAME',
		['msgFinalResults'] = 'Final Results',
		['msgProvisionalResults'] = 'Provisional Results',
		['msgPlayerStandings'] = 'Player standings',
		['msgTeamStandings'] = 'Team standings',
		['msgNobodyScored'] = 'Nobody scored',
		['msgNobodyScoredThisQuestion'] = 'Nobody scored on this question',
		['msgGotRightAnswer'] = 'got it',
		['msgNobodyKnew'] = 'Nobody knew',
		['msgAnswerWas'] = 'The answer was',
		['msgPlayerScore'] = 'Player score',
		['msgTeamScore'] = 'Team score',
		['msgHint'] = 'A Hint',
		['msgQuiz'] = 'Quiz',
		['msgBy'] = 'by',
		['msgQuestion'] = 'Question',
		['msgCategory'] = 'Category',	
		['msgAuthor'] = 'Author',	
		['msgTimesUp'] = 'Time\'s up',
		['msgManualWrap'] = 'The Game Master decided you had enough of this question',
	},
}


-- Defines the language for all string translations. If it's not found it will revert to English
function setLanguage()
	local languageName = languages[Turbine.Engine.GetLanguage()]
	if (strings[languageName] == nil) then
		clientLanguage = 'English'
	end
	return languageName
end

-- Translates a coded string to its proper readable text. It leaves the code if the translation is not found.
function translate(stringCode)
	if (strings[clientLanguage][stringCode] ~= nil) then
		return strings[clientLanguage][stringCode]
	else
		return stringCode
	end
end

clientLanguage = setLanguage()

