import 'Anglachel.Istelien.DropDown'

function activateWindow(window, visibility)
	window:SetVisible(visibility)
end

-- Get the default position of a Window in regards to display and window size
function calcDefaultWindowPos(window, width, height)
	if (width == nil) then
		width = 780
	end
	if (height == nil) then
		height = 580
	end
	if (gui[window]['posX'] == nil) then
		posX = Turbine.UI.Display.GetWidth() / 2 - width / 2
	else
		posX = gui[window]['posX']
	end
	if (gui[window]['posY'] == nil) then
		posY = Turbine.UI.Display.GetHeight() / 2 - height / 2
	else
		posY = gui[window]['posY']
	end
	
	return posX, posY
end

-- Save position of the window
function savePosition(window, key, posX, posY)
	gui[key]['posX'] = posX
	gui[key]['posY'] = posY
	dataManagement(gui, 'Save', 'Istelien_gui')
end

-- Icon to show Istelien
function launcherIcon(create)
	if (create == true) then
		local dragIcon = false
		local posX,posY = calcDefaultWindowPos('LauncherIcon', 32, 32)
		local screenWidth = Turbine.UI.Display.GetWidth()
		local screenHeight = Turbine.UI.Display.GetHeight()

		wLauncherIcon = Turbine.UI.Window()
		wLauncherIcon:SetPosition(posX, posY)
		wLauncherIcon:SetSize(32,32)
		wLauncherIcon:SetBackground(gui['Images']['GameIcon'])
		wLauncherIcon:SetVisible(true)
		wLauncherIcon.MouseClick = function(sender, args)
				if (args.Button == Turbine.UI.MouseButton.Right) then 
					if (wMainWindow == nil) then
						mainWindow(true)
						activateWindow(wMainWindow, true)
					else
						if (wMainWindow:IsVisible() == false) then
							activateWindow(wMainWindow, true)
						end
					end
				end
			end
		wLauncherIcon.MouseDown = function(sender, args)
				dragIcon = true
			end
		wLauncherIcon.MouseUp = function(sender, args)
				dragIcon = false
				local iconMoved = false
				local currentX = wLauncherIcon:GetLeft()
				local currentY = wLauncherIcon:GetTop()
				if (currentX ~= posX) then
					iconMoved = true
				end
				if (currentY ~= posY) then
					iconMoved = true
				end
				if (iconMoved == true) then
					savePosition(wLauncherIcon, 'LauncherIcon', currentX, currentY)
				end
				--dataManagement(gui, 'Save', 'Istelien_gui')
			end
		wLauncherIcon.MouseMove = function(sender, args)
				if (dragIcon == true) then
					local mousePosX = Turbine.UI.Display.GetMouseX()
					local mousePosY = Turbine.UI.Display.GetMouseY()
					local iconMoveX = mousePosX - 16
					local iconMoveY = mousePosY - 16
					if ((mousePosX - 16) < 0) then
						iconMoveX = 0
					end
					if ((mousePosY - 16) < 0) then
						iconMoveY = 0
					end
					if ((mousePosX + 16) > screenWidth) then
						iconMoveX = screenWidth - 32
					end
					if ((mousePosY + 16) > screenHeight) then
						iconMoveY = screenHeight - 32
					end
					wLauncherIcon:SetPosition(iconMoveX, iconMoveY)
				end
			end	
			
	else -- Destroy
		if (wLauncherIcon ~= nil) then
			wLauncherIcon:Close()
			wLauncherIcon = nil
		end
	end
end

guiSpacing = 20
guiCtrlHeigth = 20
guiColumnWidth = 200
guiButtonWidth = guiColumnWidth * 3/4

-- The main window of the game
function mainWindow(create)
	if (create == true) then
		local guiColumnNumber = 2
		local guiWidth = (guiColumnNumber * guiColumnWidth) + ((guiColumnNumber) * guiSpacing + guiSpacing / 2)
		local guiHeight = guiCtrlHeigth * 35
		local posX,posY = calcDefaultWindowPos('MainWindow', guiWidth, guiHeight)

		function resetStartGameMessage(saved)
			if (saved == nil) then
				saved = ''
			end
			local message = translate('msgStartingGame' .. saved) .. ' - '
			local plural = ''
			if (config['GAME']['GameTarget'] ~= 1) then
				plural = 'Plural'
			end
			message = message .. chatColours['Orange'] .. translate('msgGameMode' .. tostring(config['GAME']['GameMode'])) .. ': ' .. chatColours['Closure'] .. config['GAME']['GameTarget'] .. ' ' .. translate('msgGameTargetType' .. tostring(config['GAME']['GameMode'] .. plural)) .. '. '
			message = message .. chatColours['Orange'] .. translate('msgScoreMode' .. tostring(config['SCORING']['ScoreMode'])) .. chatColours['Closure'] .. '. '
			message = message .. replaceCharacters(replaceCharacters(translate('msgType'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ' ' .. chatColours['Orange'] .. '!help' .. chatColours['Closure'] .. ' ' .. replaceCharacters(replaceCharacters(translate('msgForCommands'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '. '
			
			return sendToChat(message, config['GAME']['GameChannel'], '', true)
		end
		
		-- CREATE WINDOW
		wMainWindow = Turbine.UI.Lotro.GoldWindow()
		wMainWindow:SetSize(guiWidth, guiHeight)
		wMainWindow:SetPosition(posX, posY)
		wMainWindow:SetBackColor(Turbine.UI.Color(0,0,0))
		wMainWindow:SetBackColorBlendMode(Turbine.UI.BlendMode.None)
		wMainWindow:SetText('Istelien')
		wMainWindow.PositionChanged = function(sender, args)				
				savePosition(wMainWindow, 'MainWindow', wMainWindow:GetLeft(), wMainWindow:GetTop())
			end
		-- wMainWindow:SetZOrder(100) -- Disabling because cannot set ZOrder in dropdowns
		
		-- Help icon
		wMainWindow.picHelp = Turbine.UI.Control()
		wMainWindow.picHelp:SetParent(wMainWindow)
		wMainWindow.picHelp:SetPosition(guiWidth - 16 - guiSpacing, guiCtrlHeigth * 2)
		wMainWindow.picHelp:SetSize(16, 16)
		wMainWindow.picHelp:SetBackground(gui['Images']['Help'])
		wMainWindow.picHelp.MouseClick = function(sender, args)
				helpWindow(true)
				activateWindow(wHelpWindow, true)	
			end

		-- General Settings label
		wMainWindow.lblGenSettings = Turbine.UI.Label()
		wMainWindow.lblGenSettings:SetParent(wMainWindow)
		wMainWindow.lblGenSettings:SetPosition(guiSpacing, guiCtrlHeigth * 2)
		wMainWindow.lblGenSettings:SetWidth(guiWidth - 16 - guiSpacing * 2, guiCtrlHeigth * 2)
		wMainWindow.lblGenSettings:SetForeColor(Turbine.UI.Color(1,0.843,0))
		wMainWindow.lblGenSettings:SetFont(Turbine.UI.Lotro.Font.TrajanPro18)
		wMainWindow.lblGenSettings:SetText(replaceCharacters(replaceCharacters(translate('txtGenSettings'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wMainWindow.lblGenSettings:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		-- Channel choice label
		wMainWindow.lblGameChannel = Turbine.UI.Label()
		wMainWindow.lblGameChannel:SetParent(wMainWindow)
		wMainWindow.lblGameChannel:SetPosition(guiSpacing * 2, guiCtrlHeigth * 3)
		wMainWindow.lblGameChannel:SetSize(guiColumnWidth - guiSpacing, guiCtrlHeigth)
		wMainWindow.lblGameChannel:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.lblGameChannel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
		wMainWindow.lblGameChannel:SetText(replaceCharacters(replaceCharacters(translate('txtChannel'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ':')
		-- wMainWindow.lblGameChannel:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		-- Channel choice dropdown
		local chatChannelSelect = copyTableShallow(chatChannels)
		chatChannelSelect['Append'] = nil -- The whole point was to ignore this artificial channel
		local lstGameChannel = sortedKeys(chatChannelSelect)
		local lstGameChannelNames = copyTableShallow(lstGameChannel) -- We don't want to put the ID in the list, we want the translated names. So we make a copy and change the values
		local lstGameChannelIndexes = {} -- We also create a reference table to go back from name to ID when the selection is changed.
		for i,v in ipairs(lstGameChannelNames) do
			lstGameChannelNames[i] = chatChannels[v]['Name']
			lstGameChannelIndexes[chatChannels[v]['Name']] = v
		end
		local savedChannelName = chatChannels[config['GAME']['GameChannel']]['Name']
		wMainWindow.ddGameChannel = DropDown(lstGameChannelNames, savedChannelName)
		wMainWindow.ddGameChannel:SetParent(wMainWindow)
		wMainWindow.ddGameChannel:SetPosition(guiColumnWidth + guiSpacing + guiSpacing / 2, guiCtrlHeigth * 3)
		wMainWindow.ddGameChannel:SetAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		-- wMainWindow.ddGameChannel:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.ddGameChannel.ItemChanged = function(Sender,Args)
				config['GAME']['GameChannel'] = lstGameChannelIndexes[Args.Text]
				wMainWindow.ddGameChannel:Reset() -- Scrolls back to the top of the list
				remapShortcut(wMainWindow.qsStartGame, resetStartGameMessage())
			end
		-- Game mode choice label
		wMainWindow.lblGameMode = Turbine.UI.Label()
		wMainWindow.lblGameMode:SetParent(wMainWindow)
		wMainWindow.lblGameMode:SetPosition(guiSpacing * 2, guiCtrlHeigth * 4)
		wMainWindow.lblGameMode:SetSize(guiColumnWidth - guiSpacing, guiCtrlHeigth)
		wMainWindow.lblGameMode:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.lblGameMode:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
		wMainWindow.lblGameMode:SetText(replaceCharacters(replaceCharacters(translate('txtGameMode'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ':') -- Game goal
		-- wMainWindow.lblGameMode:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		-- Game mode choice dropdown 
		local lstGameMode = {replaceCharacters(replaceCharacters(strings[clientLanguage]['txtGameMode1'], nonbasicCharactersForGuiPrev), nonbasicCharactersForGui),replaceCharacters(replaceCharacters(strings[clientLanguage]['txtGameMode2'], nonbasicCharactersForGuiPrev), nonbasicCharactersForGui),replaceCharacters(replaceCharacters(strings[clientLanguage]['txtGameMode3'], nonbasicCharactersForGuiPrev), nonbasicCharactersForGui),replaceCharacters(replaceCharacters(strings[clientLanguage]['txtGameMode4'], nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)}
		wMainWindow.ddGameMode = DropDown(lstGameMode, replaceCharacters(replaceCharacters(strings[clientLanguage]['txtGameMode' .. tostring(config['GAME']['GameMode'])], nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wMainWindow.ddGameMode:SetParent(wMainWindow)
		wMainWindow.ddGameMode:SetPosition(guiColumnWidth + guiSpacing + guiSpacing / 2, guiCtrlHeigth * 4)
		wMainWindow.ddGameMode:SetSize(guiColumnWidth, guiCtrlHeigth)
		wMainWindow.ddGameMode:SetAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		-- wMainWindow.ddGameMode:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.ddGameMode.ItemChanged = function(Sender,Args)
				config['GAME']['GameMode'] = Args.Index
				if (Args.Index == 4) then
					wMainWindow.chkTeamsEnable:SetChecked(true)
					config['GAME']['TeamsEnable'] = 1
				end
				wMainWindow.ddGameMode:Reset() -- Scrolls back to the top of the list
				local gameTargetType = ''
				if (config['GAME']['GameMode'] == 1) then
					if (config['GAME']['GameTarget'] == 1) then
						gameTargetType = replaceCharacters(replaceCharacters(translate('txtQuestion'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
					else
						gameTargetType = replaceCharacters(replaceCharacters(translate('txtQuestions'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
					end
				else
					if (config['GAME']['GameMode'] == 2) then
						if (config['GAME']['GameTarget'] == 1) then
							gameTargetType = replaceCharacters(replaceCharacters(translate('txtMinute'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
						else
							gameTargetType = replaceCharacters(replaceCharacters(translate('txtMinutes'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
						end
					else
						if (config['GAME']['GameTarget'] == 1) then
							gameTargetType = replaceCharacters(replaceCharacters(translate('txtPoint'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
						else
							gameTargetType = replaceCharacters(replaceCharacters(translate('txtPoints'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
						end
					end
				end
				wMainWindow.lblGameTargetAdj:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
				wMainWindow.lblGameTargetAdj:SetText(' ' .. gameTargetType .. '.')
				remapShortcut(wMainWindow.qsStartGame, resetStartGameMessage())
			end
		-- Game target label
		wMainWindow.lblGameTarget = Turbine.UI.Label()
		wMainWindow.lblGameTarget:SetParent(wMainWindow)
		wMainWindow.lblGameTarget:SetPosition(guiSpacing * 2, guiCtrlHeigth * 5)
		wMainWindow.lblGameTarget:SetSize(guiColumnWidth - guiSpacing, guiCtrlHeigth)
		wMainWindow.lblGameTarget:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.lblGameTarget:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
		wMainWindow.lblGameTarget:SetText(replaceCharacters(replaceCharacters(translate('txtGameTarget'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ':')
		-- wMainWindow.lblGameTarget:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		-- Game target input
		wMainWindow.inptGameTarget = Turbine.UI.Lotro.TextBox()
		wMainWindow.inptGameTarget:SetParent(wMainWindow)
		wMainWindow.inptGameTarget:SetPosition(guiColumnWidth + guiSpacing + guiSpacing / 2, guiCtrlHeigth * 5)
		wMainWindow.inptGameTarget:SetSize(35, guiCtrlHeigth)
		wMainWindow.inptGameTarget:SetMultiline(false)
		wMainWindow.inptGameTarget:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.inptGameTarget:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
		-- wMainWindow.inptGameTarget:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.inptGameTarget.FocusLost = function(Sender,Args)
				local newValue = validateNumberString(wMainWindow.inptGameTarget:GetText(), 1)
				if (newValue ~= nil) then
					config['GAME']['GameTarget'] = newValue
				end
				wMainWindow.inptGameTarget:SetText(tostring(config['GAME']['GameTarget']))
				local gameTargetType = ''
				if (config['GAME']['GameMode'] == 1) then
					if (config['GAME']['GameTarget'] == 1) then
						gameTargetType = replaceCharacters(replaceCharacters(translate('txtQuestion'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
					else
						gameTargetType = replaceCharacters(replaceCharacters(translate('txtQuestions'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
					end
				else
					if (config['GAME']['GameMode'] == 2) then
						if (config['GAME']['GameTarget'] == 1) then
							gameTargetType = replaceCharacters(replaceCharacters(translate('txtMinute'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
						else
							gameTargetType = replaceCharacters(replaceCharacters(translate('txtMinutes'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
						end
					else
						if (config['GAME']['GameTarget'] == 1) then
							gameTargetType = replaceCharacters(replaceCharacters(translate('txtPoint'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
						else
							gameTargetType = replaceCharacters(replaceCharacters(translate('txtPoints'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
						end
					end
				end
				wMainWindow.lblGameTargetAdj:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
				wMainWindow.lblGameTargetAdj:SetText(' ' .. gameTargetType .. '.')
				remapShortcut(wMainWindow.qsStartGame, resetStartGameMessage())
			end
		-- Game target adj
		wMainWindow.lblGameTargetAdj = Turbine.UI.Label()
		wMainWindow.lblGameTargetAdj:SetParent(wMainWindow)
		wMainWindow.lblGameTargetAdj:SetPosition(guiColumnWidth + guiSpacing + guiSpacing / 2 + 35, guiCtrlHeigth * 5)
		wMainWindow.lblGameTargetAdj:SetSize(100, guiCtrlHeigth)
		wMainWindow.lblGameTargetAdj:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.lblGameTargetAdj:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		-- wMainWindow.lblGameTargetAdj:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		-- Question mode choice label
		wMainWindow.lblQuestionMode = Turbine.UI.Label()
		wMainWindow.lblQuestionMode:SetParent(wMainWindow)
		wMainWindow.lblQuestionMode:SetPosition(guiSpacing * 2, guiCtrlHeigth * 6)
		wMainWindow.lblQuestionMode:SetSize(guiColumnWidth - guiSpacing, guiCtrlHeigth)
		wMainWindow.lblQuestionMode:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.lblQuestionMode:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
		wMainWindow.lblQuestionMode:SetText(replaceCharacters(replaceCharacters(translate('txtQuestionMode'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ':')
		-- wMainWindow.lblQuestionMode:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		-- Question mode dropdown 
		local lstQuestionMode = {replaceCharacters(replaceCharacters(strings[clientLanguage]['txtQuestionMode1'], nonbasicCharactersForGuiPrev), nonbasicCharactersForGui),replaceCharacters(replaceCharacters(strings[clientLanguage]['txtQuestionMode2'], nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)}
		wMainWindow.ddQuestionMode = DropDown(lstQuestionMode, replaceCharacters(replaceCharacters(strings[clientLanguage]['txtQuestionMode' .. tostring(config['GAME']['QuestionMode'])], nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wMainWindow.ddQuestionMode:SetParent(wMainWindow)
		wMainWindow.ddQuestionMode:SetPosition(guiColumnWidth + guiSpacing + guiSpacing / 2, guiCtrlHeigth * 6)
		wMainWindow.ddQuestionMode:SetSize(guiColumnWidth, guiCtrlHeigth)
		wMainWindow.ddQuestionMode:SetAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		-- wMainWindow.ddQuestionMode:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.ddQuestionMode.ItemChanged = function(Sender,Args)
				config['GAME']['QuestionMode'] = Args.Index
				resetActionButtons()
				wMainWindow.ddQuestionMode:Reset() -- Scrolls back to the top of the list
			end
		-- Question Time label
		wMainWindow.lblQuestionTime = Turbine.UI.Label()
		wMainWindow.lblQuestionTime:SetParent(wMainWindow)
		wMainWindow.lblQuestionTime:SetPosition(guiSpacing * 2, guiCtrlHeigth * 7)
		wMainWindow.lblQuestionTime:SetSize(guiColumnWidth - guiSpacing, guiCtrlHeigth)
		wMainWindow.lblQuestionTime:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.lblQuestionTime:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
		wMainWindow.lblQuestionTime:SetText(replaceCharacters(replaceCharacters(translate('txtQuestionTime'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ':')
		-- wMainWindow.lblQuestionTime:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		-- Question Time input
		wMainWindow.inptQuestionTime = Turbine.UI.Lotro.TextBox()
		wMainWindow.inptQuestionTime:SetParent(wMainWindow)
		wMainWindow.inptQuestionTime:SetPosition(guiColumnWidth + guiSpacing + guiSpacing / 2, guiCtrlHeigth * 7)
		wMainWindow.inptQuestionTime:SetSize(35, guiCtrlHeigth)
		wMainWindow.inptQuestionTime:SetMultiline(false)
		wMainWindow.inptQuestionTime:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.inptQuestionTime:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
		-- wMainWindow.inptQuestionTime:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.inptQuestionTime.FocusLost = function(Sender,Args)
				local newValue = validateNumberString(wMainWindow.inptQuestionTime:GetText(), 1, 600)
				if (newValue ~= nil) then
					config['GAME']['QuestionTime'] = newValue
				end
				wMainWindow.inptQuestionTime:SetText(tostring(config['GAME']['QuestionTime']))
				if (config['GAME']['QuestionTime'] == 1) then
					wMainWindow.lblQuestionTimeAdj:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtSecond'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
				else
					wMainWindow.lblQuestionTimeAdj:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtSeconds'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
				end
			end
		-- Question Time adj
		wMainWindow.lblQuestionTimeAdj = Turbine.UI.Label()
		wMainWindow.lblQuestionTimeAdj:SetParent(wMainWindow)
		wMainWindow.lblQuestionTimeAdj:SetPosition(guiColumnWidth + guiSpacing + guiSpacing / 2 + 35, guiCtrlHeigth * 7)
		wMainWindow.lblQuestionTimeAdj:SetSize(100, guiCtrlHeigth)
		wMainWindow.lblQuestionTimeAdj:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.lblQuestionTimeAdj:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		-- wMainWindow.lblQuestionTimeAdj:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		-- Hint label
		wMainWindow.lblQuestionHint = Turbine.UI.Label()
		wMainWindow.lblQuestionHint:SetParent(wMainWindow)
		wMainWindow.lblQuestionHint:SetPosition(guiSpacing * 2, guiCtrlHeigth * 8)
		wMainWindow.lblQuestionHint:SetSize(guiColumnWidth - guiSpacing, guiCtrlHeigth)
		wMainWindow.lblQuestionHint:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.lblQuestionHint:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
		wMainWindow.lblQuestionHint:SetText('  ' .. replaceCharacters(replaceCharacters(translate('txtQuestionHint'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ':')
		-- wMainWindow.lblQuestionHint:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		-- Hint time input
		wMainWindow.inptQuestionHint = Turbine.UI.Lotro.TextBox()
		wMainWindow.inptQuestionHint:SetParent(wMainWindow)
		wMainWindow.inptQuestionHint:SetPosition(guiColumnWidth + guiSpacing + guiSpacing / 2, guiCtrlHeigth * 8)
		wMainWindow.inptQuestionHint:SetSize(35, guiCtrlHeigth)
		wMainWindow.inptQuestionHint:SetMultiline(false)
		wMainWindow.inptQuestionHint:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.inptQuestionHint:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
		-- wMainWindow.inptQuestionHint:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.inptQuestionHint.FocusLost = function(Sender,Args)
				local newValue = validateNumberString(wMainWindow.inptQuestionHint:GetText(), 0, config['GAME']['QuestionTime'])
				if (newValue ~= nil) then
					config['GAME']['QuestionHint'] = newValue
				end
				wMainWindow.inptQuestionHint:SetText(tostring(config['GAME']['QuestionHint']))
				if (config['GAME']['QuestionHint'] == 1) then
					wMainWindow.lblQuestionHintAdj:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtSecond'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
				else
					wMainWindow.lblQuestionHintAdj:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtSeconds'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
				end
			end
		-- Hint time adj
		wMainWindow.lblQuestionHintAdj = Turbine.UI.Label()
		wMainWindow.lblQuestionHintAdj:SetParent(wMainWindow)
		wMainWindow.lblQuestionHintAdj:SetPosition(guiColumnWidth + guiSpacing + guiSpacing / 2 + 35, guiCtrlHeigth * 8)
		wMainWindow.lblQuestionHintAdj:SetSize(100, guiCtrlHeigth)
		wMainWindow.lblQuestionHintAdj:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.lblQuestionHintAdj:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		-- wMainWindow.lblQuestionHintAdj:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		-- Log game checkbox 
		wMainWindow.chkLogGame = Turbine.UI.Lotro.CheckBox()
		wMainWindow.chkLogGame:SetParent(wMainWindow)
		wMainWindow.chkLogGame:SetSize(20 + (#replaceCharacters(replaceCharacters(translate('txtLogGame'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) * 9), guiCtrlHeigth)
		wMainWindow.chkLogGame:SetPosition(guiWidth / 2 - wMainWindow.chkLogGame:GetWidth() / 2, guiCtrlHeigth * 9)
		wMainWindow.chkLogGame:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.chkLogGame:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		wMainWindow.chkLogGame:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtLogGame'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wMainWindow.chkLogGame:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.chkLogGame.CheckedChanged = function(Sender,Args)
				if (autoRefreshing ~= true) then -- Only use this logic when using the control manually
					if (wMainWindow.chkLogGame:IsChecked() == false) then
						config['GAME']['LogGame'] = 0
					else
						config['GAME']['LogGame'] = 1
					end
				end
			end
		-- Select quiz button
		wMainWindow.btnSelectQuiz = Turbine.UI.Lotro.Button()
		wMainWindow.btnSelectQuiz:SetParent(wMainWindow)
		wMainWindow.btnSelectQuiz:SetPosition(guiWidth / 2 - guiColumnWidth * 3/8, guiCtrlHeigth * 10)
		wMainWindow.btnSelectQuiz:SetSize(guiButtonWidth, guiCtrlHeigth)
		wMainWindow.btnSelectQuiz:SetText(replaceCharacters(replaceCharacters(translate('txtSelectQuiz'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wMainWindow.btnSelectQuiz:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.btnSelectQuiz.Click = function(sender,args)
				quizLibrary(true)
				activateWindow(wQuizLibrary, true)
			end

		-- Team Settings label
		wMainWindow.lblTeamSettings = Turbine.UI.Label()
		wMainWindow.lblTeamSettings:SetParent(wMainWindow)
		wMainWindow.lblTeamSettings:SetPosition(guiSpacing, guiCtrlHeigth * 12)
		wMainWindow.lblTeamSettings:SetWidth(wMainWindow:GetWidth() - guiSpacing / 2)
		wMainWindow.lblTeamSettings:SetForeColor(Turbine.UI.Color(1,0.843,0))
		wMainWindow.lblTeamSettings:SetFont(Turbine.UI.Lotro.Font.TrajanPro18)
		wMainWindow.lblTeamSettings:SetText(replaceCharacters(replaceCharacters(translate('txtTeamSettings'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wMainWindow.lblTeamSettings:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		-- Teams enable checkbox 
		wMainWindow.chkTeamsEnable = Turbine.UI.Lotro.CheckBox()
		wMainWindow.chkTeamsEnable:SetParent(wMainWindow)
		wMainWindow.chkTeamsEnable:SetPosition(guiSpacing * 2, guiCtrlHeigth * 13)
		wMainWindow.chkTeamsEnable:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.chkTeamsEnable:SetSize(guiWidth - guiSpacing * 3, guiCtrlHeigth)
		wMainWindow.chkTeamsEnable:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtTeamsEnable'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wMainWindow.chkTeamsEnable:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.chkTeamsEnable.CheckedChanged = function(Sender,Args)
				if (autoRefreshing ~= true) then -- Only use this logic when using the control manually
					if (wMainWindow.chkTeamsEnable:IsChecked() == false) then
						config['GAME']['TeamsEnable'] = 0
						if (config['GAME']['GameMode'] == 4) then
							config['GAME']['GameMode'] = 3
							wMainWindow.ddGameMode:SetText(strings[clientLanguage]['txtGameMode' .. tostring(config['GAME']['GameMode'])])
							wMainWindow.ddGameMode:Reset()
						end
					else
						config['GAME']['TeamsEnable'] = 1
					end
				end
			end
		-- Teams lock checkbox 
		wMainWindow.chkTeamsLock = Turbine.UI.Lotro.CheckBox()
		wMainWindow.chkTeamsLock:SetParent(wMainWindow)
		wMainWindow.chkTeamsLock:SetPosition(guiSpacing * 2, guiCtrlHeigth * 14)
		wMainWindow.chkTeamsLock:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.chkTeamsLock:SetSize(guiWidth - guiSpacing * 3, guiCtrlHeigth)
		wMainWindow.chkTeamsLock:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtTeamsLock'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wMainWindow.chkTeamsLock:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.chkTeamsLock.CheckedChanged = function(Sender,Args)
				if (autoRefreshing ~= true) then -- Only use this logic when using the control manually
					if (wMainWindow.chkTeamsLock:IsChecked() == false) then
						config['GAME']['TeamsLock'] = 0
						wMainWindow.btnManageTeams:SetEnabled(true)
					else
						config['GAME']['TeamsLock'] = 1
						wMainWindow.btnManageTeams:SetEnabled(false)
					end
				end
			end
		-- Manage Teams button
		wMainWindow.btnManageTeams = Turbine.UI.Lotro.Button()
		wMainWindow.btnManageTeams:SetParent(wMainWindow)
		wMainWindow.btnManageTeams:SetPosition(guiWidth / 2 - guiColumnWidth * 3/8, guiCtrlHeigth * 15)
		wMainWindow.btnManageTeams:SetSize(guiButtonWidth, guiCtrlHeigth)
		wMainWindow.btnManageTeams:SetText(replaceCharacters(replaceCharacters(translate('txtManageTeams'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wMainWindow.btnManageTeams:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.btnManageTeams.Click = function(sender,args)
				teamsManager(true)
				activateWindow(wTeamsManager, true)
			end

		-- Difficulty label
		wMainWindow.lblDifficulty = Turbine.UI.Label()
		wMainWindow.lblDifficulty:SetParent(wMainWindow)
		wMainWindow.lblDifficulty:SetPosition(guiSpacing, guiCtrlHeigth * 17)
		wMainWindow.lblDifficulty:SetWidth(wMainWindow:GetWidth() - guiSpacing / 2)
		wMainWindow.lblDifficulty:SetForeColor(Turbine.UI.Color(1,0.843,0))
		wMainWindow.lblDifficulty:SetFont(Turbine.UI.Lotro.Font.TrajanPro18)
		wMainWindow.lblDifficulty:SetText(replaceCharacters(replaceCharacters(translate('txtDifficulty'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wMainWindow.lblDifficulty:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		-- Ignore case checkbox 
		wMainWindow.chkIgnoreCase = Turbine.UI.Lotro.CheckBox()
		wMainWindow.chkIgnoreCase:SetParent(wMainWindow)
		wMainWindow.chkIgnoreCase:SetPosition(guiSpacing * 2, guiCtrlHeigth * 18)
		wMainWindow.chkIgnoreCase:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.chkIgnoreCase:SetSize(guiWidth - guiSpacing * 3, guiCtrlHeigth)
		wMainWindow.chkIgnoreCase:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtIgnoreCase'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wMainWindow.chkIgnoreCase:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.chkIgnoreCase.CheckedChanged = function(Sender,Args)
				if (autoRefreshing ~= true) then -- Only use this logic when using the control manually
					if (wMainWindow.chkIgnoreCase:IsChecked() == false) then
						config['DIFFICULTY']['IgnoreCase'] = 0
					else
						config['DIFFICULTY']['IgnoreCase'] = 1
					end
				end
			end
		-- Indulgent Spelling case checkbox 
		wMainWindow.chkIndulgentSpelling = Turbine.UI.Lotro.CheckBox()
		wMainWindow.chkIndulgentSpelling:SetParent(wMainWindow)
		wMainWindow.chkIndulgentSpelling:SetPosition(guiSpacing * 2, guiCtrlHeigth * 19)
		wMainWindow.chkIndulgentSpelling:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.chkIndulgentSpelling:SetSize(guiWidth - guiSpacing * 3, guiCtrlHeigth)
		wMainWindow.chkIndulgentSpelling:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtIndulgentSpelling'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wMainWindow.chkIndulgentSpelling:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.chkIndulgentSpelling.CheckedChanged = function(Sender,Args)
				if (autoRefreshing ~= true) then -- Only use this logic when using the control manually
					if (wMainWindow.chkIndulgentSpelling:IsChecked() == false) then
						config['DIFFICULTY']['IndulgentSpelling'] = 0
					else
						config['DIFFICULTY']['IndulgentSpelling'] = 1
					end
				end
			end
		-- Approximate answers checkbox 
		wMainWindow.chkApproximateAnswers = Turbine.UI.Lotro.CheckBox()
		wMainWindow.chkApproximateAnswers:SetParent(wMainWindow)
		wMainWindow.chkApproximateAnswers:SetPosition(guiSpacing * 2, guiCtrlHeigth * 20)
		wMainWindow.chkApproximateAnswers:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.chkApproximateAnswers:SetSize(guiColumnWidth - guiSpacing, guiCtrlHeigth)
		wMainWindow.chkApproximateAnswers:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtApproximateAnswers'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ':')
		-- wMainWindow.chkApproximateAnswers:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.chkApproximateAnswers.CheckedChanged = function(Sender,Args)
				if (autoRefreshing ~= true) then -- Only use this logic when using the control manually
					if (wMainWindow.chkApproximateAnswers:IsChecked() == false) then
						config['DIFFICULTY']['ApproximateAnswers'] = 0
						wMainWindow.inptProximityValue:SetEnabled(false)
					else
						config['DIFFICULTY']['ApproximateAnswers'] = 1
						wMainWindow.inptProximityValue:SetEnabled(true)
					end
				end
			end
		-- Proximity value input
		wMainWindow.inptProximityValue = Turbine.UI.Lotro.TextBox()
		wMainWindow.inptProximityValue:SetParent(wMainWindow)
		wMainWindow.inptProximityValue:SetPosition(guiColumnWidth + guiSpacing + guiSpacing / 2, guiCtrlHeigth * 20)
		wMainWindow.inptProximityValue:SetSize(35, guiCtrlHeigth)
		wMainWindow.inptProximityValue:SetMultiline(false)
		wMainWindow.inptProximityValue:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.inptProximityValue:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
		-- wMainWindow.inptProximityValue:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.inptProximityValue.FocusLost = function(Sender,Args)
				local newValue = validateNumberString(wMainWindow.inptProximityValue:GetText(), 1, 100)
				if (newValue ~= nil) then
					config['DIFFICULTY']['ProximityValue'] = newValue
				end
				wMainWindow.inptProximityValue:SetText(tostring(config['DIFFICULTY']['ProximityValue']))
			end
		if (config['DIFFICULTY']['ApproximateAnswers'] == 1) then
			wMainWindow.chkApproximateAnswers:SetChecked(true)
			wMainWindow.inptProximityValue:SetEnabled(true)
		else
			wMainWindow.chkApproximateAnswers:SetChecked(false)
			wMainWindow.inptProximityValue:SetEnabled(false)
		end
		-- Proximity value adj
		wMainWindow.lblProximityValueAdj = Turbine.UI.Label()
		wMainWindow.lblProximityValueAdj:SetParent(wMainWindow)
		wMainWindow.lblProximityValueAdj:SetPosition(guiColumnWidth + guiSpacing + guiSpacing / 2 + 35, guiCtrlHeigth * 20)
		wMainWindow.lblProximityValueAdj:SetSize(guiColumnWidth - 35 - guiSpacing * 2, guiCtrlHeigth)
		wMainWindow.lblProximityValueAdj:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.lblProximityValueAdj:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		wMainWindow.lblProximityValueAdj:SetText(replaceCharacters(replaceCharacters(translate('txtPercentAccuracy'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
		-- wMainWindow.lblProximityValueAdj:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns

		-- Scoring label
		wMainWindow.lblScoring = Turbine.UI.Label()
		wMainWindow.lblScoring:SetParent(wMainWindow)
		wMainWindow.lblScoring:SetPosition(guiSpacing, guiCtrlHeigth * 22)
		wMainWindow.lblScoring:SetWidth(wMainWindow:GetWidth() - guiSpacing / 2)
		wMainWindow.lblScoring:SetForeColor(Turbine.UI.Color(1,0.843,0))
		wMainWindow.lblScoring:SetFont(Turbine.UI.Lotro.Font.TrajanPro18)
		wMainWindow.lblScoring:SetText(replaceCharacters(replaceCharacters(translate('txtScoring'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wMainWindow.lblScoring:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		-- Score mode choice label
		wMainWindow.lblScoreMode = Turbine.UI.Label()
		wMainWindow.lblScoreMode:SetParent(wMainWindow)
		wMainWindow.lblScoreMode:SetPosition(guiSpacing * 2, guiCtrlHeigth * 23)
		wMainWindow.lblScoreMode:SetSize(guiColumnWidth - guiSpacing, guiCtrlHeigth)
		wMainWindow.lblScoreMode:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.lblScoreMode:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
		wMainWindow.lblScoreMode:SetText(replaceCharacters(replaceCharacters(translate('txtScoreMode'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ':')
		-- wMainWindow.lblScoreMode:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		-- Score mode dropdown 
		local lstScoreMode = {replaceCharacters(replaceCharacters(strings[clientLanguage]['txtScoreMode1'], nonbasicCharactersForGuiPrev), nonbasicCharactersForGui),replaceCharacters(replaceCharacters(strings[clientLanguage]['txtScoreMode2'], nonbasicCharactersForGuiPrev), nonbasicCharactersForGui),replaceCharacters(replaceCharacters(strings[clientLanguage]['txtScoreMode3'], nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)}
		wMainWindow.ddScoreMode = DropDown(lstScoreMode, replaceCharacters(replaceCharacters(strings[clientLanguage]['txtScoreMode' .. tostring(config['SCORING']['ScoreMode'])], nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wMainWindow.ddScoreMode:SetParent(wMainWindow)
		wMainWindow.ddScoreMode:SetPosition(guiColumnWidth + guiSpacing + guiSpacing / 2, guiCtrlHeigth * 23)
		wMainWindow.ddScoreMode:SetSize(guiColumnWidth, guiCtrlHeigth)
		wMainWindow.ddScoreMode:SetAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		-- wMainWindow.ddScoreMode:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.ddScoreMode.ItemChanged = function(Sender,Args)
				config['SCORING']['ScoreMode'] = Args.Index
				wMainWindow.ddScoreMode:Reset() -- Scrolls back to the top of the list
				remapShortcut(wMainWindow.qsStartGame, resetStartGameMessage())
				if (config['SCORING']['ScoreMode'] == 3) then
					wMainWindow.btnCustomScores:SetEnabled(true)
				else
					wMainWindow.btnCustomScores:SetEnabled(false)
				end
			end
		-- Custom scores button
		wMainWindow.btnCustomScores = Turbine.UI.Lotro.Button()
		wMainWindow.btnCustomScores:SetParent(wMainWindow)
		wMainWindow.btnCustomScores:SetPosition(guiWidth / 2 - guiColumnWidth * 3/8, guiCtrlHeigth * 24)
		wMainWindow.btnCustomScores:SetSize(guiButtonWidth, guiCtrlHeigth)
		wMainWindow.btnCustomScores:SetText(replaceCharacters(replaceCharacters(translate('txtCustomScores'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wMainWindow.btnCustomScores:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.btnCustomScores.Click = function(sender,args)
				customizeScores(true)
				activateWindow(wCustomizeScores, true)
			end
		if (config['SCORING']['ScoreMode'] == 3) then
			wMainWindow.btnCustomScores:SetEnabled(true)
		else
			wMainWindow.btnCustomScores:SetEnabled(false)
		end
		-- Multiple hits checkbox 
		wMainWindow.chkMultipleHits = Turbine.UI.Lotro.CheckBox()
		wMainWindow.chkMultipleHits:SetParent(wMainWindow)
		wMainWindow.chkMultipleHits:SetPosition(guiSpacing * 2, guiCtrlHeigth * 25)
		wMainWindow.chkMultipleHits:SetSize(guiWidth - guiSpacing * 3, guiCtrlHeigth)
		wMainWindow.chkMultipleHits:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.chkMultipleHits:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtMultipleHits'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wMainWindow.chkMultipleHits:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.chkMultipleHits.CheckedChanged = function(Sender,Args)
				if (autoRefreshing ~= true) then -- Only use this logic when using the control manually
					if (wMainWindow.chkMultipleHits:IsChecked() == false) then
						config['SCORING']['MultipleHits'] = 0
						wMainWindow.inptMultipleHitsTypeSpeed:SetEnabled(false)
						wMainWindow.ddMultipleHitsDivisor:SetEnabled(false)
					else
						config['SCORING']['MultipleHits'] = 1
						wMainWindow.inptMultipleHitsTypeSpeed:SetEnabled(true)
						wMainWindow.ddMultipleHitsDivisor:SetEnabled(true)
					end
				end
			end
		-- Typing threshold label
		wMainWindow.lblMultipleHitsTypeSpeed = Turbine.UI.Label()
		wMainWindow.lblMultipleHitsTypeSpeed:SetParent(wMainWindow)
		wMainWindow.lblMultipleHitsTypeSpeed:SetPosition(guiSpacing * 3, guiCtrlHeigth * 26)
		wMainWindow.lblMultipleHitsTypeSpeed:SetSize(guiColumnWidth  - guiSpacing * 2, guiCtrlHeigth)
		wMainWindow.lblMultipleHitsTypeSpeed:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.lblMultipleHitsTypeSpeed:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
		wMainWindow.lblMultipleHitsTypeSpeed:SetText('  ' .. replaceCharacters(replaceCharacters(translate('txtMultipleHitsTypeSpeed'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ':')
		-- wMainWindow.lblMultipleHitsTypeSpeed:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		-- Typing threshold input
		wMainWindow.inptMultipleHitsTypeSpeed = Turbine.UI.Lotro.TextBox()
		wMainWindow.inptMultipleHitsTypeSpeed:SetParent(wMainWindow)
		wMainWindow.inptMultipleHitsTypeSpeed:SetPosition(guiColumnWidth + guiSpacing + guiSpacing / 2, guiCtrlHeigth * 26)
		wMainWindow.inptMultipleHitsTypeSpeed:SetSize(35, guiCtrlHeigth)
		wMainWindow.inptMultipleHitsTypeSpeed:SetMultiline(false)
		wMainWindow.inptMultipleHitsTypeSpeed:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.inptMultipleHitsTypeSpeed:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
		-- wMainWindow.inptMultipleHitsTypeSpeed:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.inptMultipleHitsTypeSpeed.FocusLost = function(Sender,Args)
				local newValue = validateNumberString(wMainWindow.inptMultipleHitsTypeSpeed:GetText(), 1, 100)
				if (newValue ~= nil) then
					config['SCORING']['MultipleHitsTypeSpeed'] = newValue
				end
				wMainWindow.inptMultipleHitsTypeSpeed:SetText(tostring(config['SCORING']['MultipleHitsTypeSpeed']))
			end
		-- Tyiping threshold adj
		wMainWindow.lblMultipleHitsTypeSpeedAdj = Turbine.UI.Label()
		wMainWindow.lblMultipleHitsTypeSpeedAdj:SetParent(wMainWindow)
		wMainWindow.lblMultipleHitsTypeSpeedAdj:SetPosition(guiColumnWidth + guiSpacing + guiSpacing / 2 + 35, guiCtrlHeigth * 26)
		wMainWindow.lblMultipleHitsTypeSpeedAdj:SetSize(100, guiCtrlHeigth)
		wMainWindow.lblMultipleHitsTypeSpeedAdj:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.lblMultipleHitsTypeSpeedAdj:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		wMainWindow.lblMultipleHitsTypeSpeedAdj:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtMultipleHitsTypeSpeedAdj'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
		-- wMainWindow.lblMultipleHitsTypeSpeedAdj:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		-- Multiple hits divisor label
		wMainWindow.lblMultipleHitsDivisor = Turbine.UI.Label()
		wMainWindow.lblMultipleHitsDivisor:SetParent(wMainWindow)
		wMainWindow.lblMultipleHitsDivisor:SetPosition(guiSpacing * 3, guiCtrlHeigth * 27)
		wMainWindow.lblMultipleHitsDivisor:SetSize(guiColumnWidth  - guiSpacing * 2, guiCtrlHeigth)
		wMainWindow.lblMultipleHitsDivisor:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMainWindow.lblMultipleHitsDivisor:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
		wMainWindow.lblMultipleHitsDivisor:SetText('  ' .. replaceCharacters(replaceCharacters(translate('txtMultipleHitsDivisor'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ':')
		-- wMainWindow.lblMultipleHitsDivisor:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		-- Multiple hits divisor dropdown 
		local lstMultipleHitsDivisor = {replaceCharacters(replaceCharacters(strings[clientLanguage]['txtMultipleHitsDivisor1'], nonbasicCharactersForGuiPrev), nonbasicCharactersForGui),replaceCharacters(replaceCharacters(strings[clientLanguage]['txtMultipleHitsDivisor2'], nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)}
		wMainWindow.ddMultipleHitsDivisor = DropDown(lstMultipleHitsDivisor, replaceCharacters(replaceCharacters(strings[clientLanguage]['txtMultipleHitsDivisor' .. tostring(config['SCORING']['MultipleHitsDivisor'])], nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wMainWindow.ddMultipleHitsDivisor:SetParent(wMainWindow)
		wMainWindow.ddMultipleHitsDivisor:SetPosition(guiColumnWidth + guiSpacing + guiSpacing / 2, guiCtrlHeigth * 27)
		wMainWindow.ddMultipleHitsDivisor:SetSize(guiColumnWidth, guiCtrlHeigth)
		wMainWindow.ddMultipleHitsDivisor:SetAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		-- wMainWindow.ddMultipleHitsDivisor:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.ddMultipleHitsDivisor:SetEnabled(true)
		wMainWindow.ddMultipleHitsDivisor.ItemChanged = function(Sender,Args)
				config['SCORING']['MultipleHitsDivisor'] = Args.Index
				wMainWindow.ddMultipleHitsDivisor:Reset() -- Scrolls back to the top of the list
			end
		if (config['SCORING']['MultipleHits'] == 1) then
			wMainWindow.chkMultipleHits:SetChecked(true)
			wMainWindow.inptMultipleHitsTypeSpeed:SetEnabled(true)
			wMainWindow.ddMultipleHitsDivisor:SetEnabled(true)
		else
			wMainWindow.chkMultipleHits:SetChecked(false)
			wMainWindow.inptMultipleHitsTypeSpeed:SetEnabled(false)
			wMainWindow.ddMultipleHitsDivisor:SetEnabled(false)
		end
		refreshMainGui()

		-- Game controls label
		wMainWindow.lblGameControls = Turbine.UI.Label()
		wMainWindow.lblGameControls:SetParent(wMainWindow)
		wMainWindow.lblGameControls:SetPosition(guiSpacing, guiCtrlHeigth * 29)
		wMainWindow.lblGameControls:SetWidth(wMainWindow:GetWidth() - guiSpacing / 2)
		wMainWindow.lblGameControls:SetForeColor(Turbine.UI.Color(1,0.843,0))
		wMainWindow.lblGameControls:SetFont(Turbine.UI.Lotro.Font.TrajanPro18)
		wMainWindow.lblGameControls:SetText(replaceCharacters(replaceCharacters(translate('txtGameControls'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wMainWindow.lblGameControls:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		-- Start game quickslot		
		wMainWindow.qsStartGame = Turbine.UI.Lotro.Quickslot()
		wMainWindow.qsStartGame:SetParent(wMainWindow)
		wMainWindow.qsStartGame:SetSize(guiButtonWidth, guiCtrlHeigth)
		wMainWindow.qsStartGame:SetPosition(guiWidth / 2 - guiButtonWidth - guiSpacing / 2, guiCtrlHeigth * 30)
		wMainWindow.qsStartGame:SetUseOnRightClick(false)
		local startChatCommand = resetStartGameMessage()
		wMainWindow.qsStartGame:SetShortcut(Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, startChatCommand))
		wMainWindow.qsStartGame.ShortcutData = startChatCommand -- Prevent drop over itself bug, step 1
		wMainWindow.qsStartGame:SetAllowDrop(false)
		wMainWindow.qsStartGame.DragDrop = function()
				-- Prevent drop over itself bug, step 2
				local sc = Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '')
				sc:SetData(wMainWindow.qsStartGame.ShortcutData)
				wMainWindow.qsStartGame:SetShortcut(sc)
			end
		wMainWindow.qsStartGame.MouseClick = function()
				dataManagement(config, 'Save', 'Istelien_config') -- Save options
				dataManagement(gameParticipants, 'Save', 'Istelien_participants')
				quizLibrary(false)
				customizeScores(false)
				teamsManager(false)
				startGame() -- Turns gameState to 1
			end
		wMainWindow.qsStartGame:SetEnabled(true)
		wMainWindow.qsStartGame:SetVisible(true)
		wMainWindow.qsStartGame:SetZOrder(110) -- For some alien reason if I don't specify it to be above the window it's not usable.
		wMainWindow.btnStartGame = createOverlayButton(wMainWindow.qsStartGame, wMainWindow, replaceCharacters(replaceCharacters(translate('txtStartGame'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui), wMainWindow.qsStartGame:GetLeft(), wMainWindow.qsStartGame:GetTop(), wMainWindow.qsStartGame:GetWidth(), wMainWindow.qsStartGame:GetHeight(), wMainWindow.qsStartGame:GetZOrder() + 10, 2) -- Although named "btn" what we get is really the generic control parent to graphics and text that does the appareance trick
		wMainWindow.btnStartGame:SetEnabled(true)
		wMainWindow.btnStartGame:SetVisible(true)
		-- Pause game quickslot		
		wMainWindow.qsPauseGame = Turbine.UI.Lotro.Quickslot()
		wMainWindow.qsPauseGame:SetParent(wMainWindow)
		wMainWindow.qsPauseGame:SetSize(guiButtonWidth, guiCtrlHeigth)
		wMainWindow.qsPauseGame:SetPosition(guiWidth / 2 - guiButtonWidth - guiSpacing / 2, guiCtrlHeigth * 30)
		wMainWindow.qsPauseGame:SetUseOnRightClick(false)
		local pauseChatCommand = sendToChat(replaceCharacters(replaceCharacters(translate('msgPausingGame'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ' - ' .. replaceCharacters(replaceCharacters(translate('msgAwaitingResume'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.', config['GAME']['GameChannel'], '', true)
		wMainWindow.qsPauseGame:SetShortcut(Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, pauseChatCommand))
		wMainWindow.qsPauseGame.ShortcutData = pauseChatCommand -- Prevent drop over itself bug, step 1
		wMainWindow.qsPauseGame:SetAllowDrop(false)
		wMainWindow.qsPauseGame.DragDrop = function()
				-- Prevent drop over itself bug, step 2
				local sc = Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '')
				sc:SetData(wMainWindow.qsPauseGame.ShortcutData)
				wMainWindow.qsPauseGame:SetShortcut(sc)
			end
		wMainWindow.qsPauseGame.MouseClick = function()
				pauseGame()	-- Turns gameState to 2
			end
		wMainWindow.qsPauseGame:SetEnabled(false)
		wMainWindow.qsPauseGame:SetVisible(false)
		wMainWindow.qsPauseGame:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.btnPauseGame = createOverlayButton(wMainWindow.qsPauseGame, wMainWindow, replaceCharacters(replaceCharacters(translate('txtPauseGame'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui), wMainWindow.qsPauseGame:GetLeft(), wMainWindow.qsPauseGame:GetTop(), wMainWindow.qsPauseGame:GetWidth(), wMainWindow.qsPauseGame:GetHeight(), wMainWindow.qsPauseGame:GetZOrder() + 10, 2) -- Although named "btn" what we get is really the generic control parent to graphics and text that does the appareance trick
		wMainWindow.btnPauseGame:SetEnabled(false)
		wMainWindow.btnPauseGame:SetVisible(false)
		-- Resume game quickslot		
		wMainWindow.qsResumeGame = Turbine.UI.Lotro.Quickslot()
		wMainWindow.qsResumeGame:SetParent(wMainWindow)
		wMainWindow.qsResumeGame:SetSize(guiButtonWidth, guiCtrlHeigth)
		wMainWindow.qsResumeGame:SetPosition(guiWidth / 2 - guiButtonWidth - guiSpacing / 2, guiCtrlHeigth * 30)
		wMainWindow.qsResumeGame:SetUseOnRightClick(false)
		local resumeChatCommand = sendToChat(replaceCharacters(replaceCharacters(translate('msgResumingGame'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ' - ' .. replaceCharacters(replaceCharacters(translate('msgContinuePlaying'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.', config['GAME']['GameChannel'], '', true)
		wMainWindow.qsResumeGame:SetShortcut(Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, resumeChatCommand))
		wMainWindow.qsResumeGame.ShortcutData = resumeChatCommand -- Prevent drop over itself bug, step 1
		wMainWindow.qsResumeGame:SetAllowDrop(false)
		wMainWindow.qsResumeGame.DragDrop = function()
				-- Prevent drop over itself bug, step 2
				local sc = Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '')
				sc:SetData(wMainWindow.qsResumeGame.ShortcutData)
				wMainWindow.qsResumeGame:SetShortcut(sc)
			end
		wMainWindow.qsResumeGame.MouseClick = function()
				resumeGame()	-- Turns gameState to 1
			end
		wMainWindow.qsResumeGame:SetEnabled(false)
		wMainWindow.qsResumeGame:SetVisible(false)
		wMainWindow.qsResumeGame:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.btnResumeGame = createOverlayButton(wMainWindow.qsResumeGame, wMainWindow, replaceCharacters(replaceCharacters(translate('txtResumeGame'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui), wMainWindow.qsResumeGame:GetLeft(), wMainWindow.qsResumeGame:GetTop(), wMainWindow.qsResumeGame:GetWidth(), wMainWindow.qsResumeGame:GetHeight(), wMainWindow.qsResumeGame:GetZOrder() + 10, 2) -- Although named "btn" what we get is really the generic control parent to graphics and text that does the appareance trick
		wMainWindow.btnResumeGame:SetEnabled(false)
		wMainWindow.btnResumeGame:SetVisible(false)
		-- Resume From Save quickslot		
		wMainWindow.qsResumeFromSave = Turbine.UI.Lotro.Quickslot()
		wMainWindow.qsResumeFromSave:SetParent(wMainWindow)
		wMainWindow.qsResumeFromSave:SetSize(guiButtonWidth, guiCtrlHeigth)
		wMainWindow.qsResumeFromSave:SetPosition(guiWidth / 2 - guiButtonWidth - guiSpacing / 2, guiCtrlHeigth * 30)
		wMainWindow.qsResumeFromSave:SetUseOnRightClick(false)
		local resumeChatCommand = sendToChat(replaceCharacters(replaceCharacters(translate('msgStartingGameSaved'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ' - ' .. replaceCharacters(replaceCharacters(translate('msgContinuePlaying'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.', config['GAME']['GameChannel'], '', true)
		wMainWindow.qsResumeFromSave:SetShortcut(Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, resumeChatCommand))
		wMainWindow.qsResumeFromSave.ShortcutData = resumeChatCommand -- Prevent drop over itself bug, step 1
		wMainWindow.qsResumeFromSave:SetAllowDrop(false)
		wMainWindow.qsResumeFromSave.DragDrop = function()
				-- Prevent drop over itself bug, step 2
				local sc = Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '')
				sc:SetData(wMainWindow.qsResumeFromSave.ShortcutData)
				wMainWindow.qsResumeFromSave:SetShortcut(sc)
			end
		wMainWindow.qsResumeFromSave.MouseClick = function()
				resumeGame()	-- Turns gameState to 1
			end
		wMainWindow.qsResumeFromSave:SetEnabled(false)
		wMainWindow.qsResumeFromSave:SetVisible(false)
		wMainWindow.qsResumeFromSave:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.btnResumeFromSave = createOverlayButton(wMainWindow.qsResumeFromSave, wMainWindow, replaceCharacters(replaceCharacters(translate('txtResumeFromSave'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui), wMainWindow.qsResumeFromSave:GetLeft(), wMainWindow.qsResumeFromSave:GetTop(), wMainWindow.qsResumeFromSave:GetWidth(), wMainWindow.qsResumeFromSave:GetHeight(), wMainWindow.qsResumeFromSave:GetZOrder() + 10, 2) -- Although named "btn" what we get is really the generic control parent to graphics and text that does the appareance trick
		wMainWindow.btnResumeFromSave:SetEnabled(false)
		wMainWindow.btnResumeFromSave:SetVisible(false)
		-- End game button
		wMainWindow.btnEndGame = Turbine.UI.Lotro.Button()
		wMainWindow.btnEndGame:SetParent(wMainWindow)
		wMainWindow.btnEndGame:SetPosition(guiWidth / 2 + guiSpacing / 2, guiCtrlHeigth * 30)
		wMainWindow.btnEndGame:SetSize(guiButtonWidth, guiCtrlHeigth)
		wMainWindow.btnEndGame:SetEnabled(false)
		wMainWindow.btnEndGame:SetText(replaceCharacters(replaceCharacters(translate('txtEndGame'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wMainWindow.btnEndGame:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.btnEndGame.Click = function(sender,args)
				wMainWindow.btnEndGame:SetEnabled(false) -- First of all, prevent another click
				if (gameState == 1) then
					if (questionState == 0) then -- There's no question running. Trigger the whole End Game process
						endGame()
					else -- Just overrrides gameState to wait for the question cycle to finish and trigger end game by preQuestion().
						gameState = 0
						wMainWindow.qsStartGame:SetEnabled(true)
					end
				else
					if (gameState == 2) then  -- Game is paused. Trigger the whole End Game process
						endGame()
					end
				end
			end
		-- Load/Save button
		wMainWindow.btnLoadSave = Turbine.UI.Lotro.Button()
		wMainWindow.btnLoadSave:SetParent(wMainWindow)
		wMainWindow.btnLoadSave:SetPosition(guiWidth / 2 - guiButtonWidth - guiSpacing / 2, guiCtrlHeigth * 31)
		wMainWindow.btnLoadSave:SetSize(guiButtonWidth, guiCtrlHeigth)
		wMainWindow.btnLoadSave:SetEnabled(true)
		wMainWindow.btnLoadSave:SetText(replaceCharacters(replaceCharacters(translate('txtLoadGame'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wMainWindow.btnLoadSave:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.btnLoadSave.Click = function(sender,args)
				if (gameState ~= 2) then
					savedGames(true, 'Load')
				else
					savedGames(true, 'Save')				
				end
				activateWindow(wSavedGames, true)
			end
		-- Announce Scores button. Hidden by default
		wMainWindow.btnAnnounceScores = Turbine.UI.Lotro.Button()
		wMainWindow.btnAnnounceScores:SetParent(wMainWindow)
		wMainWindow.btnAnnounceScores:SetPosition(guiWidth / 2 + guiSpacing / 2, guiCtrlHeigth * 31)
		wMainWindow.btnAnnounceScores:SetSize(guiButtonWidth, guiCtrlHeigth)
		wMainWindow.btnAnnounceScores:SetEnabled(false)
		wMainWindow.btnAnnounceScores:SetText(replaceCharacters(replaceCharacters(translate('txtAnnounceScores'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wMainWindow.btnAnnounceScores:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.btnAnnounceScores.Click = function(sender,args)
				shareResults(true)
				activateWindow(wShareResults, true)
			end
		wMainWindow.btnAnnounceScores:SetVisible(false)
		-- Acknowledge Command quickslot
		wMainWindow.qsAckCommand = Turbine.UI.Lotro.Quickslot()
		wMainWindow.qsAckCommand:SetParent(wMainWindow)
		wMainWindow.qsAckCommand:SetSize(guiButtonWidth, guiCtrlHeigth)
		wMainWindow.qsAckCommand:SetPosition(guiWidth / 2 - guiButtonWidth - guiSpacing / 2, guiCtrlHeigth * 32)
		wMainWindow.qsAckCommand:SetUseOnRightClick(false)
		wMainWindow.qsAckCommand:SetShortcut(Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '/dance'))
		wMainWindow.qsAckCommand.ShortcutData = '/dance' -- Prevent drop over itself bug, step 1
		wMainWindow.qsAckCommand:SetAllowDrop(false)
		wMainWindow.qsAckCommand.DragDrop = function()
				-- Prevent drop over itself bug, step 2
				local sc = Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '')
				sc:SetData(wMainWindow.qsAckCommand.ShortcutData)
				wMainWindow.qsAckCommand:SetShortcut(sc)
			end
		wMainWindow.qsAckCommand.MouseClick = function()
				wMainWindow.qsAckCommand:SetEnabled(false)
				wMainWindow.qsAckCommand:SetVisible(false)
				wMainWindow.btnAckCommand:SetEnabled(false)
				wMainWindow.btnAckCommand:SetVisible(false)
			end
		wMainWindow.qsAckCommand:SetEnabled(false)
		wMainWindow.qsAckCommand:SetVisible(false)
		-- wMainWindow.qsAckCommand:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.btnAckCommand = createOverlayButton(wMainWindow.qsAckCommand, wMainWindow, replaceCharacters(replaceCharacters(translate('txtAckCommand'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui), wMainWindow.qsAckCommand:GetLeft(), wMainWindow.qsAckCommand:GetTop(), wMainWindow.qsAckCommand:GetWidth(), wMainWindow.qsAckCommand:GetHeight(), wMainWindow.qsAckCommand:GetZOrder() + 10, 1) -- Although named "btn" what we get is really the generic control parent to graphics and text that does the appareance trick
		wMainWindow.btnAckCommand:SetEnabled(false)
		wMainWindow.btnAckCommand:SetVisible(false)
		-- Master scorer button. Hidden by default
		wMainWindow.btnMasterScorer = Turbine.UI.Lotro.Button()
		wMainWindow.btnMasterScorer:SetParent(wMainWindow)
		wMainWindow.btnMasterScorer:SetPosition(guiWidth / 2 + guiSpacing / 2, guiCtrlHeigth * 32)
		wMainWindow.btnMasterScorer:SetSize(guiButtonWidth, guiCtrlHeigth)
		wMainWindow.btnMasterScorer:SetEnabled(false)
		wMainWindow.btnMasterScorer:SetText(replaceCharacters(replaceCharacters(translate('txtMasterScorer'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wMainWindow.btnMasterScorer:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.btnMasterScorer.Click = function(sender,args)
				masterScorer(true)
				activateWindow(wMasterScorer, true)
			end
		wMainWindow.btnMasterScorer:SetVisible(false)
		-- Point Gift button. Hidden by default
		wMainWindow.btnPointGift = Turbine.UI.Lotro.Button()
		wMainWindow.btnPointGift:SetParent(wMainWindow)
		wMainWindow.btnPointGift:SetPosition(guiWidth / 2 - guiButtonWidth - guiSpacing / 2, guiCtrlHeigth * 33)
		wMainWindow.btnPointGift:SetSize(guiButtonWidth, guiCtrlHeigth)
		wMainWindow.btnPointGift:SetEnabled(false)
		wMainWindow.btnPointGift:SetText(replaceCharacters(replaceCharacters(translate('txtPointGift'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wMainWindow.btnPointGift:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.btnPointGift.Click = function(sender,args)
				pointGift(true)
				activateWindow(wPointGift, true)
			end
		wMainWindow.btnPointGift:SetVisible(false)
		-- Provide Hint quickslot
		wMainWindow.qsProvideHint = Turbine.UI.Lotro.Quickslot()
		wMainWindow.qsProvideHint:SetParent(wMainWindow)
		wMainWindow.qsProvideHint:SetSize(guiButtonWidth, guiCtrlHeigth)
		wMainWindow.qsProvideHint:SetPosition(guiWidth / 2 + guiSpacing / 2, guiCtrlHeigth * 33)
		wMainWindow.qsProvideHint:SetUseOnRightClick(false)
		wMainWindow.qsProvideHint:SetShortcut(Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '/dance'))
		wMainWindow.qsProvideHint.ShortcutData = '/dance' -- Prevent drop over itself bug, step 1
		wMainWindow.qsProvideHint:SetAllowDrop(false)
		wMainWindow.qsProvideHint.DragDrop = function()
				-- Prevent drop over itself bug, step 2
				local sc = Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '')
				sc:SetData(wMainWindow.qsProvideHint.ShortcutData)
				wMainWindow.qsProvideHint:SetShortcut(sc)
			end
		wMainWindow.qsProvideHint:SetEnabled(false)
		wMainWindow.qsProvideHint:SetVisible(false)
		-- wMainWindow.qsProvideHint:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.btnProvideHint = createOverlayButton(wMainWindow.qsProvideHint, wMainWindow, replaceCharacters(replaceCharacters(translate('txtProvideHint'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui), wMainWindow.qsProvideHint:GetLeft(), wMainWindow.qsProvideHint:GetTop(), wMainWindow.qsProvideHint:GetWidth(), wMainWindow.qsProvideHint:GetHeight(), wMainWindow.qsProvideHint:GetZOrder() + 10, 1) -- Although named "btn" what we get is really the generic control parent to graphics and text that does the appareance trick
		wMainWindow.btnProvideHint:SetEnabled(false)
		wMainWindow.btnProvideHint:SetVisible(false)
		-- End Question quickslot
		wMainWindow.qsEndQuestion = Turbine.UI.Lotro.Quickslot()
		wMainWindow.qsEndQuestion:SetParent(wMainWindow)
		wMainWindow.qsEndQuestion:SetSize(guiButtonWidth, guiCtrlHeigth)
		wMainWindow.qsEndQuestion:SetPosition(guiWidth / 2 - guiButtonWidth - guiSpacing / 2, guiCtrlHeigth * 34)
		wMainWindow.qsEndQuestion:SetUseOnRightClick(false)
		wMainWindow.qsEndQuestion:SetShortcut(Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '/dance'))
		wMainWindow.qsEndQuestion.ShortcutData = '/dance' -- Prevent drop over itself bug, step 1
		wMainWindow.qsEndQuestion:SetAllowDrop(false)
		wMainWindow.qsEndQuestion.DragDrop = function()
				-- Prevent drop over itself bug, step 2
				local sc = Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '')
				sc:SetData(wMainWindow.qsEndQuestion.ShortcutData)
				wMainWindow.qsEndQuestion:SetShortcut(sc)
			end
		wMainWindow.qsEndQuestion.MouseClick = function()
				-- Code to Skip Question
				endQuestion()
			end
		wMainWindow.qsEndQuestion:SetEnabled(false)
		wMainWindow.qsEndQuestion:SetVisible(false)
		-- wMainWindow.qsEndQuestion:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.btnEndQuestion = createOverlayButton(wMainWindow.qsEndQuestion, wMainWindow, replaceCharacters(replaceCharacters(translate('txtEndQuestion'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui), wMainWindow.qsEndQuestion:GetLeft(), wMainWindow.qsEndQuestion:GetTop(), wMainWindow.qsEndQuestion:GetWidth(), wMainWindow.qsEndQuestion:GetHeight(), wMainWindow.qsEndQuestion:GetZOrder() + 10, 2) -- Although named "btn" what we get is really the generic control parent to graphics and text that does the appareance trick
		wMainWindow.btnEndQuestion:SetEnabled(false)
		wMainWindow.btnEndQuestion:SetVisible(false)
		-- Ask Question quickslot
		wMainWindow.qsAskQuestion = Turbine.UI.Lotro.Quickslot()
		wMainWindow.qsAskQuestion:SetParent(wMainWindow)
		wMainWindow.qsAskQuestion:SetSize(guiButtonWidth, guiCtrlHeigth)
		wMainWindow.qsAskQuestion:SetPosition(guiWidth / 2 + guiSpacing / 2, guiCtrlHeigth * 34)
		wMainWindow.qsAskQuestion:SetUseOnRightClick(false)
		wMainWindow.qsAskQuestion:SetShortcut(Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '/dance'))
		wMainWindow.qsAskQuestion.ShortcutData = '/dance' -- Prevent drop over itself bug, step 1
		wMainWindow.qsAskQuestion:SetAllowDrop(false)
		wMainWindow.qsAskQuestion.DragDrop = function()
				-- Prevent drop over itself bug, step 2
				local sc = Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '')
				sc:SetData(wMainWindow.qsAskQuestion.ShortcutData)
				wMainWindow.qsAskQuestion:SetShortcut(sc)
			end
		wMainWindow.qsAskQuestion.MouseClick = function()
				wMainWindow.qsAskQuestion:SetEnabled(false)
				wMainWindow.qsAskQuestion:SetVisible(false)
				wMainWindow.btnAskQuestion:SetEnabled(false)
				wMainWindow.btnAskQuestion:SetVisible(false)
				askQuestion()
			end
		wMainWindow.qsAskQuestion:SetEnabled(false)
		wMainWindow.qsAskQuestion:SetVisible(false)
		-- wMainWindow.qsAskQuestion:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.btnAskQuestion = createOverlayButton(wMainWindow.qsAskQuestion, wMainWindow, replaceCharacters(replaceCharacters(translate('txtAskQuestion'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui), wMainWindow.qsAskQuestion:GetLeft(), wMainWindow.qsAskQuestion:GetTop(), wMainWindow.qsAskQuestion:GetWidth(), wMainWindow.qsAskQuestion:GetHeight(), wMainWindow.qsAskQuestion:GetZOrder() + 10) -- Although named "btn" what we get is really the generic control parent to graphics and text that does the appareance trick
		wMainWindow.btnAskQuestion:SetEnabled(false)
		wMainWindow.btnAskQuestion:SetVisible(false)
		-- Wrap Question quickslot
		wMainWindow.qsWrapQuestion = Turbine.UI.Lotro.Quickslot()
		wMainWindow.qsWrapQuestion:SetParent(wMainWindow)
		wMainWindow.qsWrapQuestion:SetSize(guiButtonWidth, guiCtrlHeigth)
		wMainWindow.qsWrapQuestion:SetPosition(guiWidth / 2 + guiSpacing / 2, guiCtrlHeigth * 34)
		wMainWindow.qsWrapQuestion:SetUseOnRightClick(false)
		wMainWindow.qsWrapQuestion:SetShortcut(Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '/dance'))
		wMainWindow.qsWrapQuestion.ShortcutData = '/dance' -- Prevent drop over itself bug, step 1
		wMainWindow.qsWrapQuestion:SetAllowDrop(false)
		wMainWindow.qsWrapQuestion.DragDrop = function()
				-- Prevent drop over itself bug, step 2
				local sc = Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '')
				sc:SetData(wMainWindow.qsWrapQuestion.ShortcutData)
				wMainWindow.qsWrapQuestion:SetShortcut(sc)
			end
		wMainWindow.qsWrapQuestion.MouseClick = function()
				questionScoresPrinted = true
				wMainWindow.qsWrapQuestion:SetEnabled(false)
				wMainWindow.qsWrapQuestion:SetVisible(false)
				wMainWindow.btnWrapQuestion:SetEnabled(false)
				wMainWindow.btnWrapQuestion:SetVisible(false)
				preQuestion()
			end
		wMainWindow.qsWrapQuestion:SetEnabled(false)
		wMainWindow.qsWrapQuestion:SetVisible(false)
		-- wMainWindow.qsWrapQuestion:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns
		wMainWindow.btnWrapQuestion = createOverlayButton(wMainWindow.qsWrapQuestion, wMainWindow, replaceCharacters(replaceCharacters(translate('txtWrapQuestion'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui), wMainWindow.qsWrapQuestion:GetLeft(), wMainWindow.qsWrapQuestion:GetTop(), wMainWindow.qsWrapQuestion:GetWidth(), wMainWindow.qsWrapQuestion:GetHeight(), wMainWindow.qsWrapQuestion:GetZOrder() + 10) -- Although named "btn" what we get is really the generic control parent to graphics and text that does the appareance trick
		wMainWindow.btnWrapQuestion:SetEnabled(false)
		wMainWindow.btnWrapQuestion:SetVisible(false)

		-- Copyright label. Bottom right of the window.
		wMainWindow.lblCopyright = Turbine.UI.Label()
		wMainWindow.lblCopyright:SetParent(wMainWindow)
		wMainWindow.lblCopyright:SetPosition(guiWidth - guiColumnWidth - guiSpacing * 3, guiCtrlHeigth * 33)
		wMainWindow.lblCopyright:SetSize(guiColumnWidth + guiSpacing, guiCtrlHeigth)
		wMainWindow.lblCopyright:SetFont(Turbine.UI.Lotro.Font.LucidaConsole12)
		wMainWindow.lblCopyright:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
		wMainWindow.lblCopyright:SetText('\194\169 2023-2024 Alejandro Meirinhos')
		-- wMainWindow.lblCopyright:SetZOrder(110) -- Disabling because cannot set ZOrder in dropdowns

		function wMainWindow:Closing(sender,args)
			dataManagement(config, 'Save', 'Istelien_config') -- Save options on close
			dataManagement(gameParticipants, 'Save', 'Istelien_participants')
			savePosition(wMainWindow, 'MainWindow', wMainWindow:GetLeft(), wMainWindow:GetTop())
		end
	else -- Destroy
		if (wMainWindow ~= nil) then
			wMainWindow:Close()
			wMainWindow = nil
		end
	end

end

-- Update the values shown in the main window with the live settings
autoRefreshing = false -- Flag needed to prevent a catch-22 on how checkbox changes are handled. Need this to be outside of functions
function refreshMainGui()
	autoRefreshing = true
	if (wMainWindow ~= nil) then
		wMainWindow.ddGameChannel:SetText(config['GAME']['GameChannel'])
		wMainWindow.ddGameMode:SetText(strings[clientLanguage]['txtGameMode' .. tostring(config['GAME']['GameMode'])])
		wMainWindow.inptGameTarget:SetText(tostring(config['GAME']['GameTarget']))
		local gameTargetType = ''
		if (config['GAME']['GameMode'] == 1) then
			if (config['GAME']['GameTarget'] == 1) then
				gameTargetType = replaceCharacters(replaceCharacters(translate('txtQuestion'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
			else
				gameTargetType = replaceCharacters(replaceCharacters(translate('txtQuestions'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
			end
		else
			if (config['GAME']['GameMode'] == 2) then
				if (config['GAME']['GameTarget'] == 1) then
					gameTargetType = replaceCharacters(replaceCharacters(translate('txtMinute'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
				else
					gameTargetType = replaceCharacters(replaceCharacters(translate('txtMinutes'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
				end
			else
				if (config['GAME']['GameTarget'] == 1) then
					gameTargetType = replaceCharacters(replaceCharacters(translate('txtPoint'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
				else
					gameTargetType = replaceCharacters(replaceCharacters(translate('txtPoints'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
				end
			end
		end
		wMainWindow.lblGameTargetAdj:SetText(' ' .. gameTargetType .. '.')
		wMainWindow.ddQuestionMode:SetText(strings[clientLanguage]['txtQuestionMode' .. tostring(config['GAME']['QuestionMode'])])
		wMainWindow.inptQuestionTime:SetText(tostring(config['GAME']['QuestionTime']))
		if (config['GAME']['QuestionTime'] == 1) then
			wMainWindow.lblQuestionTimeAdj:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtSecond'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
		else
			wMainWindow.lblQuestionTimeAdj:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtSeconds'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
		end
		wMainWindow.inptQuestionHint:SetText(tostring(config['GAME']['QuestionHint']))
		if (config['GAME']['QuestionHint'] == 1) then
			wMainWindow.lblQuestionHintAdj:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtSecond'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
		else
			wMainWindow.lblQuestionHintAdj:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtSeconds'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
		end
		if (config['GAME']['LogGame'] == 1) then
			wMainWindow.chkLogGame:SetChecked(true)
		else
			wMainWindow.chkLogGame:SetChecked(false)
		end
		if (config['GAME']['TeamsEnable'] == 1) then
			wMainWindow.chkTeamsEnable:SetChecked(true)
		else
			wMainWindow.chkTeamsEnable:SetChecked(false)
		end
		if (config['GAME']['TeamsLock'] == 1) then
			wMainWindow.chkTeamsLock:SetChecked(true)
		else
			wMainWindow.chkTeamsLock:SetChecked(false)
		end
		if (config['GAME']['TeamsLock'] == 1) then
			wMainWindow.btnManageTeams:SetEnabled(false)
		else
			wMainWindow.btnManageTeams:SetEnabled(true)
		end
		if (config['DIFFICULTY']['IgnoreCase'] == 1) then
			wMainWindow.chkIgnoreCase:SetChecked(true)
		else
			wMainWindow.chkIgnoreCase:SetChecked(false)
		end
		if (config['DIFFICULTY']['IndulgentSpelling'] == 1) then
			wMainWindow.chkIndulgentSpelling:SetChecked(true)
		else
			wMainWindow.chkIndulgentSpelling:SetChecked(false)
		end
		if (config['DIFFICULTY']['ApproximateAnswers'] == 1) then
			wMainWindow.chkApproximateAnswers:SetChecked(true)
		else
			wMainWindow.chkApproximateAnswers:SetChecked(false)
		end
		wMainWindow.inptProximityValue:SetText(tostring(config['DIFFICULTY']['ProximityValue']))
		wMainWindow.ddScoreMode:SetText(strings[clientLanguage]['txtScoreMode' .. tostring(config['SCORING']['ScoreMode'])])
		if (config['SCORING']['MultipleHits'] == 1) then
			wMainWindow.chkMultipleHits:SetChecked(true)
		else
			wMainWindow.chkMultipleHits:SetChecked(false)
		end
		wMainWindow.inptMultipleHitsTypeSpeed:SetText(tostring(config['SCORING']['MultipleHitsTypeSpeed']))
		wMainWindow.ddMultipleHitsDivisor:SetText(strings[clientLanguage]['txtMultipleHitsDivisor' .. tostring(config['SCORING']['MultipleHitsDivisor'])])
	end
	autoRefreshing = false
end

-- Lock or unlock options to avoid changes during gameplay)
function lockMainGui(lock)
	local enabledColor  = Turbine.UI.Color(1, 1, 1) -- White
	local disabledColor = Turbine.UI.Color(0.259, 0.259, 0.259) -- Very Dark Grey
	if (lock == true) then
		wMainWindow.lblGameChannel:SetForeColor(disabledColor)
		wMainWindow.ddGameChannel:SetEnabled(false)
		wMainWindow.lblGameMode:SetForeColor(disabledColor)
		wMainWindow.ddGameMode:SetEnabled(false)
		wMainWindow.lblGameTarget:SetForeColor(disabledColor)
		wMainWindow.inptGameTarget:SetEnabled(false)
		wMainWindow.lblGameTargetAdj:SetForeColor(disabledColor)
		wMainWindow.lblQuestionMode:SetForeColor(disabledColor)
		wMainWindow.ddQuestionMode:SetEnabled(false)
		wMainWindow.lblQuestionTime:SetForeColor(disabledColor)
		wMainWindow.inptQuestionTime:SetEnabled(false)
		wMainWindow.lblQuestionTimeAdj:SetForeColor(disabledColor)
		wMainWindow.lblQuestionHint:SetForeColor(disabledColor)
		wMainWindow.inptQuestionHint:SetEnabled(false)
		wMainWindow.lblQuestionHintAdj:SetForeColor(disabledColor)
		wMainWindow.chkLogGame:SetEnabled(false)
		wMainWindow.chkLogGame:SetForeColor(disabledColor)
		wMainWindow.btnSelectQuiz:SetEnabled(false)
		wMainWindow.chkTeamsEnable:SetEnabled(false)
		wMainWindow.chkTeamsEnable:SetForeColor(disabledColor)
		wMainWindow.chkTeamsLock:SetEnabled(false)
		wMainWindow.chkTeamsLock:SetForeColor(disabledColor)
		wMainWindow.btnManageTeams:SetEnabled(false)
		wMainWindow.chkIgnoreCase:SetEnabled(false)
		wMainWindow.chkIgnoreCase:SetForeColor(disabledColor)
		wMainWindow.chkIndulgentSpelling:SetEnabled(false)
		wMainWindow.chkIndulgentSpelling:SetForeColor(disabledColor)
		wMainWindow.chkApproximateAnswers:SetEnabled(false)
		wMainWindow.chkApproximateAnswers:SetForeColor(disabledColor)
		wMainWindow.inptProximityValue:SetEnabled(false)
		wMainWindow.lblProximityValueAdj:SetForeColor(disabledColor)
		wMainWindow.lblScoreMode:SetForeColor(disabledColor)
		wMainWindow.ddScoreMode:SetEnabled(false)
		wMainWindow.btnCustomScores:SetEnabled(false)
		wMainWindow.chkMultipleHits:SetEnabled(false)
		wMainWindow.chkMultipleHits:SetForeColor(disabledColor)
		wMainWindow.lblMultipleHitsTypeSpeed:SetForeColor(disabledColor)
		wMainWindow.inptMultipleHitsTypeSpeed:SetEnabled(false)
		wMainWindow.lblMultipleHitsTypeSpeedAdj:SetForeColor(disabledColor)
		wMainWindow.lblMultipleHitsDivisor:SetForeColor(disabledColor)
		wMainWindow.ddMultipleHitsDivisor:SetEnabled(false)
	else
		wMainWindow.lblGameChannel:SetForeColor(enabledColor)
		wMainWindow.ddGameChannel:SetEnabled(true)
		wMainWindow.lblGameMode:SetForeColor(enabledColor)
		wMainWindow.ddGameMode:SetEnabled(true)
		wMainWindow.lblGameTarget:SetForeColor(enabledColor)
		wMainWindow.inptGameTarget:SetEnabled(true)
		wMainWindow.lblGameTargetAdj:SetForeColor(enabledColor)
		wMainWindow.lblQuestionMode:SetForeColor(enabledColor)
		wMainWindow.ddQuestionMode:SetEnabled(true)
		wMainWindow.lblQuestionTime:SetForeColor(enabledColor)
		wMainWindow.inptQuestionTime:SetEnabled(true)
		wMainWindow.lblQuestionTimeAdj:SetForeColor(enabledColor)
		wMainWindow.lblQuestionHint:SetForeColor(enabledColor)
		wMainWindow.inptQuestionHint:SetEnabled(true)
		wMainWindow.lblQuestionHintAdj:SetForeColor(enabledColor)
		wMainWindow.chkLogGame:SetEnabled(true)
		wMainWindow.chkLogGame:SetForeColor(enabledColor)
		wMainWindow.btnSelectQuiz:SetEnabled(true)
		wMainWindow.chkTeamsEnable:SetEnabled(true)
		wMainWindow.chkTeamsEnable:SetForeColor(enabledColor)
		wMainWindow.chkTeamsLock:SetEnabled(true)
		wMainWindow.chkTeamsLock:SetForeColor(enabledColor)
		wMainWindow.btnManageTeams:SetEnabled(true)
		wMainWindow.chkIgnoreCase:SetEnabled(true)
		wMainWindow.chkIgnoreCase:SetForeColor(enabledColor)
		wMainWindow.chkIndulgentSpelling:SetEnabled(true)
		wMainWindow.chkIndulgentSpelling:SetForeColor(enabledColor)
		wMainWindow.chkApproximateAnswers:SetEnabled(true)
		wMainWindow.chkApproximateAnswers:SetForeColor(enabledColor)
		wMainWindow.inptProximityValue:SetEnabled(true)
		wMainWindow.lblProximityValueAdj:SetForeColor(enabledColor)
		wMainWindow.lblScoreMode:SetForeColor(enabledColor)
		wMainWindow.ddScoreMode:SetEnabled(true)
		wMainWindow.btnCustomScores:SetEnabled(true)
		wMainWindow.chkMultipleHits:SetEnabled(true)
		wMainWindow.chkMultipleHits:SetForeColor(enabledColor)
		wMainWindow.lblMultipleHitsTypeSpeed:SetForeColor(enabledColor)
		wMainWindow.inptMultipleHitsTypeSpeed:SetEnabled(true)
		wMainWindow.lblMultipleHitsTypeSpeedAdj:SetForeColor(enabledColor)
		wMainWindow.lblMultipleHitsDivisor:SetForeColor(enabledColor)
		wMainWindow.ddMultipleHitsDivisor:SetEnabled(true)
	end
end

function extendMainGui(extend)
	if (extend == true) then
		wMainWindow:SetHeight(guiCtrlHeigth * 38)
		wMainWindow.lblCopyright:SetTop(guiCtrlHeigth * 36)
	else
		wMainWindow:SetHeight(guiCtrlHeigth * 35)
		wMainWindow.lblCopyright:SetTop(guiCtrlHeigth * 33)
	end
end

-- Creates a virtual button that is not actually usable, but an illusion to put over another control below
function createOverlayButton(control, parent, text, posX, posY, sizeX, sizeY, zOrder, style)
	control.virtualButton = Turbine.UI.Control()
	control.virtualButton:SetParent(parent)
	control.virtualButton:SetPosition(posX, posY)
	control.virtualButton:SetSize(sizeX, sizeY)
	control.virtualButton:SetBackColor(Turbine.UI.Color(1,0,0,0))
	control.virtualButton:SetMouseVisible(false)
	control.virtualButton:SetZOrder(zOrder + 10)
	control.virtualButton.EnabledChanged = function(sender, args)
			if (style == nil) then
				style = tostring(config['GAME']['QuestionMode'])
			end
			if (sender:IsEnabled() == false) then
				control.label:SetForeColor(Turbine.UI.Color(0.5,0.5,0.5))
				control.leftSkin:SetBackground(gui['Images']['Button'.. style ..'DL'])
				control.centerSkin:SetBackground(gui['Images']['Button'.. style ..'DC'])
				control.rightSkin:SetBackground(gui['Images']['Button'.. style ..'DR'])
				control.MouseEnter = nil
				control.MouseLeave = nil
				control.MouseDown = nil
				control.MouseUp = nil
			else
				control.label:SetForeColor(Turbine.UI.Color(0.925,0.953,0.482))
				control.leftSkin:SetBackground(gui['Images']['Button'.. style ..'EL'])
				control.centerSkin:SetBackground(gui['Images']['Button'.. style ..'EC'])
				control.rightSkin:SetBackground(gui['Images']['Button'.. style ..'ER'])
				control.MouseEnter = function()
						control.label:SetForeColor(Turbine.UI.Color(1,1,0))
						control.leftSkin:SetBackground(gui['Images']['Button'.. style ..'HL'])
						control.centerSkin:SetBackground(gui['Images']['Button'.. style ..'HC'])
						control.rightSkin:SetBackground(gui['Images']['Button'.. style ..'HR'])
					end
				control.MouseLeave = function()
						control.label:SetForeColor(Turbine.UI.Color(1,1,0))
						control.leftSkin:SetBackground(gui['Images']['Button'.. style ..'EL'])
						control.centerSkin:SetBackground(gui['Images']['Button'.. style ..'EC'])
						control.rightSkin:SetBackground(gui['Images']['Button'.. style ..'ER'])
					end
				control.MouseDown = function()
						control.label:SetForeColor(Turbine.UI.Color(0.8,0.8,0.8))
						control.leftSkin:SetBackground(gui['Images']['Button'.. style ..'CL'])
						control.centerSkin:SetBackground(gui['Images']['Button'.. style ..'CC'])
						control.rightSkin:SetBackground(gui['Images']['Button'.. style ..'CR'])
					end
				control.MouseUp = function()
						control.label:SetForeColor(Turbine.UI.Color(1,1,0))
						control.leftSkin:SetBackground(gui['Images']['Button'.. style ..'HL'])
						control.centerSkin:SetBackground(gui['Images']['Button'.. style ..'HC'])
						control.rightSkin:SetBackground(gui['Images']['Button'.. style ..'HR'])
					end			
			end
		end
	control.image = Turbine.UI.Control()
	control.image:SetParent(control.virtualButton)
	control.image:SetPosition(0, 0)
	control.image:SetSize(sizeX, sizeY)
	control.image:SetMouseVisible(false) 
	control.image:SetBlendMode(Turbine.UI.BlendMode.Overlay)
	control.image:SetZOrder(zOrder + 20)
	control.leftSkin = Turbine.UI.Control()
	control.leftSkin:SetParent(control.image)
	control.leftSkin:SetPosition(0, 0)
	control.leftSkin:SetSize(20, 20)
	control.leftSkin:SetMouseVisible(false)
	control.leftSkin:SetBlendMode(Turbine.UI.BlendMode.Overlay)
	control.leftSkin:SetBackground(0x410001a5)
	control.centerSkin = Turbine.UI.Control()
	control.centerSkin:SetParent(control.image)
	control.centerSkin:SetPosition(19, 0)
	control.centerSkin:SetSize(sizeX - 37, 20)
	control.centerSkin:SetMouseVisible(false)
	control.centerSkin:SetBlendMode(Turbine.UI.BlendMode.Overlay)
	control.centerSkin:SetBackground(0x410001ac)
	control.rightSkin = Turbine.UI.Control()
	control.rightSkin:SetParent(control.image)
	control.rightSkin:SetPosition(sizeX - 21, 0)
	control.rightSkin:SetSize(20, 20)
	control.rightSkin:SetMouseVisible(false)
	control.rightSkin:SetBlendMode(Turbine.UI.BlendMode.Overlay)
	control.rightSkin:SetBackground(0x410001b3)
	control.label = Turbine.UI.Label()
	control.label:SetParent(control.image)
	control.label:SetPosition(0, 0)
	control.label:SetSize(control.image:GetWidth(), control.image:GetHeight())
	control.label:SetFont(Turbine.UI.Lotro.Font.TrajanPro14)
	control.label:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	control.label:SetText(text)
	control.label:SetMouseVisible(false)
	control:SetEnabled(false)
	control:SetEnabled(true)
	
	return control.virtualButton
end


function resetActionButtons()
	wMainWindow.btnWrapQuestion = nil
	wMainWindow.btnAskQuestion = createOverlayButton(wMainWindow.qsAskQuestion, wMainWindow, replaceCharacters(replaceCharacters(translate('txtAskQuestion'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui), wMainWindow.qsAskQuestion:GetLeft(), wMainWindow.qsAskQuestion:GetTop(), wMainWindow.qsAskQuestion:GetWidth(), wMainWindow.qsAskQuestion:GetHeight(), wMainWindow.qsAskQuestion:GetZOrder() + 10) -- Although named "btn" what we get is really the generic control parent to graphics and text that does the appareance trick
	wMainWindow.btnAskQuestion:SetEnabled(false)
	wMainWindow.btnAskQuestion:SetVisible(false)
	wMainWindow.btnWrapQuestion = nil
	wMainWindow.btnWrapQuestion = createOverlayButton(wMainWindow.qsWrapQuestion, wMainWindow, replaceCharacters(replaceCharacters(translate('txtWrapQuestion'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui), wMainWindow.qsWrapQuestion:GetLeft(), wMainWindow.qsWrapQuestion:GetTop(), wMainWindow.qsWrapQuestion:GetWidth(), wMainWindow.qsWrapQuestion:GetHeight(), wMainWindow.qsWrapQuestion:GetZOrder() + 10) -- Although named "btn" what we get is really the generic control parent to graphics and text that does the appareance trick
	wMainWindow.btnWrapQuestion:SetEnabled(false)
	wMainWindow.btnWrapQuestion:SetVisible(false)
end

-- This is the window to add points to players manually when a question is properly ended in manual mode.
function masterScorer(create)
	if (create == true) then
		local guiColumnWidth = 110
		local sortedPlayerNames = listParticipants('Players')
		local playerListSize = math.max(math.min(#sortedPlayerNames, 10), 1)
		local guiColumnNumber = 2
		local guiWidth = (guiColumnNumber * guiColumnWidth) + ((guiColumnNumber + 1) * guiSpacing)
		local guiHeight =  guiCtrlHeigth * (16 + playerListSize)
		local posX,posY = calcDefaultWindowPos('MasterScorer', guiWidth, guiHeight)

		-- CREATE WINDOW
		wMasterScorer = Turbine.UI.Lotro.Window()
		wMasterScorer:SetSize(guiWidth, guiHeight)
		wMasterScorer:SetPosition(posX, posY)
		wMasterScorer:SetText(replaceCharacters(replaceCharacters(translate('txtMasterScorer'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wMasterScorer:SetZOrder(400)

		-- Master Scorer information label
		wMasterScorer.lblMasterScorerInfo = Turbine.UI.Label()
		wMasterScorer.lblMasterScorerInfo:SetParent(wMasterScorer)
		wMasterScorer.lblMasterScorerInfo:SetPosition(guiSpacing, guiCtrlHeigth * 2)
		wMasterScorer.lblMasterScorerInfo:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth * 5)
		wMasterScorer.lblMasterScorerInfo:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMasterScorer.lblMasterScorerInfo:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		wMasterScorer.lblMasterScorerInfo:SetText(replaceCharacters(replaceCharacters(translate('txtMasterScorerInfo'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
		wMasterScorer.lblMasterScorerInfo:SetZOrder(410)

		-- Box with the list of participants and suggested points
		wMasterScorer.boxList = Turbine.UI.ListBox()
		wMasterScorer.boxList:SetParent(wMasterScorer)
		wMasterScorer.boxList:SetPosition(guiSpacing, guiCtrlHeigth * 8)
		wMasterScorer.boxList:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth * playerListSize)
		wMasterScorer.boxList:SetZOrder(410)
		local listItems = {}
		for i,v in ipairs(sortedPlayerNames) do
			listItems[i] = {}
			local playerRow = Turbine.UI.Control()
			playerRow:SetParent(wMasterScorer.boxList)
			playerRow:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth)
			-- Player name
			listItems[i][1] = Turbine.UI.Label()
			listItems[i][1]:SetParent(playerRow)
			listItems[i][1]:SetPosition(0, 0)
			listItems[i][1]:SetSize(guiColumnWidth, guiCtrlHeigth)
			listItems[i][1]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
			listItems[i][1]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
			listItems[i][1]:SetText(v)
			-- Input for points
			listItems[i][2] = Turbine.UI.Lotro.TextBox()
			listItems[i][2]:SetParent(playerRow)
			listItems[i][2]:SetPosition(guiColumnWidth + guiSpacing / 2, 0)
			listItems[i][2]:SetSize(35, guiCtrlHeigth)
			listItems[i][2]:SetMultiline(false)
			listItems[i][2]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
			listItems[i][2]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
			if (suggestedScores[v] == nil) then
				listItems[i][2]:SetText('0')
			else
				listItems[i][2]:SetText(tostring(suggestedScores[v]))
			end
			listItems[i][2].FocusLost = function(Sender,Args)
				local newValue = validateNumberString(listItems[i][2]:GetText(), 0.01, 1000, 2)
				if (newValue == nil) then
					listItems[i][2]:SetText('0')
				else
					if (tonumber(newValue) == 1) then
						listItems[i][3]:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtPoint'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
					else
						listItems[i][3]:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtPoints'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
					end
				end
			end
			-- Player points adj
			listItems[i][3] = Turbine.UI.Label()
			listItems[i][3]:SetParent(playerRow)
			listItems[i][3]:SetPosition(guiColumnWidth + guiSpacing / 2 + 35, 0)
			listItems[i][3]:SetSize(60, guiCtrlHeigth)
			listItems[i][3]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
			listItems[i][3]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
			listItems[i][3]:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtPoints'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
			wMasterScorer.boxList:AddItem(playerRow)
		end
		-- Scrollbar for participants list
		wMasterScorer.vScroll = Turbine.UI.Lotro.ScrollBar()
		wMasterScorer.vScroll:SetParent(wMasterScorer)
		wMasterScorer.vScroll:SetOrientation(Turbine.UI.Orientation.Vertical)
		wMasterScorer.vScroll:SetPosition(wMasterScorer.boxList:GetLeft() + wMasterScorer.boxList:GetWidth(), wMasterScorer.boxList:GetTop())
		wMasterScorer.vScroll:SetSize(12, wMasterScorer.boxList:GetHeight())
		wMasterScorer.vScroll:SetZOrder(410)
		wMasterScorer.boxList:SetVerticalScrollBar(wMasterScorer.vScroll)
		-- Correct Answer label
		wMasterScorer.lblCorrectAnswer = Turbine.UI.Label()
		wMasterScorer.lblCorrectAnswer:SetParent(wMasterScorer)
		wMasterScorer.lblCorrectAnswer:SetPosition(guiSpacing, guiCtrlHeigth * (9 + playerListSize))
		wMasterScorer.lblCorrectAnswer:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth)
		wMasterScorer.lblCorrectAnswer:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMasterScorer.lblCorrectAnswer:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		wMasterScorer.lblCorrectAnswer:SetText(replaceCharacters(replaceCharacters(translate('txtCorrectAnswer'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ':')
		wMasterScorer.lblCorrectAnswer:SetZOrder(410)
		-- Answer Reveal label
		wMasterScorer.lblAnswerReveal = Turbine.UI.Label()
		wMasterScorer.lblAnswerReveal:SetParent(wMasterScorer)
		wMasterScorer.lblAnswerReveal:SetPosition(guiSpacing, guiCtrlHeigth * (10 + playerListSize))
		wMasterScorer.lblAnswerReveal:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth * 3)
		wMasterScorer.lblAnswerReveal:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wMasterScorer.lblAnswerReveal:SetForeColor(Turbine.UI.Color(1,0.843,0))
		wMasterScorer.lblAnswerReveal:SetTextAlignment(Turbine.UI.ContentAlignment.TopCenter)
		wMasterScorer.lblAnswerReveal:SetText(replaceCharacters(replaceCharacters(questionAnswer, nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
		wMasterScorer.lblAnswerReveal:SetZOrder(410)
		-- Set points button
		wMasterScorer.btnSetPoints = Turbine.UI.Lotro.Button()
		wMasterScorer.btnSetPoints:SetParent(wMasterScorer)
		wMasterScorer.btnSetPoints:SetPosition(guiWidth / 2 - (guiButtonWidth) / 2, guiCtrlHeigth * (13 + playerListSize))
		wMasterScorer.btnSetPoints:SetSize(guiButtonWidth, guiCtrlHeigth)
		wMasterScorer.btnSetPoints:SetEnabled(true)
		wMasterScorer.btnSetPoints:SetText(replaceCharacters(replaceCharacters(translate('txtSetPoints'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wMasterScorer.btnSetPoints:SetZOrder(410)
		wMasterScorer.btnSetPoints.Click = function(sender,args)
				wMasterScorer.btnSetPoints:SetEnabled(false) -- Prevent the usage of this function more than once
				wMainWindow.btnMasterScorer:SetEnabled(false) -- Prevent reopening this window until the end of next question
				for i,v in ipairs(listItems) do
					if (tonumber(v[2]:GetText()) > 0) then
						addQuestionScorer(v[1]:GetText(), questionCounter)
						addScore(v[1]:GetText(), tonumber(v[2]:GetText()), questionCounter)
					end
				end
				local textChannel =  config['GAME']['GameChannel'] -- Default value for message
				if (endQuestionMessage ~= '') then
					textChannel = 'Append' -- If it wasn't empy is because we had a winner.
				end
				local appendScores = printQuestionScoresAll('', questionCounter, textChannel)
				if (appendScores ~= nil) then
					endQuestionMessage = endQuestionMessage .. '\n' .. appendScores
				end
				remapShortcut(wMasterScorer.qsAccept, endQuestionMessage) -- Show results of this question
				wMasterScorer.qsAccept:SetEnabled(true)
				wMasterScorer.qsAccept:SetVisible(true)
				wMasterScorer.btnAccept:SetEnabled(true)
				wMasterScorer.btnAccept:SetVisible(true)
			end
		-- Accept button
		wMasterScorer.qsAccept = Turbine.UI.Lotro.Quickslot()
		wMasterScorer.qsAccept:SetParent(wMasterScorer)
		wMasterScorer.qsAccept:SetPosition(guiWidth / 2 - (guiButtonWidth) / 2, guiCtrlHeigth * (14 + playerListSize))
		wMasterScorer.qsAccept:SetSize(guiButtonWidth, guiCtrlHeigth)
		wMasterScorer.qsAccept:SetUseOnRightClick(false)
		wMasterScorer.qsAccept:SetShortcut(Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '/dance'))
		wMasterScorer.qsAccept.ShortcutData = '/dance' -- Prevent drop over itself bug, step 1
		wMasterScorer.qsAccept:SetAllowDrop(false)
		wMasterScorer.qsAccept:SetZOrder(410)
		wMasterScorer.qsAccept.DragDrop = function()
				-- Prevent drop over itself bug, step 2
				local sc = Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '')
				sc:SetData(wMasterScorer.qsAccept.ShortcutData)
				wMasterScorer.qsAccept:SetShortcut(sc)
			end
		wMasterScorer.qsAccept.MouseClick = function()
				wMasterScorer.qsAccept:SetEnabled(false)
				wMasterScorer.qsAccept:SetVisible(false)
				wMasterScorer.btnAccept:SetEnabled(false)
				wMasterScorer.btnAccept:SetVisible(false)
				questionScoresPrinted = true
				masterScorer(false)
				preQuestion()
			end
		wMasterScorer.qsAccept:SetEnabled(false)
		wMasterScorer.qsAccept:SetVisible(false)
		wMasterScorer.btnAccept = createOverlayButton(wMasterScorer.qsAccept, wMasterScorer, replaceCharacters(replaceCharacters(translate('txtAccept'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui), wMasterScorer.qsAccept:GetLeft(), wMasterScorer.qsAccept:GetTop(), wMasterScorer.qsAccept:GetWidth(), wMasterScorer.qsAccept:GetHeight(), wMasterScorer.qsAccept:GetZOrder(), 2) -- Although named "btn" what we get is really the generic control parent to graphics and text that does the appareance trick
		wMasterScorer.btnAccept:SetVisible(false)
		
		
		function wMasterScorer:Deactivated(sender,args) -- Make it stay always on top
			if (wMasterScorer ~= nil) then
				wMasterScorer:Activate()
				wMasterScorer:Focus()
			end
		end
				
		function wMasterScorer:Closing(sender,args)
			savePosition(wMasterScorer, 'MasterScorer', wMasterScorer:GetLeft(), wMasterScorer:GetTop())
		end

	else -- Destroy
		if (wMasterScorer ~= nil) then
			wMasterScorer:Close()
			wMasterScorer = nil
		end
	end
end

-- This window is to add an arbitrary amount of points to a registered player or team.
function pointGift(create)
	if (create == true) then
		local guiColumnNumber = 1
		local guiWidth = (guiColumnNumber * guiColumnWidth) + ((guiColumnNumber + 1) * guiSpacing)
		local guiHeight =  guiCtrlHeigth * 10
		local posX,posY = calcDefaultWindowPos('PointGift', guiWidth, guiHeight)

		-- CREATE WINDOW
		wPointGift = Turbine.UI.Lotro.Window()
		wPointGift:SetSize(guiWidth, guiHeight)
		wPointGift:SetPosition(posX, posY)
		wPointGift:SetText(replaceCharacters(replaceCharacters(translate('txtPointGift'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		--wPointGift:SetZOrder(300) -- Disabling because cannot set ZOrder in dropdowns

		-- Add points input
		wPointGift.inptAddPoints = Turbine.UI.Lotro.TextBox()
		wPointGift.inptAddPoints:SetParent(wPointGift)
		wPointGift.inptAddPoints:SetPosition(guiSpacing, guiCtrlHeigth * 2)
		wPointGift.inptAddPoints:SetSize(35, guiCtrlHeigth)
		wPointGift.inptAddPoints:SetMultiline(false)
		wPointGift.inptAddPoints:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wPointGift.inptAddPoints:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
		wPointGift.inptAddPoints:SetText('1')
		wPointGift.inptAddPoints:SetZOrder(310) -- Disabling because cannot set ZOrder in dropdowns
		wPointGift.inptAddPoints.FocusLost = function(Sender,Args)
				local newValue = validateNumberString(wPointGift.inptAddPoints:GetText(), 0.01, 1000, 2)
				if (newValue == nil) then
					newValue = 1
				end
				if (newValue == l) then
					wPointGift.lblAddPointsAdj:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtPointTo'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ':')
				else
					wPointGift.lblAddPointsAdj:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtPointsTo'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ':')
				end
				wPointGift.inptAddPoints:SetText(newValue)
			end
		-- Add points adj
		wPointGift.lblAddPointsAdj = Turbine.UI.Label()
		wPointGift.lblAddPointsAdj:SetParent(wPointGift)
		wPointGift.lblAddPointsAdj:SetPosition(guiSpacing + 35, guiCtrlHeigth * 2)
		wPointGift.lblAddPointsAdj:SetSize(guiWidth - 35 - guiSpacing * 2, guiCtrlHeigth)
		wPointGift.lblAddPointsAdj:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wPointGift.lblAddPointsAdj:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		wPointGift.lblAddPointsAdj:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtPointTo'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ':')
		wPointGift.lblAddPointsAdj:SetZOrder(310) -- Disabling because cannot set ZOrder in dropdowns
		-- ParticipantsType choice dropdown
		local lstParticipantsType = sortedKeys(gameParticipants)
		-- Create a translated list and a way to translate it back
		local lstParticipantsTypeTrans = {}
		local translations = {}
		for i,v in ipairs(lstParticipantsType) do
			lstParticipantsTypeTrans[i] = translate('txt' .. v)
			translations[translate('txt' .. v)] = v		
		end
		wPointGift.ddParticipantsType = DropDown(lstParticipantsTypeTrans,  replaceCharacters(replaceCharacters(translate('txtPlayers'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wPointGift.ddParticipantsType:SetParent(wPointGift)
		wPointGift.ddParticipantsType:SetPosition(guiSpacing, guiCtrlHeigth * 3)
		wPointGift.ddParticipantsType:SetWidth(guiColumnWidth)
		wPointGift.ddParticipantsType:SetAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		wPointGift.ddParticipantsType:SetZOrder(310) -- Disabling because cannot set ZOrder in dropdowns
		wPointGift.ddParticipantsType.ItemChanged = function(Sender,Args)
				-- Tricky way to update second list
				wPointGift.ddParticipants.Close()
				wPointGift.ddParticipants = nil
				lstParticipants = sortedKeys(gameParticipants[translations[Args.Text]])
				wPointGift.ddParticipants = DropDown(lstParticipants)
				wPointGift.ddParticipants:SetParent(wPointGift)
				wPointGift.ddParticipants:SetPosition(guiSpacing, guiCtrlHeigth * 4)
				wPointGift.ddParticipants:SetWidth(guiColumnWidth)
				wPointGift.ddParticipants:SetAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
				wPointGift.ddParticipants:SetZOrder(310) -- Disabling because cannot set ZOrder in dropdowns
				wPointGift.ddParticipants.ItemChanged = function(Sender,Args)
						 -- Choose ParticipantsType for next dropdown list
						wPointGift.ddParticipants:Reset() -- Scrolls back to the top of the list
					end
					--]]
				wPointGift.ddParticipantsType:Reset() -- Scrolls back to the top of the list
			end
		-- Participant choice dropdown
		local lstParticipants = sortedKeys(gameParticipants['Players'])
		wPointGift.ddParticipants = DropDown(lstParticipants)
		wPointGift.ddParticipants:SetParent(wPointGift)
		wPointGift.ddParticipants:SetPosition(guiSpacing, guiCtrlHeigth * 4)
		wPointGift.ddParticipants:SetWidth(guiColumnWidth)
		wPointGift.ddParticipants:SetAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		wPointGift.ddParticipants:SetZOrder(310) -- Disabling because cannot set ZOrder in dropdowns
		wPointGift.ddParticipants.ItemChanged = function(Sender,Args)
				 -- Choose ParticipantsType for next dropdown list
				wPointGift.ddParticipants:Reset() -- Scrolls back to the top of the list
			end
		-- Set points button
		wPointGift.btnSetPoints = Turbine.UI.Lotro.Button()
		wPointGift.btnSetPoints:SetParent(wPointGift)
		wPointGift.btnSetPoints:SetPosition(guiWidth / 2 - (guiButtonWidth) / 2, guiCtrlHeigth * 5)
		wPointGift.btnSetPoints:SetSize(guiButtonWidth, guiCtrlHeigth)
		wPointGift.btnSetPoints:SetEnabled(true)
		wPointGift.btnSetPoints:SetText(replaceCharacters(replaceCharacters(translate('txtSetPoints'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wPointGift.btnSetPoints:SetZOrder(310) -- Disabling because cannot set ZOrder in dropdowns
		wPointGift.btnSetPoints.Click = function(sender,args)
				local pointString = replaceCharacters(replaceCharacters(translate('msgPoints'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
				if (tonumber(wPointGift.inptAddPoints:GetText()) == 1) then
					pointString = replaceCharacters(replaceCharacters(translate('msgPoint'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
				end
				local newShortcut = sendToChat(chatColours['Orange'] .. replaceCharacters(translate('msgOpenExclamation'), nonbasicCharactersInChat) .. replaceCharacters(translate('msgOpenExclamation'), nonbasicCharactersInChat) .. replaceCharacters(translate('msgOpenExclamation'), nonbasicCharactersInChat) .. string.upper(replaceCharacters(translate('msgPointGift'), nonbasicCharactersInChat)) .. replaceCharacters(translate('msgCloseExclamation'), nonbasicCharactersInChat) .. replaceCharacters(translate('msgCloseExclamation'), nonbasicCharactersInChat) .. replaceCharacters(translate('msgCloseExclamation'), nonbasicCharactersInChat) .. chatColours['Closure'] .. ' ' .. replaceCharacters(translate('msgGameMasterAdded'), nonbasicCharactersInChat) .. ' ' .. chatColours['Orange'] .. wPointGift.inptAddPoints:GetText() .. ' ' .. pointString .. chatColours['Closure'] .. ' ' .. replaceCharacters(translate('msgTo'), nonbasicCharactersInChat) .. ' ' .. chatColours['Orange'] .. wPointGift.ddParticipants:GetText() .. chatColours['Closure'] .. '.', config['GAME']['GameChannel'], '')
				wPointGift.qsAccept:SetShortcut(Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, newShortcut))
				wPointGift.qsAccept.ShortcutData = newShortcut
				wPointGift.qsAccept:SetEnabled(true)
				wPointGift.qsAccept:SetVisible(true)
				wPointGift.btnAccept:SetEnabled(true)
				wPointGift.btnAccept:SetVisible(true)
			end
		-- Accept button
		wPointGift.qsAccept = Turbine.UI.Lotro.Quickslot()
		wPointGift.qsAccept:SetParent(wPointGift)
		wPointGift.qsAccept:SetPosition(guiWidth / 2 - (guiButtonWidth) / 2, guiCtrlHeigth * 7)
		wPointGift.qsAccept:SetSize(guiButtonWidth, guiCtrlHeigth)
		wPointGift.qsAccept:SetShortcut(Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '/dance'))
		wPointGift.qsAccept.ShortcutData = '/dance' -- Prevent drop over itself bug, step 1
		wPointGift.qsAccept:SetAllowDrop(false)
		wPointGift.qsAccept:SetZOrder(310) -- Disabling because cannot set ZOrder in dropdowns
		wPointGift.qsAccept.DragDrop = function()
				-- Prevent drop over itself bug, step 2
				local sc = Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '')
				sc:SetData(wPointGift.qsAccept.ShortcutData)
				wPointGift.qsAccept:SetShortcut(sc)
			end
		wPointGift.qsAccept.MouseClick = function()
				if (wPointGift.ddParticipantsType:GetText() == replaceCharacters(replaceCharacters(translate('txtPlayers'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)) then
					addScore(wPointGift.ddParticipants:GetText(), tonumber(wPointGift.inptAddPoints:GetText()), 0)
				else
					addTeamScore(wPointGift.ddParticipants:GetText(), tonumber(wPointGift.inptAddPoints:GetText()))
				end
				pointGift(false)
			end
		wPointGift.qsAccept:SetEnabled(false)
		wPointGift.qsAccept:SetVisible(false)
		wPointGift.btnAccept = createOverlayButton(wPointGift.qsAccept, wPointGift, replaceCharacters(replaceCharacters(translate('txtAccept'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui), wPointGift.qsAccept:GetLeft(), wPointGift.qsAccept:GetTop(), wPointGift.qsAccept:GetWidth(), wPointGift.qsAccept:GetHeight(), wPointGift.qsAccept:GetZOrder(), 2) -- Although named "btn" what we get is really the generic control parent to graphics and text that does the appareance trick
		wPointGift.btnAccept:SetEnabled(false)
		wPointGift.btnAccept:SetVisible(false)
		-- Cancel button
		wPointGift.btnCancel = Turbine.UI.Lotro.Button()
		wPointGift.btnCancel:SetParent(wPointGift)
		wPointGift.btnCancel:SetPosition(guiWidth / 2 - (guiButtonWidth) / 2, guiCtrlHeigth * 8)
		wPointGift.btnCancel:SetSize(guiButtonWidth, guiCtrlHeigth)
		wPointGift.btnCancel:SetEnabled(true)
		wPointGift.btnCancel:SetText(replaceCharacters(replaceCharacters(translate('txtCancel'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wPointGift.btnCancel:SetZOrder(310) -- Disabling because cannot set ZOrder in dropdowns
		wPointGift.btnCancel.Click = function(sender,args)
				pointGift(false)
			end

		function wPointGift:Closing(sender,args)
			savePosition(wPointGift, 'PointGift', wPointGift:GetLeft(), wPointGift:GetTop())
		end
	else -- Destroy
		if (wPointGift ~= nil) then
			wPointGift:Close()
			wPointGift = nil
		end
	end
end

-- This is the window to publish the game standings.
function shareResults(create)
	if (create == true) then
		local guiColumnWidth = 100
		local playerStandings = getStandings('Players')
		if (playerStandings == nil) then
			playerStandings = {[1] = replaceCharacters(replaceCharacters(translate('txtNobodyScored'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)}
		end
		local teamStandings = getStandings('Teams')
		if (teamStandings == nil) then
			teamStandings = {[1] = replaceCharacters(replaceCharacters(translate('txtNobodyScored'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)}
		end
		local playerListSize = math.max(math.min(#playerStandings, 10), 1)
		local teamListSize = math.max(math.min(#teamStandings, 10), 1)
		local windowExtension = 0
		if (config['GAME']['TeamsEnable'] == 1) then
			windowExtension = guiCtrlHeigth * (2 + teamListSize)
		end
		local guiColumnNumber = 2
		local guiWidth = (guiColumnNumber * guiColumnWidth) + ((guiColumnNumber + 1) * guiSpacing)
		local guiHeight =  guiCtrlHeigth * (6 + playerListSize) + windowExtension
		local posX,posY = calcDefaultWindowPos('ShareResults', guiWidth, guiHeight)

		-- CREATE WINDOW
		wShareResults = Turbine.UI.Lotro.Window()
		wShareResults:SetSize(guiWidth, guiHeight)
		wShareResults:SetPosition(posX, posY)
		wShareResults:SetText(replaceCharacters(replaceCharacters(translate('txtStandings'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wShareResults:SetZOrder(500)

		-- Player standings label
		wShareResults.lblPlayerStandings = Turbine.UI.Label()
		wShareResults.lblPlayerStandings:SetParent(wShareResults)
		wShareResults.lblPlayerStandings:SetPosition(guiSpacing, guiCtrlHeigth * 2)
		wShareResults.lblPlayerStandings:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth)
		wShareResults.lblPlayerStandings:SetForeColor(Turbine.UI.Color(1,0.843,0))
		wShareResults.lblPlayerStandings:SetFont(Turbine.UI.Lotro.Font.TrajanPro18)
		wShareResults.lblPlayerStandings:SetText(replaceCharacters(replaceCharacters(translate('txtPlayerStandings'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
		wShareResults.lblPlayerStandings:SetZOrder(510)

		-- Box with the list of participants and suggested points
		wShareResults.playerBoxList = Turbine.UI.ListBox()
		wShareResults.playerBoxList:SetParent(wShareResults)
		wShareResults.playerBoxList:SetPosition(guiSpacing, guiCtrlHeigth * 3)
		wShareResults.playerBoxList:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth * playerListSize)
		wShareResults.playerBoxList:SetZOrder(510)
		local listItems = {}
		for i,v in ipairs(playerStandings) do
			local playerRow = Turbine.UI.Control()
			playerRow:SetParent(wShareResults.playerBoxList)
			playerRow:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth)
			listItems[i] = {}
			if (v ~= replaceCharacters(replaceCharacters(translate('txtNobodyScored'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)) then
				local playerName = ''
				local playerScore = ''
				for j,w in pairs(v) do -- There should only be one item
					playerName = j
					playerScore = tostring(w)
				end
				-- Player name
				listItems[i][1] = Turbine.UI.Label()
				listItems[i][1]:SetParent(playerRow)
				listItems[i][1]:SetPosition(0, 0)
				listItems[i][1]:SetSize(guiColumnWidth, guiCtrlHeigth)
				listItems[i][1]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
				listItems[i][1]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
				listItems[i][1]:SetText(playerName)
				-- Number of points
				listItems[i][2] = Turbine.UI.Label()
				listItems[i][2]:SetParent(playerRow)
				listItems[i][2]:SetPosition(guiColumnWidth + guiSpacing / 2, 0)
				listItems[i][2]:SetSize(40, guiCtrlHeigth)
				listItems[i][2]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
				listItems[i][2]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
				listItems[i][2]:SetText(playerScore)
				-- Player points adj
				listItems[i][3] = Turbine.UI.Label()
				listItems[i][3]:SetParent(playerRow)
				listItems[i][3]:SetPosition(guiColumnWidth + guiSpacing / 2 + 40, 0)
				listItems[i][3]:SetSize(60, guiCtrlHeigth)
				listItems[i][3]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
				listItems[i][3]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
				if (playerScore == 1) then
					listItems[i][3]:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtPoint'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
				else
					listItems[i][3]:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtPoints'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
				end
			else
				listItems[i][1] = Turbine.UI.Label()
				listItems[i][1]:SetParent(playerRow)
				listItems[i][1]:SetPosition(0, 0)
				listItems[i][1]:SetSize(guiColumnWidth, guiCtrlHeigth)
				listItems[i][1]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
				listItems[i][1]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
				listItems[i][1]:SetText(v)
			end
			wShareResults.playerBoxList:AddItem(playerRow)
		end
		-- Scrollbar for participants list
		wShareResults.vScrollP = Turbine.UI.Lotro.ScrollBar()
		wShareResults.vScrollP:SetParent(wShareResults)
		wShareResults.vScrollP:SetOrientation(Turbine.UI.Orientation.Vertical)
		wShareResults.vScrollP:SetPosition(wShareResults.playerBoxList:GetLeft() + wShareResults.playerBoxList:GetWidth(), wShareResults.playerBoxList:GetTop())
		wShareResults.vScrollP:SetSize(12, wShareResults.playerBoxList:GetHeight())
		wShareResults.vScrollP:SetZOrder(510)
		wShareResults.playerBoxList:SetVerticalScrollBar(wShareResults.vScrollP)

		if (config['GAME']['TeamsEnable'] == 1) then
			-- Teams standings label
			wShareResults.lblTeamStandings = Turbine.UI.Label()
			wShareResults.lblTeamStandings:SetParent(wShareResults)
			wShareResults.lblTeamStandings:SetPosition(guiSpacing, guiCtrlHeigth * (4 + playerListSize))
			wShareResults.lblTeamStandings:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth)
			wShareResults.lblTeamStandings:SetForeColor(Turbine.UI.Color(1,0.843,0))
			wShareResults.lblTeamStandings:SetFont(Turbine.UI.Lotro.Font.TrajanPro18)
			wShareResults.lblTeamStandings:SetText(replaceCharacters(replaceCharacters(translate('txtTeamStandings'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
			wShareResults.lblTeamStandings:SetZOrder(510)

			-- Box with the list of participants and suggested points
			wShareResults.teamBoxList = Turbine.UI.ListBox()
			wShareResults.teamBoxList:SetParent(wShareResults)
			wShareResults.teamBoxList:SetPosition(guiSpacing, (guiCtrlHeigth * (4 + playerListSize)) + (guiCtrlHeigth))
			wShareResults.teamBoxList:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth * teamListSize)
			wShareResults.teamBoxList:SetZOrder(510)
			local listItems = {}
			for i,v in ipairs(teamStandings) do
				local teamRow = Turbine.UI.Control()
				teamRow:SetParent(wShareResults.teamBoxList)
				teamRow:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth)
				listItems[i] = {}
				if (v ~= replaceCharacters(replaceCharacters(translate('txtNobodyScored'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)) then
					local teamName = ''
					local teamScore = ''
					for j,w in pairs(v) do -- There should only be one item
						teamName = j
						teamScore = tostring(w)
					end
					-- Team name
					listItems[i][1] = Turbine.UI.Label()
					listItems[i][1]:SetParent(teamRow)
					listItems[i][1]:SetPosition(0, 0)
					listItems[i][1]:SetSize(guiColumnWidth, guiCtrlHeigth)
					listItems[i][1]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
					listItems[i][1]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
					listItems[i][1]:SetText(teamName)
					-- Number of points
					listItems[i][2] = Turbine.UI.Label()
					listItems[i][2]:SetParent(teamRow)
					listItems[i][2]:SetPosition(guiColumnWidth + guiSpacing / 2, 0)
					listItems[i][2]:SetSize(40, guiCtrlHeigth)
					listItems[i][2]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
					listItems[i][2]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
					listItems[i][2]:SetText(teamScore)
					-- Team points adj
					listItems[i][3] = Turbine.UI.Label()
					listItems[i][3]:SetParent(teamRow)
					listItems[i][3]:SetPosition(guiColumnWidth + guiSpacing / 2 + 40, 0)
					listItems[i][3]:SetSize(60, guiCtrlHeigth)
					listItems[i][3]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
					listItems[i][3]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
					if (teamScore == 1) then
						listItems[i][3]:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtPoint'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
					else
						listItems[i][3]:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtPoints'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
					end
				else
					listItems[i][1] = Turbine.UI.Label()
					listItems[i][1]:SetParent(teamRow)
					listItems[i][1]:SetPosition(0, 0)
					listItems[i][1]:SetSize(guiColumnWidth, guiCtrlHeigth)
					listItems[i][1]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
					listItems[i][1]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
					listItems[i][1]:SetText(v)
				end
				wShareResults.teamBoxList:AddItem(teamRow)
			end
			-- Scrollbar for participants list
			wShareResults.vScrollT = Turbine.UI.Lotro.ScrollBar()
			wShareResults.vScrollT:SetParent(wShareResults)
			wShareResults.vScrollT:SetOrientation(Turbine.UI.Orientation.Vertical)
			wShareResults.vScrollT:SetPosition(wShareResults.teamBoxList:GetLeft() + wShareResults.teamBoxList:GetWidth(), wShareResults.teamBoxList:GetTop())
			wShareResults.vScrollT:SetSize(12, wShareResults.teamBoxList:GetHeight())
			wShareResults.vScrollT:SetZOrder(510)
			wShareResults.teamBoxList:SetVerticalScrollBar(wShareResults.vScrollT)
		end
		-- Publish button
		wShareResults.qsPublish = Turbine.UI.Lotro.Quickslot()
		wShareResults.qsPublish:SetParent(wShareResults)
		wShareResults.qsPublish:SetSize(guiButtonWidth, guiCtrlHeigth)
		wShareResults.qsPublish:SetPosition(guiWidth / 2 - (guiButtonWidth) / 2, (guiCtrlHeigth * (4 + playerListSize)) + windowExtension)
		wShareResults.qsPublish:SetUseOnRightClick(false)
		wShareResults.qsPublish:SetShortcut(Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '/dance'))
		wShareResults.qsPublish.ShortcutData = '/dance' -- Prevent drop over itself bug, step 1
		wShareResults.qsPublish:SetAllowDrop(false)
		wShareResults.qsPublish:SetZOrder(510)
		wShareResults.qsPublish.DragDrop = function()
				-- Prevent drop over itself bug, step 2
				local sc = Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '')
				sc:SetData(wShareResults.qsPublish.ShortcutData)
				wShareResults.qsPublish:SetShortcut(sc)
			end
		wShareResults.qsPublish.MouseClick = function()
				shareResults(false)
			end

		-- Set command depending on game state
		if (gameState == 0) then
			remapShortcut(wShareResults.qsPublish, sendToChat(replaceCharacters(translate('msgEndGame'), nonbasicCharactersInChat) .. '\n' .. chatColours['Orange'] .. replaceCharacters(translate('msgFinalResults'), nonbasicCharactersInChat) .. chatColours['Closure'], config['GAME']['GameChannel'], '', true) .. '\n' .. printResults('', '', 'Append'))
		else
			remapShortcut(wShareResults.qsPublish, sendToChat(chatColours['Orange'] .. replaceCharacters(translate('msgProvisionalResults'), nonbasicCharactersInChat) .. chatColours['Closure'], config['GAME']['GameChannel'], '', true) .. '\n'  .. printResults('', '', 'Append'))
		end
		wShareResults.qsPublish:SetEnabled(true)
		wShareResults.qsPublish:SetVisible(true)
		wShareResults.btnPublish = createOverlayButton(wShareResults.qsPublish, wShareResults, replaceCharacters(replaceCharacters(translate('txtPublishResults'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui), wShareResults.qsPublish:GetLeft(), wShareResults.qsPublish:GetTop(), wShareResults.qsPublish:GetWidth(), wShareResults.qsPublish:GetHeight(), wShareResults.qsPublish:GetZOrder(), 2) -- Although named "btn" what we get is really the generic control parent to graphics and text that does the appareance trick
		
		
		function wShareResults:Deactivated(sender,args) -- Make it stay always on top
			if (wShareResults ~= nil) then
				wShareResults:Activate()
				wShareResults:Focus()
			end
		end
		
		function wShareResults:Closing(sender,args)
			savePosition(wShareResults, 'ShareResults', wShareResults:GetLeft(), wShareResults:GetTop())
		end
	else -- Destroy
		if (wShareResults ~= nil) then
			wShareResults:Close()
			wShareResults = nil
		end
	end
end

-- This is the window to browse the Quiz Library and select packages for the game
function quizLibrary(create)
	if (create == true) then
		local guiColumnWidth = 300
		local availablePackages = quizPackageList(quizLib)
		local packageListSize = math.min(#availablePackages, 15)
		local guiColumnNumber = 2
		local guiWidth = (guiColumnNumber * guiColumnWidth) + ((guiColumnNumber + 1) * guiSpacing)
		local guiHeight =  guiCtrlHeigth * (10 + packageListSize)
		local posX,posY = calcDefaultWindowPos('QuizLibrary', guiWidth, guiHeight)
		local numberOfQuestions = 0

		-- CREATE WINDOW
		wQuizLibrary = Turbine.UI.Lotro.Window()
		wQuizLibrary:SetSize(guiWidth, guiHeight)
		wQuizLibrary:SetPosition(posX, posY)
		wQuizLibrary:SetText(replaceCharacters(replaceCharacters(translate('txtQuizLibrary'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wQuizLibrary:SetZOrder(200)

		-- Quiz Library information label
		wQuizLibrary.lblQuizLibraryInfo = Turbine.UI.Label()
		wQuizLibrary.lblQuizLibraryInfo:SetParent(wQuizLibrary)
		wQuizLibrary.lblQuizLibraryInfo:SetPosition(guiSpacing, guiCtrlHeigth * 2)
		wQuizLibrary.lblQuizLibraryInfo:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth * 2)
		wQuizLibrary.lblQuizLibraryInfo:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wQuizLibrary.lblQuizLibraryInfo:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		wQuizLibrary.lblQuizLibraryInfo:SetText(replaceCharacters(replaceCharacters(translate('txtQuizLibraryInfo'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wQuizLibrary.lblQuizLibraryInfo:SetZOrder(210)
		-- Package List title
		wQuizLibrary.lblPackageListTitle = Turbine.UI.Label()
		wQuizLibrary.lblPackageListTitle:SetParent(wQuizLibrary)
		wQuizLibrary.lblPackageListTitle:SetPosition(guiSpacing, guiCtrlHeigth * 4)
		wQuizLibrary.lblPackageListTitle:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth)
		wQuizLibrary.lblPackageListTitle:SetForeColor(Turbine.UI.Color(1,0.843,0))
		wQuizLibrary.lblPackageListTitle:SetFont(Turbine.UI.Lotro.Font.TrajanPro18)
		wQuizLibrary.lblPackageListTitle:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		wQuizLibrary.lblPackageListTitle:SetText(replaceCharacters(replaceCharacters(translate('txtPackageList'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wQuizLibrary.lblPackageListTitle:SetZOrder(210)
		-- Box with the list of participants and suggested points
		wQuizLibrary.boxList = Turbine.UI.ListBox()
		wQuizLibrary.boxList:SetParent(wQuizLibrary)
		wQuizLibrary.boxList:SetPosition(guiSpacing, guiCtrlHeigth * 5)
		wQuizLibrary.boxList:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth * packageListSize)
		wQuizLibrary.boxList:SetZOrder(210)
		local defaultColor = Turbine.UI.Color(0, 0, 0)
		local selectedColor = Turbine.UI.Color(0.404, 0, 0.404) -- Very Dark Magenta
		local listItems = {}
		for i,v in ipairs(availablePackages) do
			listItems[i] = {}
			local packageRow = Turbine.UI.Control()
			packageRow:SetParent(wQuizLibrary.boxList)
			packageRow:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth)
			-- Package name
			listItems[i][1] = Turbine.UI.Label()
			listItems[i][1]:SetParent(packageRow)
			listItems[i][1]:SetPosition(0, 0)
			listItems[i][1]:SetSize(guiWidth - guiSpacing * 2 - 12, guiCtrlHeigth)
			listItems[i][1]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
			listItems[i][1]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
			listItems[i][1]:SetText(v['Summary'])
			listItems[i][3] = v['Questions']
			if (config['GAME']['SelectedQuiz'][i] == true) then
				listItems[i][2] = true
				listItems[i][1]:SetBackColor(selectedColor)
				numberOfQuestions = numberOfQuestions + listItems[i][3] 
			else
				listItems[i][2] = false
				listItems[i][1]:SetBackColor(defaultColor)
			end
			listItems[i][1].MouseClick = function() -- Toggle selection
					if (listItems[i][2] == true) then
						listItems[i][2] = false
						listItems[i][1]:SetBackColor(defaultColor)
						numberOfQuestions = numberOfQuestions - listItems[i][3] 
						wQuizLibrary.lblNumberOfQuestions:SetText(tostring(numberOfQuestions) .. ' ' .. replaceCharacters(replaceCharacters(translate('txtQuestions'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
					else
						listItems[i][2] = true
						listItems[i][1]:SetBackColor(selectedColor)
						numberOfQuestions = numberOfQuestions + listItems[i][3] 
						wQuizLibrary.lblNumberOfQuestions:SetText(tostring(numberOfQuestions) .. ' ' .. replaceCharacters(replaceCharacters(translate('txtQuestions'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
					end
				end
			wQuizLibrary.boxList:AddItem(packageRow)
		end
		-- Scrollbar for package list
		wQuizLibrary.vScroll = Turbine.UI.Lotro.ScrollBar()
		wQuizLibrary.vScroll:SetParent(wQuizLibrary)
		wQuizLibrary.vScroll:SetOrientation(Turbine.UI.Orientation.Vertical)
		wQuizLibrary.vScroll:SetPosition(wQuizLibrary.boxList:GetLeft() + wQuizLibrary.boxList:GetWidth(), wQuizLibrary.boxList:GetTop())
		wQuizLibrary.vScroll:SetSize(12, wQuizLibrary.boxList:GetHeight())
		wQuizLibrary.vScroll:SetZOrder(210)
		wQuizLibrary.boxList:SetVerticalScrollBar(wQuizLibrary.vScroll)		
		-- Number of questions label
		wQuizLibrary.lblNumberOfQuestions = Turbine.UI.Label()
		wQuizLibrary.lblNumberOfQuestions:SetParent(wQuizLibrary)
		wQuizLibrary.lblNumberOfQuestions:SetPosition(guiWidth / 2 + guiButtonWidth / 2 - guiSpacing, guiCtrlHeigth * (5 + packageListSize))
		wQuizLibrary.lblNumberOfQuestions:SetSize(guiWidth / 2 - guiButtonWidth / 2 - guiSpacing, guiCtrlHeigth)
		wQuizLibrary.lblNumberOfQuestions:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wQuizLibrary.lblNumberOfQuestions:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
		wQuizLibrary.lblNumberOfQuestions:SetText(tostring(numberOfQuestions) .. ' ' .. replaceCharacters(replaceCharacters(translate('txtQuestions'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
		wQuizLibrary.lblNumberOfQuestions:SetZOrder(210)		
		-- Clear selection button
		wQuizLibrary.btnClearSelection = Turbine.UI.Lotro.Button()
		wQuizLibrary.btnClearSelection:SetParent(wQuizLibrary)
		wQuizLibrary.btnClearSelection:SetPosition(guiWidth / 2 - (guiButtonWidth) / 2, guiCtrlHeigth * (6 + packageListSize))
		wQuizLibrary.btnClearSelection:SetSize(guiButtonWidth, guiCtrlHeigth)
		wQuizLibrary.btnClearSelection:SetEnabled(true)
		wQuizLibrary.btnClearSelection:SetText(replaceCharacters(replaceCharacters(translate('txtClearSelection'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wQuizLibrary.btnClearSelection:SetZOrder(210)
		wQuizLibrary.btnClearSelection.Click = function(sender,args)
				for i,v in ipairs(listItems) do
					listItems[i][1]:SetBackColor(defaultColor)
					listItems[i][2] = false
					numberOfQuestions = 0
					wQuizLibrary.lblNumberOfQuestions:SetText(tostring(numberOfQuestions) .. ' ' .. replaceCharacters(replaceCharacters(translate('txtQuestions'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
				end
			end
		-- Accept button
		wQuizLibrary.btnAccept = Turbine.UI.Lotro.Button()
		wQuizLibrary.btnAccept:SetParent(wQuizLibrary)
		wQuizLibrary.btnAccept:SetPosition((guiWidth / 2) - guiButtonWidth - (guiSpacing / 2), guiCtrlHeigth * (8 + packageListSize))
		wQuizLibrary.btnAccept:SetSize(guiButtonWidth, guiCtrlHeigth)
		wQuizLibrary.btnAccept:SetEnabled(true)
		wQuizLibrary.btnAccept:SetText(replaceCharacters(replaceCharacters(translate('txtAccept'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wQuizLibrary.btnAccept:SetZOrder(210)
		wQuizLibrary.btnAccept.Click = function(sender,args)
				for i,v in ipairs(listItems) do
					config['GAME']['SelectedQuiz'][i] = listItems[i][2]
				end
				quizPackage = loadQuiz(config['GAME']['SelectedQuiz'])
				if (quizPackage == nil) then -- No package selected.
					quizPackage = defaultQuizLib[1]
				end
				dataManagement(config, 'Save', 'Istelien_config')
				quizLibrary(false)
			end
		-- Cancel button
		wQuizLibrary.btnCancel = Turbine.UI.Lotro.Button()
		wQuizLibrary.btnCancel:SetParent(wQuizLibrary)
		wQuizLibrary.btnCancel:SetPosition((guiWidth / 2) + (guiSpacing / 2), guiCtrlHeigth * (8 + packageListSize))
		wQuizLibrary.btnCancel:SetSize(guiButtonWidth, guiCtrlHeigth)
		wQuizLibrary.btnCancel:SetEnabled(true)
		wQuizLibrary.btnCancel:SetText(replaceCharacters(replaceCharacters(translate('txtCancel'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wQuizLibrary.btnCancel:SetZOrder(210)
		wQuizLibrary.btnCancel.Click = function(sender,args)
				quizLibrary(false)
			end

		function wQuizLibrary:Closing(sender,args)
			savePosition(wQuizLibrary, 'QuizLibrary', wQuizLibrary:GetLeft(), wQuizLibrary:GetTop())
		end
	else -- Destroy
		if (wQuizLibrary ~= nil) then
			wQuizLibrary:Close()
			wQuizLibrary = nil
		end
	end
end

-- This is the window to set the custom scoring, which depends on answer word count
function customizeScores(create)
	if (create == true) then
		local guiColumnWidth = 70
		local guiButtonWidth = guiColumnWidth
		local scoreList = config['SCORING']['CustomScores']
		local scoreListSize = math.min(math.max(#scoreList + 1, 10), 10)
		local guiColumnNumber = 2
		local guiWidth = (guiColumnNumber * guiColumnWidth) + (guiColumnNumber  * guiSpacing) + (guiSpacing * 3)
		local guiHeight =  guiCtrlHeigth * (9 + scoreListSize)
		local posX,posY = calcDefaultWindowPos('CustomizeScores', guiWidth, guiHeight)

		-- CREATE WINDOW
		wCustomizeScores = Turbine.UI.Lotro.Window()
		wCustomizeScores:SetSize(guiWidth, guiHeight)
		wCustomizeScores:SetPosition(posX,posY)
		wCustomizeScores:SetText(replaceCharacters(replaceCharacters(translate('txtCustomizeScores'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wCustomizeScores:SetZOrder(200)

		-- Customize Scores information label
		wCustomizeScores.lblCustomizeScoresInfo = Turbine.UI.Label()
		wCustomizeScores.lblCustomizeScoresInfo:SetParent(wCustomizeScores)
		wCustomizeScores.lblCustomizeScoresInfo:SetPosition(guiSpacing, guiCtrlHeigth * 2)
		wCustomizeScores.lblCustomizeScoresInfo:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth * 3)
		wCustomizeScores.lblCustomizeScoresInfo:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wCustomizeScores.lblCustomizeScoresInfo:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		wCustomizeScores.lblCustomizeScoresInfo:SetText(replaceCharacters(replaceCharacters(translate('txtCustomizeScoresInfo'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
		wCustomizeScores.lblCustomizeScoresInfo:SetZOrder(210)

		-- Box with the list of answer length and configured points
		wCustomizeScores.boxList = Turbine.UI.ListBox()
		wCustomizeScores.boxList:SetParent(wCustomizeScores)
		wCustomizeScores.boxList:SetPosition(guiSpacing, guiCtrlHeigth * 5)
		wCustomizeScores.boxList:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth * scoreListSize)
		wCustomizeScores.boxList:SetZOrder(210)
		local listItems = {}
		local maxPoints = 0
		for i,v in ipairs(scoreList) do
			local wordString = replaceCharacters(replaceCharacters(translate('txtWords'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
			local pointString = replaceCharacters(replaceCharacters(translate('txtPoints'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
			maxPoints = math.max(maxPoints, v)
			if (i == 1) then
				wordString = replaceCharacters(replaceCharacters(translate('txtWord'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
			end
			if (v == 1) then
				pointString = replaceCharacters(replaceCharacters(translate('txtPoint'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
			end
			listItems[i] = {}
			local playerRow = Turbine.UI.Control()
			playerRow:SetParent(wCustomizeScores.boxList)
			playerRow:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth)
			-- Word count
			listItems[i][1] = Turbine.UI.Label()
			listItems[i][1]:SetParent(playerRow)
			listItems[i][1]:SetPosition(0, 0)
			listItems[i][1]:SetSize(guiColumnWidth + guiSpacing, guiCtrlHeigth)
			listItems[i][1]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
			listItems[i][1]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
			listItems[i][1]:SetText(i .. ' ' .. wordString .. ':')
			-- Input for points
			listItems[i][2] = Turbine.UI.Lotro.TextBox()
			listItems[i][2]:SetParent(playerRow)
			listItems[i][2]:SetPosition(guiColumnWidth + guiSpacing, 0)
			listItems[i][2]:SetSize(guiSpacing * 2, guiCtrlHeigth)
			listItems[i][2]:SetMultiline(false)
			listItems[i][2]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
			listItems[i][2]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
			if (v == nil) then -- This shouldn't happen
				listItems[i][2]:SetText('0')
			else
				listItems[i][2]:SetText(tostring(v))
			end
			listItems[i][2].FocusLost = function(Sender,Args)
				local newValue = validateNumberString(listItems[i][2]:GetText(), 0.01, 1000, 2)
				if (newValue == nil) then
					listItems[i][2]:SetText('0')
				else
					if (tonumber(newValue) == 1) then
						listItems[i][3]:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtPoint'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
					else
						listItems[i][3]:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtPoints'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
					end
				end
				maxPoints = math.max(maxPoints, newValue)
			end
			-- Word points adj
			listItems[i][3] = Turbine.UI.Label()
			listItems[i][3]:SetParent(playerRow)
			listItems[i][3]:SetPosition(guiColumnWidth + guiSpacing * 3, 0)
			listItems[i][3]:SetSize(guiColumnWidth, guiCtrlHeigth)
			listItems[i][3]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
			listItems[i][3]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
			listItems[i][3]:SetText(' ' .. pointString .. '.')
			wCustomizeScores.boxList:AddItem(playerRow)
		end
		-- We put the 'More words' as final element
		listItems[0] = {}
		local playerRow = Turbine.UI.Control()
		playerRow:SetParent(wCustomizeScores.boxList)
		playerRow:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth)
		listItems[0][1] = Turbine.UI.Label()
		listItems[0][1]:SetParent(playerRow)
		listItems[0][1]:SetPosition(0, 0)
		listItems[0][1]:SetSize(guiColumnWidth + guiSpacing, guiCtrlHeigth)
		listItems[0][1]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		listItems[0][1]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		listItems[0][1]:SetText(replaceCharacters(replaceCharacters(translate('txtMore'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ':')
		listItems[0][2] = Turbine.UI.Lotro.TextBox()
		listItems[0][2]:SetParent(playerRow)
		listItems[0][2]:SetPosition(guiColumnWidth + guiSpacing, 0)
		listItems[0][2]:SetSize(guiSpacing * 2, guiCtrlHeigth)
		listItems[0][2]:SetMultiline(false)
		listItems[0][2]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		listItems[0][2]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		if (scoreList[0] == nil) then -- This shouldn't happen
			listItems[0][2]:SetText(maxPoints)
		else
			listItems[0][2]:SetText(scoreList[0])
			if (scoreList[0] == 1) then
				pointString = replaceCharacters(replaceCharacters(translate('txtPoint'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
			else
				pointString = replaceCharacters(replaceCharacters(translate('txtPoints'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
			end
		end
		listItems[0][2].FocusLost = function(Sender,Args)
			local newValue = validateNumberString(listItems[0][2]:GetText(), 0.01, 1000, 2)	 -- We'll allow any positive value, despite it's designed to be the space for the most lengthy answers and thus most scoring one.
			if (newValue == nil) then
				listItems[0][2]:SetText(maxPoints)
			else
				if (tonumber(newValue) == 1) then
					listItems[0][3]:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtPoint'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
				else
					listItems[0][3]:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtPoints'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
				end
				maxPoints = math.max(maxPoints, newValue)
			end
		end
		listItems[0][3] = Turbine.UI.Label()
		listItems[0][3]:SetParent(playerRow)
		listItems[0][3]:SetPosition(guiColumnWidth + guiSpacing * 3, 0)
		listItems[0][3]:SetSize(guiColumnWidth, guiCtrlHeigth)
		listItems[0][3]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		listItems[0][3]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		listItems[0][3]:SetText(' ' .. pointString .. '.')
		wCustomizeScores.boxList:AddItem(playerRow)
		-- Scrollbar for Words list
		wCustomizeScores.vScroll = Turbine.UI.Lotro.ScrollBar()
		wCustomizeScores.vScroll:SetParent(wCustomizeScores)
		wCustomizeScores.vScroll:SetOrientation(Turbine.UI.Orientation.Vertical)
		wCustomizeScores.vScroll:SetPosition(wCustomizeScores.boxList:GetLeft() + wCustomizeScores.boxList:GetWidth(), wCustomizeScores.boxList:GetTop())
		wCustomizeScores.vScroll:SetSize(12, wCustomizeScores.boxList:GetHeight())
		wCustomizeScores.vScroll:SetZOrder(210)
		wCustomizeScores.boxList:SetVerticalScrollBar(wCustomizeScores.vScroll)
		-- Add line button
		wCustomizeScores.btnAddLine = Turbine.UI.Lotro.Button()
		wCustomizeScores.btnAddLine:SetParent(wCustomizeScores)
		wCustomizeScores.btnAddLine:SetPosition((guiWidth / 2) - guiButtonWidth - (guiSpacing / 2), guiCtrlHeigth * (5 + scoreListSize))
		wCustomizeScores.btnAddLine:SetSize(guiButtonWidth, guiCtrlHeigth)
		wCustomizeScores.btnAddLine:SetEnabled(true)
		wCustomizeScores.btnAddLine:SetText(replaceCharacters(replaceCharacters(translate('txtAddLine'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wCustomizeScores.btnAddLine:SetZOrder(210)
		wCustomizeScores.btnAddLine.Click = function(sender,args)
				local newIndex = wCustomizeScores.boxList:GetItemCount() -- Because there's one element ("More") that has index 0, the total count will be the appropriate index for the new element
				savedMaxItem = wCustomizeScores.boxList:GetItem(newIndex) -- Get a copy of the ("More) element
				wCustomizeScores.boxList:RemoveItemAt(newIndex) -- Delete it to place the new one on its location
				-- Create another row.
				pointValue = maxPoints
				if (newIndex == 1) then
					wordString = replaceCharacters(replaceCharacters(translate('txtWord'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
				else
					wordString = replaceCharacters(replaceCharacters(translate('txtWords'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
				end
				if (pointValue == 1) then
					pointString = replaceCharacters(replaceCharacters(translate('txtPoint'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
				else
					pointString = replaceCharacters(replaceCharacters(translate('txtPoints'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
				end
				listItems[newIndex] = {}
				local playerRow = Turbine.UI.Control()
				playerRow:SetParent(wCustomizeScores.boxList)
				playerRow:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth)
				-- Word count
				listItems[newIndex][1] = Turbine.UI.Label()
				listItems[newIndex][1]:SetParent(playerRow)
				listItems[newIndex][1]:SetPosition(0, 0)
				listItems[newIndex][1]:SetSize(guiColumnWidth + guiSpacing, guiCtrlHeigth)
				listItems[newIndex][1]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
				listItems[newIndex][1]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
				listItems[newIndex][1]:SetText(newIndex .. ' ' .. wordString .. ':')
				-- Input for points
				listItems[newIndex][2] = Turbine.UI.Lotro.TextBox()
				listItems[newIndex][2]:SetParent(playerRow)
				listItems[newIndex][2]:SetPosition(guiColumnWidth + guiSpacing, 0)
				listItems[newIndex][2]:SetSize(guiSpacing * 2, guiCtrlHeigth)
				listItems[newIndex][2]:SetMultiline(false)
				listItems[newIndex][2]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
				listItems[newIndex][2]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
				listItems[newIndex][2]:SetText(tostring(pointValue))
				listItems[newIndex][2].FocusLost = function(Sender,Args)
					local newValue = validateNumberString(listItems[newIndex][2]:GetText(), 0.01, 1000, 2)
					if (newValue == nil) then
						listItems[newIndex][2]:SetText('0')
					else
						if (tonumber(newValue) == 1) then
							listItems[newIndex][3]:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtPoint'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
						else
							listItems[newIndex][3]:SetText(' ' .. replaceCharacters(replaceCharacters(translate('txtPoints'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
						end
					end
					maxPoints = math.max(maxPoints, newValue)
			end
			-- Word points adj
			listItems[newIndex][3] = Turbine.UI.Label()
			listItems[newIndex][3]:SetParent(playerRow)
			listItems[newIndex][3]:SetPosition(guiColumnWidth + guiSpacing * 3, 0)
			listItems[newIndex][3]:SetSize(guiColumnWidth, guiCtrlHeigth)
			listItems[newIndex][3]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
			listItems[newIndex][3]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
			listItems[newIndex][3]:SetText(' ' .. pointString .. '.')
			-- Append the new row. We put the ("More") element at again so it's always the last in the list to preserve the mechanic for any other future insertion or deletion.
			wCustomizeScores.boxList:AddItem(playerRow)
			wCustomizeScores.boxList:AddItem(savedMaxItem)
			end
		-- Remove line button
		wCustomizeScores.btnRemoveLine = Turbine.UI.Lotro.Button()
		wCustomizeScores.btnRemoveLine:SetParent(wCustomizeScores)
		wCustomizeScores.btnRemoveLine:SetPosition((guiWidth / 2) + (guiSpacing / 2), guiCtrlHeigth * (5 + scoreListSize))
		wCustomizeScores.btnRemoveLine:SetSize(guiButtonWidth, guiCtrlHeigth)
		wCustomizeScores.btnRemoveLine:SetEnabled(true)
		wCustomizeScores.btnRemoveLine:SetText(replaceCharacters(replaceCharacters(translate('txtRemoveLine'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wCustomizeScores.btnRemoveLine:SetZOrder(210)
		wCustomizeScores.btnRemoveLine.Click = function(sender,args)
				wCustomizeScores.boxList:RemoveItemAt(wCustomizeScores.boxList:GetItemCount() - 1) -- We don't want to remove the last element of boxList ("More")
			end
		-- Accept button
		wCustomizeScores.btnAccept = Turbine.UI.Lotro.Button()
		wCustomizeScores.btnAccept:SetParent(wCustomizeScores)
		wCustomizeScores.btnAccept:SetPosition((guiWidth / 2) - guiButtonWidth - (guiSpacing / 2), guiCtrlHeigth * (7 + scoreListSize))
		wCustomizeScores.btnAccept:SetSize(guiButtonWidth, guiCtrlHeigth)
		wCustomizeScores.btnAccept:SetEnabled(true)
		wCustomizeScores.btnAccept:SetText(replaceCharacters(replaceCharacters(translate('txtAccept'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wCustomizeScores.btnAccept:SetZOrder(210)
		wCustomizeScores.btnAccept.Click = function(sender,args)
				for i,v in ipairs(listItems) do
					config['SCORING']['CustomScores'][i] = tonumber(v[2]:GetText())
				end
				config['SCORING']['CustomScores'][0] = tonumber(listItems[0][2]:GetText())
				customizeScores(false)
				dataManagement(config, 'Save', 'Istelien_config')
			end
		-- Cancel button
		wCustomizeScores.btnCancel = Turbine.UI.Lotro.Button()
		wCustomizeScores.btnCancel:SetParent(wCustomizeScores)
		wCustomizeScores.btnCancel:SetPosition((guiWidth / 2) + (guiSpacing / 2), guiCtrlHeigth * (7 + scoreListSize))
		wCustomizeScores.btnCancel:SetSize(guiButtonWidth, guiCtrlHeigth)
		wCustomizeScores.btnCancel:SetEnabled(true)
		wCustomizeScores.btnCancel:SetText(replaceCharacters(replaceCharacters(translate('txtCancel'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wCustomizeScores.btnCancel:SetZOrder(210)
		wCustomizeScores.btnCancel.Click = function(sender,args)
				customizeScores(false)
			end

		function wCustomizeScores:Closing(sender,args)
			savePosition(wCustomizeScores, 'CustomizeScores', wCustomizeScores:GetLeft(), wCustomizeScores:GetTop())
		end
	else -- Destroy
		if (wCustomizeScores ~= nil) then
			wCustomizeScores:Close()
			wCustomizeScores = nil
		end
	end
end

-- This is the window to create and delete teams, declare or remove players and link them both.
function teamsManager(create)
	if (create == true) then
		local guiButtonWidth = guiColumnWidth
		local guiSmallButtonWidth = guiSpacing * 2
		local guiInterBoxSpace1 = guiSpacing / 2
		local guiInterBoxSpace2 = guiSpacing * 3
		local guiColumnNumber = 3
		local guiWidth = (guiColumnNumber * guiColumnWidth) + (guiSpacing * 2) + guiInterBoxSpace1 + guiInterBoxSpace2
		local guiHeight =  guiCtrlHeigth * 18
		local posX,posY = calcDefaultWindowPos('TeamsManager', guiWidth, guiHeight)
		local boxListsSize = 9
		local defaultColor = Turbine.UI.Color(0.106, 0.106, 0.106) -- Almost black
		local selectedColor = Turbine.UI.Color(0.404, 0, 0.404) -- Very Dark Magenta
		local inTeamColor = Turbine.UI.Color(0.259, 0.259, 0.259) -- Very Dark Grey
		local selectedPlayer = ''
		local selectedTeam = ''
		local selectedMember = ''

		-- Function to call for build the listboxes' content or rebuild them when there's an update
		function refreshTMList(list, parentControl)
			parentControl:ClearItems()
			local listItems = {}
			if (#list > 0) then
				for i,v in ipairs(list) do
					local row = Turbine.UI.Control()
					row:SetParent(wTeamsManager.teamsBoxList)
					row:SetSize(guiColumnWidth, guiCtrlHeigth)
					-- Team name
					listItems[i]= Turbine.UI.Label()
					listItems[i]:SetParent(row)
					listItems[i]:SetPosition(guiInterBoxSpace1, 0)
					listItems[i]:SetSize(guiColumnWidth - (guiInterBoxSpace1 * 2) - 5, guiCtrlHeigth)
					if (parentControl == wTeamsManager.playersBoxList) then
						if (gameParticipants['Players'][v]['Team'] ~= nil) then
							listItems[i]:SetForeColor(inTeamColor) -- Very Dark Grey
						end
					end
					listItems[i]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
					listItems[i]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
					listItems[i]:SetText(v)
					listItems[i].MouseClick = function(sender) -- Select item
							for i,v in ipairs(listItems) do
								listItems[i]:SetBackColor(defaultColor)
							end
							sender:SetBackColor(selectedColor)
							if (parentControl == wTeamsManager.teamsBoxList) then
								selectedTeam = sender:GetText()
								local memberList = listTeamMembers('', selectedTeam)
								if (memberList == nil) then
									memberList = {}
								end
								refreshTMList(memberList, wTeamsManager.membersBoxList)
								remapShortcut(wTeamsManager.qsAnnounceMembers, printPlayers(selectedPlayer, selectedTeam, config['GAME']['GameChannel']))
								wTeamsManager.qsAnnounceMembers:SetEnabled(true)
								wTeamsManager.qsAnnounceMembers:SetVisible(true)
								wTeamsManager.btnAnnounceMembers:SetEnabled(true)
								wTeamsManager.btnAnnounceMembers:SetVisible(true)
							else
								if (parentControl == wTeamsManager.membersBoxList) then
									selectedMember = sender:GetText()
								else
									selectedPlayer = sender:GetText()
								end
							end
							-- Turbine.Shell.WriteLine('selectedTeam:' .. selectedTeam .. '- selectedMember:' .. selectedMember .. ' - selectedPlayer:' .. selectedPlayer) -- DEBUG
						end
					parentControl:AddItem(row)
				end
				-- Scrollbar 
				if (parentControl:GetVerticalScrollBar() == nil) then
					listScrollBar = Turbine.UI.Lotro.ScrollBar()
					listScrollBar:SetParent(wTeamsManager)
					listScrollBar:SetOrientation(Turbine.UI.Orientation.Vertical)
					listScrollBar:SetPosition(parentControl:GetLeft() + parentControl:GetWidth(), parentControl:GetTop())
					listScrollBar:SetSize(12, parentControl:GetHeight())
					listScrollBar:SetZOrder(210)
					parentControl:SetVerticalScrollBar(listScrollBar)
				end
			end
		end
		
		-- CREATE WINDOW
		wTeamsManager = Turbine.UI.Lotro.Window()
		wTeamsManager:SetSize(guiWidth, guiHeight)
		wTeamsManager:SetPosition(posX, posY)
		wTeamsManager:SetText(replaceCharacters(replaceCharacters(translate('txtTeamsManager'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wTeamsManager:SetZOrder(200)

		-- Team list information label
		wTeamsManager.lblAvailableTeams = Turbine.UI.Label()
		wTeamsManager.lblAvailableTeams:SetParent(wTeamsManager)
		wTeamsManager.lblAvailableTeams:SetPosition(guiSpacing, guiCtrlHeigth * 2)
		wTeamsManager.lblAvailableTeams:SetSize(guiColumnWidth, guiCtrlHeigth)
		wTeamsManager.lblAvailableTeams:SetForeColor(Turbine.UI.Color(1,0.843,0))
		wTeamsManager.lblAvailableTeams:SetFont(Turbine.UI.Lotro.Font.TrajanPro18)
		wTeamsManager.lblAvailableTeams:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		wTeamsManager.lblAvailableTeams:SetText(replaceCharacters(replaceCharacters(translate('txtAvailableTeams'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wTeamsManager.lblAvailableTeams:SetZOrder(210)
		-- Team members information label
		wTeamsManager.lblTeamMembers = Turbine.UI.Label()
		wTeamsManager.lblTeamMembers:SetParent(wTeamsManager)
		wTeamsManager.lblTeamMembers:SetPosition(guiSpacing + guiColumnWidth + guiInterBoxSpace1, guiCtrlHeigth * 2)
		wTeamsManager.lblTeamMembers:SetSize(guiColumnWidth, guiCtrlHeigth)
		wTeamsManager.lblTeamMembers:SetForeColor(Turbine.UI.Color(1,0.843,0))
		wTeamsManager.lblTeamMembers:SetFont(Turbine.UI.Lotro.Font.TrajanPro18)
		wTeamsManager.lblTeamMembers:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		wTeamsManager.lblTeamMembers:SetText(replaceCharacters(replaceCharacters(translate('txtTeamMembers'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wTeamsManager.lblTeamMembers:SetZOrder(210)
		-- Player list information label
		wTeamsManager.lblRegisteredPlayers = Turbine.UI.Label()
		wTeamsManager.lblRegisteredPlayers:SetParent(wTeamsManager)
		wTeamsManager.lblRegisteredPlayers:SetPosition(guiSpacing + guiColumnWidth * 2 + guiInterBoxSpace1 + guiInterBoxSpace2, guiCtrlHeigth * 2)
		wTeamsManager.lblRegisteredPlayers:SetSize(guiColumnWidth, guiCtrlHeigth)
		wTeamsManager.lblRegisteredPlayers:SetForeColor(Turbine.UI.Color(1,0.843,0))
		wTeamsManager.lblRegisteredPlayers:SetFont(Turbine.UI.Lotro.Font.TrajanPro18)
		wTeamsManager.lblRegisteredPlayers:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		wTeamsManager.lblRegisteredPlayers:SetText(replaceCharacters(replaceCharacters(translate('txtRegisteredPlayers'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wTeamsManager.lblRegisteredPlayers:SetZOrder(210)

		-- Box with the list of teams
		wTeamsManager.teamsBoxList = Turbine.UI.ListBox()
		wTeamsManager.teamsBoxList:SetParent(wTeamsManager)
		wTeamsManager.teamsBoxList:SetPosition(guiSpacing, guiCtrlHeigth * 3)
		wTeamsManager.teamsBoxList:SetSize(guiColumnWidth - 5, guiCtrlHeigth * boxListsSize)
		wTeamsManager.teamsBoxList:SetBackColor(defaultColor)
		wTeamsManager.teamsBoxList:SetZOrder(210)
		local teamList = listParticipants('Teams')
		refreshTMList(teamList, wTeamsManager.teamsBoxList)
		-- Box with the team members
		wTeamsManager.membersBoxList = Turbine.UI.ListBox()
		wTeamsManager.membersBoxList:SetParent(wTeamsManager)
		wTeamsManager.membersBoxList:SetPosition(guiSpacing + guiColumnWidth + guiInterBoxSpace1, guiCtrlHeigth * 3)
		wTeamsManager.membersBoxList:SetSize(guiColumnWidth - 5, guiCtrlHeigth * boxListsSize)
		wTeamsManager.membersBoxList:SetBackColor(defaultColor)
		wTeamsManager.membersBoxList:SetZOrder(210)
		local memberList = {}
		refreshTMList(memberList, wTeamsManager.membersBoxList)
		-- Box with the list of registered players
		wTeamsManager.playersBoxList = Turbine.UI.ListBox()
		wTeamsManager.playersBoxList:SetParent(wTeamsManager)
		wTeamsManager.playersBoxList:SetPosition(guiSpacing + guiColumnWidth * 2 + guiInterBoxSpace1 + guiInterBoxSpace2, guiCtrlHeigth * 3)
		wTeamsManager.playersBoxList:SetSize(guiColumnWidth - 5, guiCtrlHeigth * boxListsSize)
		wTeamsManager.playersBoxList:SetBackColor(defaultColor)
		wTeamsManager.playersBoxList:SetZOrder(210)
		local playerList = listParticipants('Players')
		refreshTMList(playerList, wTeamsManager.playersBoxList)

		-- Add Member button
		wTeamsManager.btnAddMember = Turbine.UI.Lotro.Button()
		wTeamsManager.btnAddMember:SetParent(wTeamsManager)
		wTeamsManager.btnAddMember:SetPosition(guiSpacing + guiColumnWidth * 2 + guiInterBoxSpace1 + (guiInterBoxSpace2 / 2) - (guiSmallButtonWidth / 2), guiCtrlHeigth * 6)
		wTeamsManager.btnAddMember:SetSize(guiSmallButtonWidth, guiCtrlHeigth)
		wTeamsManager.btnAddMember:SetEnabled(true)
		wTeamsManager.btnAddMember:SetText(replaceCharacters(replaceCharacters(translate('txtAddMember'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wTeamsManager.btnAddMember:SetZOrder(210)
		wTeamsManager.btnAddMember.Click = function(sender,args)
				if (selectedTeam ~= '') then
					joinTeam(selectedPlayer, selectedTeam)
					local memberList = listTeamMembers(selectedPlayer, selectedTeam)
					refreshTMList(memberList, wTeamsManager.membersBoxList)
					local playerList = listParticipants('Players')
					refreshTMList(playerList, wTeamsManager.playersBoxList)
					remapShortcut(wTeamsManager.qsAnnounceMembers, printPlayers(selectedPlayer, selectedTeam, config['GAME']['GameChannel']))
					wTeamsManager.qsAnnounceMembers:SetEnabled(true)
					wTeamsManager.qsAnnounceMembers:SetVisible(true)
					wTeamsManager.btnAnnounceMembers:SetEnabled(true)
					wTeamsManager.btnAnnounceMembers:SetVisible(true)
				end
			end
		-- Delete Member button
		wTeamsManager.btnDeleteMember = Turbine.UI.Lotro.Button()
		wTeamsManager.btnDeleteMember:SetParent(wTeamsManager)
		wTeamsManager.btnDeleteMember:SetPosition(guiSpacing + guiColumnWidth * 2 + guiInterBoxSpace1 + (guiInterBoxSpace2 / 2) - (guiSmallButtonWidth / 2), guiCtrlHeigth * 8)
		wTeamsManager.btnDeleteMember:SetSize(guiSmallButtonWidth, guiCtrlHeigth)
		wTeamsManager.btnDeleteMember:SetEnabled(true)
		wTeamsManager.btnDeleteMember:SetText(replaceCharacters(replaceCharacters(translate('txtDeleteMember'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wTeamsManager.btnDeleteMember:SetZOrder(210)
		wTeamsManager.btnDeleteMember.Click = function(sender,args)
				if (selectedMember ~= '') then
					leaveTeam(selectedMember)
					local memberList = listTeamMembers(selectedPlayer, selectedTeam)
					refreshTMList(memberList, wTeamsManager.membersBoxList)
					selectedMember = ''
					local playerList = listParticipants('Players')
					refreshTMList(playerList, wTeamsManager.playersBoxList)
					remapShortcut(wTeamsManager.qsAnnounceMembers, printPlayers(selectedPlayer, selectedTeam, config['GAME']['GameChannel']))
					wTeamsManager.qsAnnounceMembers:SetEnabled(true)
					wTeamsManager.qsAnnounceMembers:SetVisible(true)
					wTeamsManager.btnAnnounceMembers:SetEnabled(true)
					wTeamsManager.btnAnnounceMembers:SetVisible(true)
				end
			end
		-- Add Team button
		wTeamsManager.btnAddTeam = Turbine.UI.Lotro.Button()
		wTeamsManager.btnAddTeam:SetParent(wTeamsManager)
		wTeamsManager.btnAddTeam:SetPosition(guiSpacing + (guiColumnWidth / 2) - guiSmallButtonWidth - (guiSpacing / 2), guiCtrlHeigth * 12)
		wTeamsManager.btnAddTeam:SetSize(guiSmallButtonWidth, guiCtrlHeigth)
		wTeamsManager.btnAddTeam:SetEnabled(true)
		wTeamsManager.btnAddTeam:SetText(replaceCharacters(replaceCharacters(translate('txtAddTeam'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wTeamsManager.btnAddTeam:SetZOrder(210)
		wTeamsManager.btnAddTeam.Click = function(sender,args)
				addNameDialog(true, 'Teams')
				activateWindow(wAddNameDialog, true)
			end
		-- Delete Team button
		wTeamsManager.btnDeleteTeam = Turbine.UI.Lotro.Button()
		wTeamsManager.btnDeleteTeam:SetParent(wTeamsManager)
		wTeamsManager.btnDeleteTeam:SetPosition(guiSpacing + (guiColumnWidth / 2) + (guiSpacing / 2), guiCtrlHeigth * 12)
		wTeamsManager.btnDeleteTeam:SetSize(guiSmallButtonWidth, guiCtrlHeigth)
		wTeamsManager.btnDeleteTeam:SetEnabled(true)
		wTeamsManager.btnDeleteTeam:SetText(replaceCharacters(replaceCharacters(translate('txtDeleteTeam'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wTeamsManager.btnDeleteTeam:SetZOrder(210)
		wTeamsManager.btnDeleteTeam.Click = function(sender,args)
				deleteTeam(selectedTeam)
				local teamList = listParticipants('Teams')
				refreshTMList(teamList, wTeamsManager.teamsBoxList)
				selectedTeam = ''
				remapShortcut(wTeamsManager.qsAnnounceTeams, printTeams('', '', config['GAME']['GameChannel']))
				local memberList = listTeamMembers(selectedPlayer, selectedTeam)
				refreshTMList(memberList, wTeamsManager.membersBoxList)
				selectedMember = ''
				local playerList = listParticipants('Players')
				refreshTMList(playerList, wTeamsManager.playersBoxList)
				selectedPlayer = ''
				remapShortcut(wTeamsManager.qsAnnounceMembers, '/dance')
				wTeamsManager.qsAnnounceMembers:SetEnabled(false)
				wTeamsManager.qsAnnounceMembers:SetVisible(false)
				wTeamsManager.btnAnnounceMembers:SetEnabled(false)
				wTeamsManager.btnAnnounceMembers:SetVisible(false)
			end
		-- Announce Members quickslot
		wTeamsManager.qsAnnounceMembers = Turbine.UI.Lotro.Quickslot()
		wTeamsManager.qsAnnounceMembers:SetParent(wTeamsManager)
		wTeamsManager.qsAnnounceMembers:SetPosition(guiSpacing + guiColumnWidth + guiInterBoxSpace1 + guiColumnWidth / 2 - guiButtonWidth / 2, guiCtrlHeigth * 12)
		wTeamsManager.qsAnnounceMembers:SetSize(guiButtonWidth - 5, guiCtrlHeigth)
		wTeamsManager.qsAnnounceMembers:SetShortcut(Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '/dance'))
		wTeamsManager.qsAnnounceMembers.ShortcutData = '/dance' -- Prevent drop over itself bug, step 1
		wTeamsManager.qsAnnounceMembers:SetAllowDrop(false)
		wTeamsManager.qsAnnounceMembers:SetZOrder(210)
		wTeamsManager.qsAnnounceMembers.DragDrop = function()
				-- Prevent drop over itself bug, step 2
				local sc = Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '')
				sc:SetData(wTeamsManager.qsAnnounceMembers.ShortcutData)
				wTeamsManager.qsAnnounceMembers:SetShortcut(sc)
			end
		wTeamsManager.qsAnnounceMembers:SetEnabled(false)
		wTeamsManager.qsAnnounceMembers:SetVisible(false)
		wTeamsManager.btnAnnounceMembers = createOverlayButton(wTeamsManager.qsAnnounceMembers, wTeamsManager, replaceCharacters(replaceCharacters(translate('txtAnnounceMembers'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui), wTeamsManager.qsAnnounceMembers:GetLeft(), wTeamsManager.qsAnnounceMembers:GetTop(), wTeamsManager.qsAnnounceMembers:GetWidth(), wTeamsManager.qsAnnounceMembers:GetHeight(), wTeamsManager.qsAnnounceMembers:GetZOrder(), 2) -- Although named "btn" what we get is really the generic control parent to graphics and text that does the appareance trick
		wTeamsManager.btnAnnounceMembers:SetEnabled(false)
		wTeamsManager.btnAnnounceMembers:SetVisible(false)
		-- Add Player button
		wTeamsManager.btnAddPlayer = Turbine.UI.Lotro.Button()
		wTeamsManager.btnAddPlayer:SetParent(wTeamsManager)
		wTeamsManager.btnAddPlayer:SetPosition(guiSpacing + guiColumnWidth * 2 + guiInterBoxSpace1 + guiInterBoxSpace2 + (guiColumnWidth / 2) - guiSmallButtonWidth - (guiSpacing / 2), guiCtrlHeigth * 12)
		wTeamsManager.btnAddPlayer:SetSize(guiSmallButtonWidth, guiCtrlHeigth)
		wTeamsManager.btnAddPlayer:SetEnabled(true)
		wTeamsManager.btnAddPlayer:SetText(replaceCharacters(replaceCharacters(translate('txtAddPlayer'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wTeamsManager.btnAddPlayer:SetZOrder(210)
		wTeamsManager.btnAddPlayer.Click = function(sender,args)
				addNameDialog(true, 'Players')
				activateWindow(wAddNameDialog, true)
			end
		-- Delete Player button
		wTeamsManager.DeletePlayer = Turbine.UI.Lotro.Button()
		wTeamsManager.DeletePlayer:SetParent(wTeamsManager)
		wTeamsManager.DeletePlayer:SetPosition(guiSpacing + guiColumnWidth * 2 + guiInterBoxSpace1 + guiInterBoxSpace2 + (guiColumnWidth / 2) + (guiSpacing / 2), guiCtrlHeigth * 12)
		wTeamsManager.DeletePlayer:SetSize(guiSmallButtonWidth, guiCtrlHeigth)
		wTeamsManager.DeletePlayer:SetEnabled(true)
		wTeamsManager.DeletePlayer:SetText(replaceCharacters(replaceCharacters(translate('txtDeletePlayer'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wTeamsManager.DeletePlayer:SetZOrder(210)
		wTeamsManager.DeletePlayer.Click = function(sender,args)
				deletePlayer(selectedPlayer)
				local playerList = listParticipants('Players')
				refreshTMList(playerList, wTeamsManager.playersBoxList)
				selectedPlayer = ''
				local teamList = listParticipants('Teams')
				refreshTMList(teamList, wTeamsManager.teamsBoxList)
				remapShortcut(wTeamsManager.qsAnnounceTeams, printTeams('', '', config['GAME']['GameChannel']))
				selectedTeam = ''
				local memberList = listTeamMembers(selectedPlayer, selectedTeam)
				refreshTMList(memberList, wTeamsManager.membersBoxList)
				selectedMember = ''
				remapShortcut(wTeamsManager.qsAnnounceMembers, printPlayers(selectedPlayer, selectedTeam, config['GAME']['GameChannel']))
				wTeamsManager.qsAnnounceMembers:SetEnabled(false)
				wTeamsManager.qsAnnounceMembers:SetVisible(false)
				wTeamsManager.btnAnnounceMembers:SetEnabled(false)
				wTeamsManager.btnAnnounceMembers:SetVisible(false)
			end

		-- Teams Manager information label
		wTeamsManager.lblTeamsManagerInfo = Turbine.UI.Label()
		wTeamsManager.lblTeamsManagerInfo:SetParent(wTeamsManager)
		wTeamsManager.lblTeamsManagerInfo:SetPosition(guiSpacing, guiCtrlHeigth * 13)
		wTeamsManager.lblTeamsManagerInfo:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth * 3)
		wTeamsManager.lblTeamsManagerInfo:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		wTeamsManager.lblTeamsManagerInfo:SetText(replaceCharacters(replaceCharacters(translate('txtTeamsManagerInfo'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. '.')
		wTeamsManager.lblTeamsManagerInfo:SetZOrder(210)
		-- Announce Teams quickslot
		local chatCommand = printTeams('', '', config['GAME']['GameChannel'])
		wTeamsManager.qsAnnounceTeams = Turbine.UI.Lotro.Quickslot()
		wTeamsManager.qsAnnounceTeams:SetParent(wTeamsManager)
		wTeamsManager.qsAnnounceTeams:SetPosition((guiWidth / 2) - guiButtonWidth - (guiSpacing / 2), guiCtrlHeigth * 16)
		wTeamsManager.qsAnnounceTeams:SetSize(guiButtonWidth, guiCtrlHeigth)
		wTeamsManager.qsAnnounceTeams:SetShortcut(Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, chatCommand))
		wTeamsManager.qsAnnounceTeams.ShortcutData = chatCommand -- Prevent drop over itself bug, step 1
		wTeamsManager.qsAnnounceTeams:SetAllowDrop(false)
		wTeamsManager.qsAnnounceTeams:SetZOrder(210)
		wTeamsManager.qsAnnounceTeams.DragDrop = function()
				-- Prevent drop over itself bug, step 2
				local sc = Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias, '')
				sc:SetData(wTeamsManager.qsAnnounceTeams.ShortcutData)
				wTeamsManager.qsAnnounceTeams:SetShortcut(sc)
			end
		wTeamsManager.btnAnnounceTeams = createOverlayButton(wTeamsManager.qsAnnounceTeams, wTeamsManager, replaceCharacters(replaceCharacters(translate('txtAnnounceTeams'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui), wTeamsManager.qsAnnounceTeams:GetLeft(), wTeamsManager.qsAnnounceTeams:GetTop(), wTeamsManager.qsAnnounceTeams:GetWidth(), wTeamsManager.qsAnnounceTeams:GetHeight(), wTeamsManager.qsAnnounceTeams:GetZOrder(), 2) -- Although named "btn" what we get is really the generic control parent to graphics and text that does the appareance trick

		-- Close button
		wTeamsManager.btnClose = Turbine.UI.Lotro.Button()
		wTeamsManager.btnClose:SetParent(wTeamsManager)
		wTeamsManager.btnClose:SetPosition((guiWidth / 2) + (guiSpacing / 2), guiCtrlHeigth * 16)
		wTeamsManager.btnClose:SetSize(guiButtonWidth, guiCtrlHeigth)
		wTeamsManager.btnClose:SetEnabled(true)
		wTeamsManager.btnClose:SetText(replaceCharacters(replaceCharacters(translate('txtClose'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wTeamsManager.btnClose:SetZOrder(210)
		wTeamsManager.btnClose.Click = function(sender,args)
				teamsManager(false)
				dataManagement(gameParticipants, 'Save', 'Istelien_participants')
			end

		function wTeamsManager:Closing(sender,args)
			savePosition(wTeamsManager, 'TeamsManager', wTeamsManager:GetLeft(), wTeamsManager:GetTop())
		end

	else -- Destroy
		if (wTeamsManager ~= nil) then
			wTeamsManager:Close()
			wTeamsManager = nil
		end
	end
end

-- Introduce a name for either a new player or a new team.
function addNameDialog(create, participantsType)
	if (create == true) then
		local guiColumnWidth = 150
		local guiColumnNumber = 1
		local guiWidth = (guiColumnNumber * guiColumnWidth) + ((guiColumnNumber + 1) * guiSpacing)
		local guiHeight =  guiCtrlHeigth * 6
		local newElement = ''

		-- CREATE WINDOW
		wAddNameDialog = Turbine.UI.Lotro.Window()
		wAddNameDialog:SetSize(guiWidth, guiHeight)
		wAddNameDialog:SetPosition((Turbine.UI.Display.GetWidth()/2)-(guiWidth/2),(Turbine.UI.Display.GetHeight()/2)-(guiHeight/2))
		wAddNameDialog:SetText(replaceCharacters(replaceCharacters(translate('txtName'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wAddNameDialog:SetZOrder(300)
		-- Enter Name input
		wAddNameDialog.inptEnterName = Turbine.UI.Lotro.TextBox()
		wAddNameDialog.inptEnterName:SetParent(wAddNameDialog)
		wAddNameDialog.inptEnterName:SetPosition(guiSpacing, guiCtrlHeigth * 2)
		wAddNameDialog.inptEnterName:SetSize(guiColumnWidth, guiCtrlHeigth)
		wAddNameDialog.inptEnterName:SetMultiline(false)
		wAddNameDialog.inptEnterName:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wAddNameDialog.inptEnterName:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		wAddNameDialog.inptEnterName:SetText('')
		-- wAddNameDialog.inptEnterName:SetZOrder(310) -- Disabling because cannot set ZOrder in dropdowns
		-- Add button
		wAddNameDialog.btnAdd = Turbine.UI.Lotro.Button()
		wAddNameDialog.btnAdd:SetParent(wAddNameDialog)
		wAddNameDialog.btnAdd:SetPosition((guiWidth / 2) - (guiButtonWidth / 2), guiCtrlHeigth * 4)
		wAddNameDialog.btnAdd:SetSize(guiButtonWidth, guiCtrlHeigth)
		wAddNameDialog.btnAdd:SetText(replaceCharacters(replaceCharacters(translate('txtAdd'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wAddNameDialog.btnAdd:SetZOrder(310) -- Disabling because cannot set ZOrder in dropdowns
		wAddNameDialog.btnAdd.Click = function(sender,args)
				newElement = wAddNameDialog.inptEnterName:GetText()
				if (newElement ~= '') then
					if (participantsType == 'Players') then
						updatePlayerData(newElement)
						local teamsList = listParticipants('Teams')
						refreshTMList(teamsList, wTeamsManager.teamsBoxList)
						selectedTeam = ''
						local memberList = listTeamMembers(selectedPlayer, selectedTeam)
						refreshTMList(memberList, wTeamsManager.membersBoxList)
						selectedMember = ''
						local playerList = listParticipants('Players')
						refreshTMList(playerList, wTeamsManager.playersBoxList)
						selectedPlayer = ''
						remapShortcut(wTeamsManager.qsAnnounceMembers, '/dance')
						wTeamsManager.qsAnnounceMembers:SetEnabled(false)
						wTeamsManager.qsAnnounceMembers:SetVisible(false)
						wTeamsManager.btnAnnounceMembers:SetEnabled(false)
						wTeamsManager.btnAnnounceMembers:SetVisible(false)
					else
						createTeam(newElement)
						local teamsList = listParticipants('Teams')
						refreshTMList(teamsList, wTeamsManager.teamsBoxList)
						selectedTeam = ''
						local memberList = listTeamMembers(selectedPlayer, selectedTeam)
						refreshTMList(memberList, wTeamsManager.membersBoxList)
						selectedMember = ''
						local playerList = listParticipants('Players')
						refreshTMList(playerList, wTeamsManager.playersBoxList)
						selectedPlayer = ''
						remapShortcut(wTeamsManager.qsAnnounceTeams, printTeams('', '', config['GAME']['GameChannel']))
						remapShortcut(wTeamsManager.qsAnnounceMembers, '/dance')
						wTeamsManager.qsAnnounceMembers:SetEnabled(false)
						wTeamsManager.qsAnnounceMembers:SetVisible(false)
						wTeamsManager.btnAnnounceMembers:SetEnabled(false)
						wTeamsManager.btnAnnounceMembers:SetVisible(false)
					end
				end
				addNameDialog(false)
			end
			
		function wAddNameDialog:Deactivated(sender,args) -- Make it stay always on top
			if (wAddNameDialog ~= nil) then
				wAddNameDialog:Activate()
				wAddNameDialog:Focus()
			end
		end

	else -- Destroy
		if (wAddNameDialog ~= nil) then
			wAddNameDialog:Close()
			wAddNameDialog = nil
		end
	end
end


-- This is the window to browse the savegame slots and perform load / save operations
function savedGames(create, mode)
	if (create == true) then
		local guiColumnWidth = 150
		local savegameSlots = 10
		local guiColumnNumber = 2
		local guiWidth = (guiColumnNumber * guiColumnWidth) + ((guiColumnNumber + 1) * guiSpacing)
		local guiHeight =  guiCtrlHeigth * (7 + savegameSlots)		
		local posX,posY = calcDefaultWindowPos('SavedGames', guiWidth, guiHeight)
		local defaultColor = Turbine.UI.Color(0, 0, 0)
		local selectedColor = Turbine.UI.Color(0.404, 0, 0.404) -- Very Dark Magenta
		local disabledColor = Turbine.UI.Color(0.259, 0.259, 0.259) -- Very Dark Grey
		selectedSave = 0
		
		-- Function to call for build the listbox's content or rebuild it when there's an update
		function refreshSGList(list, parentControl)
			parentControl:ClearItems()
			local listItems = {}
			for i = 1, 10 do
				listItems[i] = {}
				local slotRow = Turbine.UI.Control()
				slotRow:SetParent(parentControl)
				slotRow:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth)
				-- Savegame name
				local saveName = i .. ' - ' .. replaceCharacters(replaceCharacters(translate('txtEmptySlot'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui)
				listItems[i] = Turbine.UI.Label()
				listItems[i]:SetParent(slotRow)
				listItems[i]:SetPosition(0, 0)
				listItems[i]:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth)
				listItems[i]:SetFont(Turbine.UI.Lotro.Font.Verdana16)
				listItems[i]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
				listItems[i]:SetBackColor(defaultColor)
				if (list[i] ~= nil) then
					saveName = i .. ' - ' .. list[i]['SaveName']
				else
					listItems[i]:SetForeColor(disabledColor)
				end
				if (i == selectedSave) then
					listItems[i]:SetBackColor(selectedColor)
					if (mode == 'Load') then
						wSavedGames.btnLoad:SetEnabled(true)
					else
						wSavedGames.btnSave:SetEnabled(true)
					end
				end
				listItems[i]:SetText(saveName)
				listItems[i].MouseClick = function() -- Change selection
						if (mode == 'Load') then
							if (list[i] ~= nil) then
								selectedSave = i
								-- Disabling buttons because the we're resetting the list (and thus the window) and if there's a selection they'll be enabled again when building the list.
								wSavedGames.btnLoad:SetEnabled(false)
								refreshSGList(savegameLib, wSavedGames.boxList)
							end
						else -- mode = 'Save'					
							selectedSave = i
							wSavedGames.btnSave:SetEnabled(false)
							refreshSGList(savegameLib, wSavedGames.boxList)
						end
					end
				parentControl:AddItem(slotRow)
			end
		end		

		-- CREATE WINDOW
		wSavedGames = Turbine.UI.Lotro.Window()
		wSavedGames:SetSize(guiWidth, guiHeight)
		wSavedGames:SetPosition(posX, posY)
		wSavedGames:SetText(replaceCharacters(replaceCharacters(translate('txtSavegames'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wSavedGames:SetZOrder(200)

		-- Package List title
		wSavedGames.lblSavegameListTitle = Turbine.UI.Label()
		wSavedGames.lblSavegameListTitle:SetParent(wSavedGames)
		wSavedGames.lblSavegameListTitle:SetPosition(guiSpacing, guiCtrlHeigth * 2)
		wSavedGames.lblSavegameListTitle:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth)
		wSavedGames.lblSavegameListTitle:SetForeColor(Turbine.UI.Color(1,0.843,0))
		wSavedGames.lblSavegameListTitle:SetFont(Turbine.UI.Lotro.Font.TrajanPro18)
		wSavedGames.lblSavegameListTitle:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		wSavedGames.lblSavegameListTitle:SetText(replaceCharacters(replaceCharacters(translate('txtSavegameList'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wSavedGames.lblSavegameListTitle:SetZOrder(210)
		-- Box with the list of participants and suggested points
		wSavedGames.boxList = Turbine.UI.ListBox()
		wSavedGames.boxList:SetParent(wSavedGames)
		wSavedGames.boxList:SetPosition(guiSpacing, guiCtrlHeigth * 3)
		wSavedGames.boxList:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth * savegameSlots)
		wSavedGames.boxList:SetZOrder(210)
		refreshSGList(savegameLib, wSavedGames.boxList)
		-- Delete selected button
		wSavedGames.btnDeleteSelected = Turbine.UI.Lotro.Button()
		wSavedGames.btnDeleteSelected:SetParent(wSavedGames)
		wSavedGames.btnDeleteSelected:SetPosition((guiWidth / 2) + (guiSpacing / 2), guiCtrlHeigth * (3 + savegameSlots))
		wSavedGames.btnDeleteSelected:SetSize(guiButtonWidth, guiCtrlHeigth)
		wSavedGames.btnDeleteSelected:SetEnabled(true)
		wSavedGames.btnDeleteSelected:SetText(replaceCharacters(replaceCharacters(translate('txtDeleteSelected'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wSavedGames.btnDeleteSelected:SetZOrder(210)
		wSavedGames.btnDeleteSelected.Click = function(sender,args)
				local index = selectedSave
				savegameLib[index] = nil
				selectedSave = 0
				refreshSGList(savegameLib, wSavedGames.boxList)
				if (savegameLib[index] ~= nil) then
					listItems[index]:SetBackColor(selectedColor)
					selectedSave = index
					wSavedGames.lblSavegameConfirmation:SetText(replaceCharacters(replaceCharacters(translate('txtDeletedSelectedFail'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ' ' .. index .. '.')
				else					
					wSavedGames.lblSavegameConfirmation:SetText(replaceCharacters(replaceCharacters(translate('txtDeletedSelectedOK'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ' ' .. index .. '.')
					dataManagement(savegameLib, 'Save', 'Istelien_savegameLib')
					if (mode == 'Load') then	
						wSavedGames.btnLoad:SetEnabled(false)
					else
						wSavedGames.btnSave:SetEnabled(false)
					end
				end
			end
		if (mode == 'Load') then		
			wSavedGames.btnDeleteSelected:SetPosition((guiWidth / 2) + (guiSpacing / 2), guiCtrlHeigth * (3 + savegameSlots))
			-- Load button
			wSavedGames.btnLoad = Turbine.UI.Lotro.Button()
			wSavedGames.btnLoad:SetParent(wSavedGames)
			wSavedGames.btnLoad:SetPosition((guiWidth / 2) - guiButtonWidth - (guiSpacing / 2), guiCtrlHeigth * (3 + savegameSlots))
			wSavedGames.btnLoad:SetSize(guiButtonWidth, guiCtrlHeigth)
			wSavedGames.btnLoad:SetEnabled(false)
			wSavedGames.btnLoad:SetText(replaceCharacters(replaceCharacters(translate('txtLoadGame'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
			wSavedGames.btnLoad:SetZOrder(210)
			wSavedGames.btnLoad.Click = function(sender,args)
					local index = selectedSave
					if (loadGame(savegameLib, selectedSave) == true) then
						wSavedGames.lblSavegameConfirmation:SetText(replaceCharacters(replaceCharacters(translate('txtLoadGameOK'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ' ' .. index .. '.')
						pausedGameFromSave()
						refreshMainGui()
						resetActionButtons()
					else
						wSavedGames.lblSavegameConfirmation:SetText(replaceCharacters(replaceCharacters(translate('txtLoadGameFail'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ' ' .. index .. '.')
						selectedSave = 0
						wSavedGames.btnLoad:SetEnabled(false)
					end
					refreshSGList(savegameLib, wSavedGames.boxList)
				end
		else			
			-- Save button
			wSavedGames.btnSave = Turbine.UI.Lotro.Button()
			wSavedGames.btnSave:SetParent(wSavedGames)
			wSavedGames.btnSave:SetPosition((guiWidth / 2) - guiButtonWidth - (guiSpacing / 2), guiCtrlHeigth * (3 + savegameSlots))
			wSavedGames.btnSave:SetSize(guiButtonWidth, guiCtrlHeigth)
			wSavedGames.btnSave:SetEnabled(false)
			wSavedGames.btnSave:SetText(replaceCharacters(replaceCharacters(translate('txtSaveGame'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
			wSavedGames.btnSave:SetZOrder(210)
			wSavedGames.btnSave.Click = function(sender,args)
					if (selectedSave ~= 0) then
						savegameNameDialog(true, selectedSave)
						activateWindow(wSavegameNameDialog, true)				
					end								
				end
		end
		wSavedGames.lblSavegameConfirmation = Turbine.UI.Label()
		wSavedGames.lblSavegameConfirmation:SetParent(wSavedGames)
		wSavedGames.lblSavegameConfirmation:SetPosition(guiSpacing,guiCtrlHeigth * (4 + savegameSlots))
		wSavedGames.lblSavegameConfirmation:SetSize(guiWidth - guiSpacing * 2, guiCtrlHeigth)
		wSavedGames.lblSavegameConfirmation:SetForeColor(Turbine.UI.Color(1,0.843,0))
		wSavedGames.lblSavegameConfirmation:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wSavedGames.lblSavegameConfirmation:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		wSavedGames.lblSavegameConfirmation:SetText('')
		wSavedGames.lblSavegameConfirmation:SetZOrder(210)
		-- Close / cancel button
		wSavedGames.btnClose = Turbine.UI.Lotro.Button()
		wSavedGames.btnClose:SetParent(wSavedGames)
		wSavedGames.btnClose:SetPosition((guiWidth / 2) - (guiButtonWidth / 2), guiCtrlHeigth * (5 + savegameSlots))
		wSavedGames.btnClose:SetSize(guiButtonWidth, guiCtrlHeigth)
		wSavedGames.btnClose:SetEnabled(true)
		wSavedGames.btnClose:SetText(replaceCharacters(replaceCharacters(translate('txtClose'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wSavedGames.btnClose:SetZOrder(210)
		wSavedGames.btnClose.Click = function(sender,args)
				savedGames(false)
			end

		function wSavedGames:Closing(sender,args)
			savePosition(wSavedGames, 'SavedGames', wSavedGames:GetLeft(), wSavedGames:GetTop())
		end
	else -- Destroy
		if (wSavedGames ~= nil) then
			wSavedGames:Close()
			wSavedGames = nil
		end
	end
end

-- introduce a name and save game
function savegameNameDialog(create, slotNumber)
	if (create == true) then
		local guiColumnWidth = 150
		local guiColumnNumber = 1
		local guiWidth = (guiColumnNumber * guiColumnWidth) + ((guiColumnNumber + 1) * guiSpacing)
		local guiHeight =  guiCtrlHeigth * 7
		local newElement = ''

		-- CREATE WINDOW
		wSavegameNameDialog = Turbine.UI.Lotro.Window()
		wSavegameNameDialog:SetSize(guiWidth, guiHeight)
		wSavegameNameDialog:SetPosition((Turbine.UI.Display.GetWidth()/2)-(guiWidth/2),(Turbine.UI.Display.GetHeight()/2)-(guiHeight/2))
		wSavegameNameDialog:SetText(replaceCharacters(replaceCharacters(translate('txtName'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		wSavegameNameDialog:SetZOrder(300)
		-- Enter Name input
		wSavegameNameDialog.inptEnterName = Turbine.UI.Lotro.TextBox()
		wSavegameNameDialog.inptEnterName:SetParent(wSavegameNameDialog)
		wSavegameNameDialog.inptEnterName:SetPosition(guiSpacing, guiCtrlHeigth * 2)
		wSavegameNameDialog.inptEnterName:SetSize(guiColumnWidth, guiCtrlHeigth)
		wSavegameNameDialog.inptEnterName:SetMultiline(false)
		wSavegameNameDialog.inptEnterName:SetFont(Turbine.UI.Lotro.Font.Verdana16)
		wSavegameNameDialog.inptEnterName:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
		wSavegameNameDialog.inptEnterName:SetText(replaceCharacters(replaceCharacters(translate('txtName'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wSavegameNameDialog.inptEnterName:SetZOrder(310) -- Disabling because cannot set ZOrder in dropdowns
		-- Save button
		wSavegameNameDialog.btnSave = Turbine.UI.Lotro.Button()
		wSavegameNameDialog.btnSave:SetParent(wSavegameNameDialog)
		wSavegameNameDialog.btnSave:SetPosition((guiWidth / 2) - (guiButtonWidth / 2), guiCtrlHeigth * 4)
		wSavegameNameDialog.btnSave:SetSize(guiButtonWidth, guiCtrlHeigth)
		wSavegameNameDialog.btnSave:SetText(replaceCharacters(replaceCharacters(translate('txtSave'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wSavegameNameDialog.btnSave:SetZOrder(310) -- Disabling because cannot set ZOrder in dropdowns
		wSavegameNameDialog.btnSave.Click = function(sender,args)
				local saveName = wSavegameNameDialog.inptEnterName:GetText()
				
				if (saveGame(slotNumber, saveName) == true) then
					wSavedGames.lblSavegameConfirmation:SetText(replaceCharacters(replaceCharacters(translate('txtSaveGameOK'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ' ' .. slotNumber .. '.')
					dataManagement(savegameLib, 'Save', 'Istelien_savegameLib')
					Turbine.Shell.WriteLine(istelienTextLogo .. ' Game Saved.')
				else
					wSavedGames.lblSavegameConfirmation:SetText(replaceCharacters(replaceCharacters(translate('txtSaveGameFail'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui) .. ' ' .. slotNumber .. '.')
					selectedSave = 0
					wSavedGames.btnSave:SetEnabled(false)
				end
				refreshSGList(savegameLib, wSavedGames.boxList)
				savegameNameDialog(false)
			end
		-- Cancel button
		wSavegameNameDialog.btnCancel = Turbine.UI.Lotro.Button()
		wSavegameNameDialog.btnCancel:SetParent(wSavegameNameDialog)
		wSavegameNameDialog.btnCancel:SetPosition((guiWidth / 2) - (guiButtonWidth / 2), guiCtrlHeigth * 5)
		wSavegameNameDialog.btnCancel:SetSize(guiButtonWidth, guiCtrlHeigth)
		wSavegameNameDialog.btnCancel:SetText(replaceCharacters(replaceCharacters(translate('txtCancel'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- wSavegameNameDialog.btnCancel:SetZOrder(310) -- Disabling because cannot set ZOrder in dropdowns
		wSavegameNameDialog.btnCancel.Click = function(sender,args)
				savegameNameDialog(false)
			end
			
		function wSavegameNameDialog:Deactivated(sender,args) -- Make it stay always on top
			if (wSavegameNameDialog ~= nil) then
				wSavegameNameDialog:Activate()
				wSavegameNameDialog:Focus()
			end
		end

	else -- Destroy
		if (wSavegameNameDialog ~= nil) then
			wSavegameNameDialog:Close()
			wSavegameNameDialog = nil
		end
	end
end

-- introduce a name and save game
function helpWindow(create)
	if (create == true) then
		local guiColumnWidth = 500
		local guiWidth = (guiColumnWidth + guiSpacing * 2)
		local guiHeight =  500

		-- CREATE WINDOW
		wHelpWindow = Turbine.UI.Lotro.Window()
		wHelpWindow:SetSize(guiWidth, guiHeight)
		wHelpWindow:SetPosition((Turbine.UI.Display.GetWidth()/2)-(guiWidth/2),(Turbine.UI.Display.GetHeight()/2)-(guiHeight/2))
		wHelpWindow:SetText('Istelien')
		wHelpWindow:SetZOrder(10000)
		-- Information text
		wHelpWindow.lblText = Turbine.UI.Label()
		wHelpWindow.lblText:SetParent(wHelpWindow)
		wHelpWindow.lblText:SetPosition(guiSpacing, guiSpacing)
		wHelpWindow.lblText:SetSize(guiColumnWidth, guiHeight - guiSpacing * 2)
		wHelpWindow.lblText:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
		wHelpWindow.lblText:SetText(replaceCharacters(replaceCharacters(translate('txtHelpText'), nonbasicCharactersForGuiPrev), nonbasicCharactersForGui))
		-- Author label. Bottom right of the window.
		wHelpWindow.lblAuthor = Turbine.UI.Label()
		wHelpWindow.lblAuthor:SetParent(wHelpWindow)
		wHelpWindow.lblAuthor:SetPosition(guiWidth / 2, guiHeight - guiSpacing * 2)
		wHelpWindow.lblAuthor:SetSize(guiWidth / 2 - guiSpacing * 2, guiCtrlHeigth)
		wHelpWindow.lblAuthor:SetFont(Turbine.UI.Lotro.Font.LucidaConsole12)
		wHelpWindow.lblAuthor:SetTextAlignment(Turbine.UI.ContentAlignment.BottomRight)
		wHelpWindow.lblAuthor:SetText('Anglachel')	
		
	else -- Destroy
		if (wHelpWindow ~= nil) then
			wHelpWindow:Close()
			wHelpWindow = nil
		end
	end
end


function stringTrick(input)

	return output

end